@@ -27,7 +27,8 @@
 
 class CustomTrackScene;
 
-class AbstractClipItem : public QObject , public QGraphicsRectItem {
+class AbstractClipItem : public QObject , public QGraphicsRectItem
+{
     Q_OBJECT
 public:
     AbstractClipItem(const ItemInfo info, const QRectF& rect, double fps);
@@ -42,6 +43,8 @@ public:
     CustomTrackScene* projectScene();
     void updateRectGeometry();
     void updateItem();
+    void setItemLocked(bool locked);
+    bool isItemLocked() const;
 
     virtual  OPERATIONTYPE operationMode(QPointF pos) = 0;
     virtual GenTime startPos() const ;
@@ -72,7 +75,7 @@ protected:
     double m_fps;
     QPainterPath upperRectPart(QRectF);
     QPainterPath lowerRectPart(QRectF);
-    QRect visibleRect();
+    //QRect visibleRect();
     void drawKeyFrames(QPainter *painter, QRectF exposedRect);
     int mouseOverKeyFrames(QPointF pos);
 };
