@@ -17,16 +17,17 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
-#include <QDir>
+
+#include "clipproperties.h"
+#include "kdenlivesettings.h"
+#include "kthumb.h"
+#include "markerdialog.h"
 
 #include <KStandardDirs>
 #include <KDebug>
 #include <KFileItem>
 
-#include "kdenlivesettings.h"
-#include "clipproperties.h"
-#include "kthumb.h"
-#include "markerdialog.h"
+#include <QDir>
 
 static const int VIDEOTAB = 0;
 static const int AUDIOTAB = 1;
@@ -42,7 +43,14 @@ static const int TYPE_PNG = 1;
 static const int TYPE_BMP = 2;
 static const int TYPE_GIF = 3;
 
-ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidget * parent): QDialog(parent), m_tc(tc), m_clip(clip), m_fps(fps), m_clipNeedsRefresh(false), m_count(0) {
+ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidget * parent) :
+        QDialog(parent),
+        m_clip(clip),
+        m_tc(tc),
+        m_fps(fps),
+        m_count(0),
+        m_clipNeedsRefresh(false)
+{
     setFont(KGlobalSettings::toolBarFont());
     m_view.setupUi(this);
     KUrl url = m_clip->fileURL();
@@ -130,7 +138,7 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
         m_view.tabWidget->removeTab(AUDIOTAB);
         m_view.tabWidget->removeTab(VIDEOTAB);
         m_view.clip_thumb->setHidden(true);
-        m_view.clip_color->setColor(QColor("#" + props.value("colour").right(8).left(6)));
+        m_view.clip_color->setColor(QColor('#' + props.value("colour").right(8).left(6)));
     } else if (t == SLIDESHOW) {
         m_view.clip_path->setText(url.directory());
         m_view.tabWidget->removeTab(METATAB);
@@ -176,8 +184,8 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
             m_view.luma_file->addItem(KIcon(folder + '/' + fname), fname, folder + '/' + fname);
         }
 
-        slotEnableLuma(m_view.slide_fade->isChecked());
-        slotEnableLumaFile(m_view.slide_luma->isChecked());
+        slotEnableLuma(m_view.slide_fade->checkState());
+        slotEnableLumaFile(m_view.slide_luma->checkState());
 
         if (!lumaFile.isEmpty()) {
             m_view.slide_luma->setChecked(true);
@@ -234,7 +242,8 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
     adjustSize();
 }
 
-void ClipProperties::slotEnableLuma(int state) {
+void ClipProperties::slotEnableLuma(int state)
+{
     bool enable = false;
     if (state == Qt::Checked) enable = true;
     m_view.luma_duration->setEnabled(enable);
@@ -246,7 +255,8 @@ void ClipProperties::slotEnableLuma(int state) {
     m_view.luma_softness->setEnabled(m_view.label_softness->isEnabled());
 }
 
-void ClipProperties::slotEnableLumaFile(int state) {
+void ClipProperties::slotEnableLumaFile(int state)
+{
     bool enable = false;
     if (state == Qt::Checked) enable = true;
     m_view.luma_file->setEnabled(enable);
@@ -254,10 +264,11 @@ void ClipProperties::slotEnableLumaFile(int state) {
     m_view.label_softness->setEnabled(enable);
 }
 
-void ClipProperties::slotFillMarkersList() {
+void ClipProperties::slotFillMarkersList()
+{
     m_view.markers_list->clear();
     QList < CommentedTime > marks = m_clip->commentedSnapMarkers();
-    for (uint count = 0; count < marks.count(); ++count) {
+    for (int count = 0; count < marks.count(); ++count) {
         QString time = m_tc.getTimecode(marks[count].time(), m_tc.fps());
         QStringList itemtext;
         itemtext << time << marks[count].comment();
@@ -265,7 +276,8 @@ void ClipProperties::slotFillMarkersList() {
     }
 }
 
-void ClipProperties::slotAddMarker() {
+void ClipProperties::slotAddMarker()
+{
     CommentedTime marker(GenTime(), i18n("Marker"));
     MarkerDialog d(m_clip, marker, m_tc, i18n("Add Marker"), this);
     if (d.exec() == QDialog::Accepted) {
@@ -274,7 +286,8 @@ void ClipProperties::slotAddMarker() {
     QTimer::singleShot(500, this, SLOT(slotFillMarkersList()));
 }
 
-void ClipProperties::slotEditMarker() {
+void ClipProperties::slotEditMarker()
+{
     QList < CommentedTime > marks = m_clip->commentedSnapMarkers();
     int pos = m_view.markers_list->currentIndex().row();
     if (pos < 0 || pos > marks.count() - 1) return;
@@ -285,7 +298,8 @@ void ClipProperties::slotEditMarker() {
     QTimer::singleShot(500, this, SLOT(slotFillMarkersList()));
 }
 
-void ClipProperties::slotDeleteMarker() {
+void ClipProperties::slotDeleteMarker()
+{
     QList < CommentedTime > marks = m_clip->commentedSnapMarkers();
     int pos = m_view.markers_list->currentIndex().row();
     if (pos < 0 || pos > marks.count() - 1) return;
@@ -294,12 +308,14 @@ void ClipProperties::slotDeleteMarker() {
     QTimer::singleShot(500, this, SLOT(slotFillMarkersList()));
 }
 
-const QString &ClipProperties::clipId() const {
+const QString &ClipProperties::clipId() const
+{
     return m_clip->getId();
 }
 
 
-QMap <QString, QString> ClipProperties::properties() {
+QMap <QString, QString> ClipProperties::properties()
+{
     QMap <QString, QString> props;
     CLIPTYPE t = m_clip->clipType();
     QMap <QString, QString> old_props = m_clip->properties();
@@ -314,7 +330,7 @@ QMap <QString, QString> ClipProperties::properties() {
             m_clipNeedsRefresh = true;
         }
     } else if (old_props.contains("force_aspect_ratio")) {
-        props["force_aspect_ratio"] = QString();
+        props["force_aspect_ratio"].clear();
         m_clipNeedsRefresh = true;
     }
 
@@ -324,7 +340,7 @@ QMap <QString, QString> ClipProperties::properties() {
             props["threads"] = QString::number(threads);
         }
     } else if (old_props.contains("threads")) {
-        props["threads"] = QString();
+        props["threads"].clear();
     }
 
     int vindex = m_view.clip_vindex->value();
@@ -333,7 +349,7 @@ QMap <QString, QString> ClipProperties::properties() {
             props["video_index"] = QString::number(vindex);
         }
     } else if (old_props.contains("video_index")) {
-        props["video_index"] = QString();
+        props["video_index"].clear();
     }
 
     int aindex = m_view.clip_aindex->value();
@@ -342,12 +358,12 @@ QMap <QString, QString> ClipProperties::properties() {
             props["audio_index"] = QString::number(aindex);
         }
     } else if (old_props.contains("audio_index")) {
-        props["audio_index"] = QString();
+        props["audio_index"].clear();
     }
 
     if (t == COLOR) {
         QString new_color = m_view.clip_color->color().name();
-        if (new_color != QString("#" + old_props.value("colour").right(8).left(6))) {
+        if (new_color != QString('#' + old_props.value("colour").right(8).left(6))) {
             m_clipNeedsRefresh = true;
             props["colour"] = "0x" + new_color.right(6) + "ff";
         }
@@ -417,8 +433,8 @@ QMap <QString, QString> ClipProperties::properties() {
                 props["luma_file"] = lumaFile;
             }
         } else {
-            if (old_props.value("luma_file") != QString()) {
-                props["luma_file"] = QString();
+            if (!old_props.value("luma_file").isEmpty()) {
+                props["luma_file"].clear();
             }
         }
 
@@ -426,11 +442,13 @@ QMap <QString, QString> ClipProperties::properties() {
     return props;
 }
 
-bool ClipProperties::needsTimelineRefresh() const {
+bool ClipProperties::needsTimelineRefresh() const
+{
     return m_clipNeedsRefresh;
 }
 
-void ClipProperties::parseFolder() {
+void ClipProperties::parseFolder()
+{
 
     QDir dir(m_view.clip_path->text());
     QStringList filters;
@@ -468,7 +486,8 @@ void ClipProperties::parseFolder() {
     m_view.clip_thumb->setPixmap(pix);
 }
 
-void ClipProperties::slotCheckMaxLength() {
+void ClipProperties::slotCheckMaxLength()
+{
     int duration = m_tc.getFrameCount(m_view.clip_duration->text(), m_fps);
     if (duration > m_clip->maxDuration().frames(m_fps)) {
         m_view.clip_duration->setText(m_tc.getTimecode(m_clip->maxDuration(), m_fps));
