@@ -1,48 +1,73 @@
-/**************************1*************************************************
-                          DocClipBase.cpp  -  description
-                             -------------------
-    begin                : Fri Apr 12 2002
-    copyright            : (C) 2002 by Jason Wood
-    email                : jasonwood@blueyonder.co.uk
- ***************************************************************************/
-
 /***************************************************************************
+ *                         DocClipBase.cpp  -  description                 *
+ *                           -------------------                           *
+ *   begin                : Fri Apr 12 2002                                *
+ *   Copyright (C) 2002 by Jason Wood (jasonwood@blueyonder.co.uk)         *
+ *   Copyright (C) 2007 by Jean-Baptiste Mardelle (jb@kdenlive.org)        *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
-#include <QCryptographicHash>
 
-#include <KDebug>
 
-#include "kdenlivesettings.h"
+
 #include "docclipbase.h"
+#include "kdenlivesettings.h"
 #include "kthumb.h"
 #include "clipmanager.h"
 
-DocClipBase::DocClipBase(ClipManager *clipManager, QDomElement xml, const QString &id):
-        m_id(id), m_description(QString()), m_refcount(0), m_audioThumbCreated(false), m_duration(GenTime()), m_thumbProd(NULL), m_audioTimer(NULL), m_properties(QMap <QString, QString> ()), audioFrameChache(QMap<int, QMap<int, QByteArray> > ()), m_baseTrackProducers(QList <Mlt::Producer *>()), m_snapMarkers(QList < CommentedTime > ())  {
+#include <KDebug>
+
+#include <QCryptographicHash>
+
+DocClipBase::DocClipBase(ClipManager *clipManager, QDomElement xml, const QString &id, bool placeHolder) :
+        QObject(),
+        m_audioFrameCache(),
+        m_refcount(0),
+        m_baseTrackProducers(),
+        m_audioTrackProducers(),
+        m_videoOnlyProducer(NULL),
+        m_snapMarkers(),
+        m_duration(),
+        m_audioTimer(NULL),
+        m_thumbProd(NULL),
+        m_audioThumbCreated(false),
+        m_id(id),
+        m_placeHolder(placeHolder),
+        m_properties()
+{
     int type = xml.attribute("type").toInt();
     m_clipType = (CLIPTYPE) type;
 
     QDomNamedNodeMap attributes = xml.attributes();
-    for (unsigned int i = 0; i < attributes.count(); i++) {
+    for (int i = 0; i < attributes.count(); i++) {
         m_properties.insert(attributes.item(i).nodeName(), attributes.item(i).nodeValue());
     }
 
     KUrl url = KUrl(xml.attribute("resource"));
     if (!m_properties.contains("file_hash") && !url.isEmpty()) getFileHash(url.path());
-    int out = xml.attribute("out").toInt();
-    if (out != 0) {
-        setDuration(GenTime(out, KdenliveSettings::project_fps()));
+
+    if (xml.hasAttribute("duration")) {
+        setDuration(GenTime(xml.attribute("duration").toInt(), KdenliveSettings::project_fps()));
     } else {
-        out = xml.attribute("duration").toInt();
-        if (out != 0) setDuration(GenTime(out, KdenliveSettings::project_fps()));
+        int out = xml.attribute("out").toInt();
+        int in = xml.attribute("in").toInt();
+        setDuration(GenTime(out - in, KdenliveSettings::project_fps()));
     }
+
     if (!m_properties.contains("name")) m_properties.insert("name", url.fileName());
 
     //if (!url.isEmpty() && QFile::exists(url.path()))
@@ -64,45 +89,53 @@ DocClipBase::DocClipBase(ClipManager *clipManager, QDomElement xml, const QStrin
     return *this;
 }*/
 
-DocClipBase::~DocClipBase() {
-    if (m_thumbProd) {
-        delete m_thumbProd;
-    }
+DocClipBase::~DocClipBase()
+{
+    delete m_thumbProd;
     if (m_audioTimer) {
         m_audioTimer->stop();
         delete m_audioTimer;
     }
     qDeleteAll(m_baseTrackProducers);
     m_baseTrackProducers.clear();
+    qDeleteAll(m_audioTrackProducers);
+    m_audioTrackProducers.clear();
+    delete m_videoOnlyProducer;
+    m_videoOnlyProducer = NULL;
 }
 
-void DocClipBase::setZone(QPoint zone) {
+void DocClipBase::setZone(QPoint zone)
+{
     m_properties.insert("zone_in", QString::number(zone.x()));
     m_properties.insert("zone_out", QString::number(zone.y()));
 }
 
-QPoint DocClipBase::zone() const {
+QPoint DocClipBase::zone() const
+{
     QPoint zone;
     zone.setX(m_properties.value("zone_in").toInt());
     zone.setY(m_properties.value("zone_out", "50").toInt());
     return zone;
 }
 
-void DocClipBase::slotCreateAudioTimer() {
+void DocClipBase::slotCreateAudioTimer()
+{
     connect(m_thumbProd, SIGNAL(audioThumbReady(QMap <int, QMap <int, QByteArray> >)), this , SLOT(updateAudioThumbnail(QMap <int, QMap <int, QByteArray> >)));
     connect(this, SIGNAL(getAudioThumbs()), this , SLOT(slotGetAudioThumbs()));
     m_audioTimer = new QTimer(this);
     connect(m_audioTimer, SIGNAL(timeout()), this, SLOT(slotGetAudioThumbs()));
 }
 
-void DocClipBase::askForAudioThumbs() {
+void DocClipBase::askForAudioThumbs()
+{
     if (m_thumbProd) m_thumbProd->askForAudioThumbs(getId());
 }
 
-void DocClipBase::slotClearAudioCache() {
+void DocClipBase::slotClearAudioCache()
+{
     if (m_thumbProd) m_thumbProd->stopAudioThumbs();
     if (m_audioTimer != NULL) m_audioTimer->stop();
-    audioFrameChache.clear();
+    m_audioFrameCache.clear();
     m_audioThumbCreated = false;
 }
 
@@ -110,32 +143,39 @@ void DocClipBase::slotClearAudioCache() {
     if (m_thumbProd) m_thumbProd->getMainThumb(m_properties.value("thumbnail").toInt());
 }*/
 
-KThumb *DocClipBase::thumbProducer() {
+KThumb *DocClipBase::thumbProducer()
+{
     return m_thumbProd;
 }
 
-bool DocClipBase::audioThumbCreated() const {
+bool DocClipBase::audioThumbCreated() const
+{
     return m_audioThumbCreated;
 }
 
-const QString & DocClipBase::name() const {
+const QString DocClipBase::name() const
+{
 
     return m_properties.value("name");
 }
 
-const QString &DocClipBase::getId() const {
+const QString &DocClipBase::getId() const
+{
     return m_id;
 }
 
-void DocClipBase::setId(const QString &newId) {
+void DocClipBase::setId(const QString &newId)
+{
     m_id = newId;
 }
 
-const CLIPTYPE & DocClipBase::clipType() const {
+const CLIPTYPE & DocClipBase::clipType() const
+{
     return m_clipType;
 }
 
-void DocClipBase::setClipType(CLIPTYPE type) {
+void DocClipBase::setClipType(CLIPTYPE type)
+{
     m_clipType = type;
 
     m_properties.insert("type", QString::number((int) type));
@@ -143,42 +183,51 @@ void DocClipBase::setClipType(CLIPTYPE type) {
         slotCreateAudioTimer();
 }
 
-KUrl DocClipBase::fileURL() const {
+KUrl DocClipBase::fileURL() const
+{
     QString res = m_properties.value("resource");
     if (m_clipType != COLOR && !res.isEmpty()) return KUrl(res);
     return KUrl();
 }
 
-void DocClipBase::setClipThumbFrame(const uint &ix) {
+void DocClipBase::setClipThumbFrame(const uint &ix)
+{
     m_properties.insert("thumbnail", QString::number((int) ix));
 }
 
-uint DocClipBase::getClipThumbFrame() const {
+uint DocClipBase::getClipThumbFrame() const
+{
     return (uint) m_properties.value("thumbnail").toInt();
 }
 
-const QString DocClipBase::description() const {
+const QString DocClipBase::description() const
+{
     return m_properties.value("description");
 }
 
-bool DocClipBase::isTransparent() const {
+bool DocClipBase::isTransparent() const
+{
     return (m_properties.value("transparency") == "1");
 }
 
-const QString DocClipBase::getProperty(const QString prop) const {
+const QString DocClipBase::getProperty(const QString prop) const
+{
     return m_properties.value(prop);
 }
 
-void DocClipBase::setDuration(GenTime dur) {
+void DocClipBase::setDuration(GenTime dur)
+{
     m_duration = dur;
     m_properties.insert("duration", QString::number((int) dur.frames(KdenliveSettings::project_fps())));
 }
 
-const GenTime &DocClipBase::duration() const {
+const GenTime &DocClipBase::duration() const
+{
     return m_duration;
 }
 
-const GenTime &DocClipBase::maxDuration() const {
+const GenTime DocClipBase::maxDuration() const
+{
     if (m_clipType == COLOR || m_clipType == IMAGE || m_clipType == TEXT || (m_clipType == SLIDESHOW &&  m_properties.value("loop") == "1")) {
         const GenTime dur(15000, KdenliveSettings::project_fps());
         return dur;
@@ -186,15 +235,16 @@ const GenTime &DocClipBase::maxDuration() const {
     return m_duration;
 }
 
-bool DocClipBase::hasFileSize() const {
+bool DocClipBase::hasFileSize() const
+{
     return true;
 }
 
 
 // virtual
-QDomElement DocClipBase::toXML() const {
+QDomElement DocClipBase::toXML() const
+{
     QDomDocument doc;
-
     QDomElement clip = doc.createElement("producer");
 
     QMapIterator<QString, QString> i(m_properties);
@@ -202,94 +252,59 @@ QDomElement DocClipBase::toXML() const {
         i.next();
         if (!i.value().isEmpty()) clip.setAttribute(i.key(), i.value());
     }
-    //doc.appendChild(clip);
+    doc.appendChild(clip);
     //kDebug()<<"/// CLIP XML: "<<doc.toString();
-    return clip;
+    return doc.documentElement();
 }
 
-DocClipBase *DocClipBase::
-createClip(KdenliveDoc *doc, const QDomElement & element) {
-    DocClipBase *clip = 0;
-    QString description;
-    QDomNode node = element;
-    node.normalize();
-    if (element.tagName() != "kdenliveclip") {
-        kWarning() <<
-        "DocClipBase::createClip() element has unknown tagName : " << element.tagName();
-        return 0;
-    }
 
-    QDomNode n = element.firstChild();
-
-    while (!n.isNull()) {
-        QDomElement e = n.toElement();
-        if (!e.isNull()) {
-            QString tagName = e.tagName();
-            if (e.tagName() == "avfile") {
-                // clip = DocClipAVFile::createClip(e);
-            } else if (e.tagName() == "DocTrackBaseList") {
-                // clip = DocClipProject::createClip(doc, e);
-            }
-        } else {
-            QDomText text = n.toText();
-            if (!text.isNull()) {
-                description = text.nodeValue();
-            }
-        }
-
-        n = n.nextSibling();
-    }
-    if (clip == 0) {
-        kWarning() << "DocClipBase::createClip() unable to create clip";
-    } else {
-        // setup DocClipBase specifics of the clip.
-        QMap <QString, QString> props;
-        props.insert("description", description);
-        clip->setProperties(props);
-        clip->setAudioThumbCreated(false);
-    }
-    return clip;
-}
-
-void DocClipBase::setAudioThumbCreated(bool isDone) {
+void DocClipBase::setAudioThumbCreated(bool isDone)
+{
     m_audioThumbCreated = isDone;
 }
 
 
-void DocClipBase::setThumbnail(const QPixmap & pixmap) {
+void DocClipBase::setThumbnail(const QPixmap & pixmap)
+{
     m_thumbnail = pixmap;
 }
 
-const QPixmap & DocClipBase::thumbnail() const {
+const QPixmap & DocClipBase::thumbnail() const
+{
     return m_thumbnail;
 }
 
-void DocClipBase::updateAudioThumbnail(QMap<int, QMap<int, QByteArray> > data) {
+void DocClipBase::updateAudioThumbnail(QMap<int, QMap<int, QByteArray> > data)
+{
     //kDebug() << "CLIPBASE RECIEDVED AUDIO DATA*********************************************";
-    audioFrameChache = data;
+    m_audioFrameCache = data;
     m_audioThumbCreated = true;
     emit gotAudioData();
 }
 
-QList < GenTime > DocClipBase::snapMarkers() const {
+QList < GenTime > DocClipBase::snapMarkers() const
+{
     QList < GenTime > markers;
 
-    for (uint count = 0; count < m_snapMarkers.count(); ++count) {
+    for (int count = 0; count < m_snapMarkers.count(); ++count) {
         markers.append(m_snapMarkers[count].time());
     }
 
     return markers;
 }
 
-QList < CommentedTime > DocClipBase::commentedSnapMarkers() const {
+QList < CommentedTime > DocClipBase::commentedSnapMarkers() const
+{
     return m_snapMarkers;
 }
 
-void DocClipBase::setSnapMarkers(QList < CommentedTime > markers) {
+void DocClipBase::setSnapMarkers(QList < CommentedTime > markers)
+{
     m_snapMarkers = markers;
 }
 
-void DocClipBase::addSnapMarker(const GenTime & time, QString comment) {
+void DocClipBase::addSnapMarker(const GenTime & time, QString comment)
+{
     QList < CommentedTime >::Iterator it = m_snapMarkers.begin();
     for (it = m_snapMarkers.begin(); it != m_snapMarkers.end(); ++it) {
         if ((*it).time() >= time)
@@ -306,7 +321,8 @@ void DocClipBase::addSnapMarker(const GenTime & time, QString comment) {
 
 }
 
-void DocClipBase::editSnapMarker(const GenTime & time, QString comment) {
+void DocClipBase::editSnapMarker(const GenTime & time, QString comment)
+{
     QList < CommentedTime >::Iterator it;
     for (it = m_snapMarkers.begin(); it != m_snapMarkers.end(); ++it) {
         if ((*it).time() == time)
@@ -319,7 +335,8 @@ void DocClipBase::editSnapMarker(const GenTime & time, QString comment) {
     }
 }
 
-QString DocClipBase::deleteSnapMarker(const GenTime & time) {
+QString DocClipBase::deleteSnapMarker(const GenTime & time)
+{
     QString result = i18n("Marker");
     QList < CommentedTime >::Iterator itt = m_snapMarkers.begin();
 
@@ -337,7 +354,8 @@ QString DocClipBase::deleteSnapMarker(const GenTime & time) {
 }
 
 
-GenTime DocClipBase::hasSnapMarkers(const GenTime & time) {
+GenTime DocClipBase::hasSnapMarkers(const GenTime & time)
+{
     QList < CommentedTime >::Iterator itt = m_snapMarkers.begin();
 
     while (itt != m_snapMarkers.end()) {
@@ -349,7 +367,8 @@ GenTime DocClipBase::hasSnapMarkers(const GenTime & time) {
     return GenTime(0.0);
 }
 
-GenTime DocClipBase::findPreviousSnapMarker(const GenTime & currTime) {
+GenTime DocClipBase::findPreviousSnapMarker(const GenTime & currTime)
+{
     int it;
     for (it = 0; it < m_snapMarkers.count(); it++) {
         if (m_snapMarkers[it].time() >= currTime)
@@ -361,7 +380,8 @@ GenTime DocClipBase::findPreviousSnapMarker(const GenTime & currTime) {
     else return m_snapMarkers[it-1].time();
 }
 
-GenTime DocClipBase::findNextSnapMarker(const GenTime & currTime) {
+GenTime DocClipBase::findNextSnapMarker(const GenTime & currTime)
+{
     int it;
     for (it = 0; it < m_snapMarkers.count(); it++) {
         if (m_snapMarkers[it].time() > currTime)
@@ -371,7 +391,8 @@ GenTime DocClipBase::findNextSnapMarker(const GenTime & currTime) {
     return duration();
 }
 
-QString DocClipBase::markerComment(GenTime t) {
+QString DocClipBase::markerComment(GenTime t)
+{
     QList < CommentedTime >::Iterator itt = m_snapMarkers.begin();
 
     while (itt != m_snapMarkers.end()) {
@@ -379,21 +400,42 @@ QString DocClipBase::markerComment(GenTime t) {
             return (*itt).comment();
         ++itt;
     }
-    return QString::null;
+    return QString();
 }
 
-void DocClipBase::deleteProducers() {
+void DocClipBase::deleteProducers()
+{
     qDeleteAll(m_baseTrackProducers);
     m_baseTrackProducers.clear();
     if (m_thumbProd) m_thumbProd->clearProducer();
+    qDeleteAll(m_audioTrackProducers);
+    m_audioTrackProducers.clear();
+    delete m_videoOnlyProducer;
+    m_videoOnlyProducer = NULL;
 }
 
-void DocClipBase::setProducer(Mlt::Producer *producer) {
+void DocClipBase::setProducer(Mlt::Producer *producer)
+{
     if (producer == NULL) return;
     QString id = producer->get("id");
     if (id.contains('_')) {
         // this is a subtrack producer, insert it at correct place
-        int pos = id.section('_', 1, 1).toInt();
+        id = id.section('_', 1);
+        if (id.endsWith("audio")) {
+            int pos = id.section('_', 0, 0).toInt();
+            if (pos >= m_audioTrackProducers.count()) {
+                while (m_audioTrackProducers.count() - 1 < pos) {
+                    m_audioTrackProducers.append(NULL);
+                }
+            }
+            if (m_audioTrackProducers.at(pos) == NULL) m_audioTrackProducers[pos] = producer;
+            return;
+        }
+        if (id.endsWith("video")) {
+            m_videoOnlyProducer = producer;
+            return;
+        }
+        int pos = id.toInt();
         if (pos >= m_baseTrackProducers.count()) {
             while (m_baseTrackProducers.count() - 1 < pos) {
                 m_baseTrackProducers.append(NULL);
@@ -409,13 +451,53 @@ void DocClipBase::setProducer(Mlt::Producer *producer) {
     if (m_thumbProd && !m_thumbProd->hasProducer()) m_thumbProd->setProducer(producer);
 }
 
-Mlt::Producer *DocClipBase::producer(int track) {
+Mlt::Producer *DocClipBase::audioProducer(int track)
+{
+    if (m_audioTrackProducers.count() <= track) {
+        while (m_audioTrackProducers.count() - 1 < track) {
+            m_audioTrackProducers.append(NULL);
+        }
+    }
+    if (m_audioTrackProducers.at(track) == NULL) {
+        Mlt::Producer *base = producer();
+        m_audioTrackProducers[track] = new Mlt::Producer(*(base->profile()), base->get("resource"));
+        if (m_properties.contains("force_aspect_ratio")) m_audioTrackProducers.at(track)->set("force_aspect_ratio", m_properties.value("force_aspect_ratio").toDouble());
+        if (m_properties.contains("threads")) m_audioTrackProducers.at(track)->set("threads", m_properties.value("threads").toInt());
+        m_audioTrackProducers.at(track)->set("video_index", -1);
+        if (m_properties.contains("audio_index")) m_audioTrackProducers.at(track)->set("audio_index", m_properties.value("audio_index").toInt());
+        char *tmp = (char *) qstrdup(QString(getId() + '_' + QString::number(track) + "_audio").toUtf8().data());
+        m_audioTrackProducers.at(track)->set("id", tmp);
+        delete[] tmp;
+    }
+    return m_audioTrackProducers.at(track);
+}
+
+Mlt::Producer *DocClipBase::videoProducer()
+{
+    if (m_videoOnlyProducer == NULL) {
+        int i;
+        for (i = 0; i < m_baseTrackProducers.count(); i++)
+            if (m_baseTrackProducers.at(i) != NULL) break;
+        if (i >= m_baseTrackProducers.count()) return NULL;
+        m_videoOnlyProducer = new Mlt::Producer(*m_baseTrackProducers.at(i)->profile(), m_baseTrackProducers.at(i)->get("resource"));
+        if (m_properties.contains("force_aspect_ratio")) m_videoOnlyProducer->set("force_aspect_ratio", m_properties.value("force_aspect_ratio").toDouble());
+        if (m_properties.contains("threads")) m_videoOnlyProducer->set("threads", m_properties.value("threads").toInt());
+        m_videoOnlyProducer->set("audio_index", -1);
+        if (m_properties.contains("video_index")) m_videoOnlyProducer->set("video_index", m_properties.value("video_index").toInt());
+        char *tmp = (char *) qstrdup(QString(getId() + "_video").toUtf8().data());
+        m_videoOnlyProducer->set("id", tmp);
+        delete[] tmp;
+    }
+    return m_videoOnlyProducer;
+}
+
+Mlt::Producer *DocClipBase::producer(int track)
+{
     /*for (int i = 0; i < m_baseTrackProducers.count(); i++) {
         if (m_baseTrackProducers.at(i)) kDebug() << "// PROD: " << i << ", ID: " << m_baseTrackProducers.at(i)->get("id");
     }*/
     if (track == -1 || (m_clipType != AUDIO && m_clipType != AV)) {
         if (m_baseTrackProducers.count() == 0) return NULL;
-        int i;
         for (int i = 0; i < m_baseTrackProducers.count(); i++) {
             if (m_baseTrackProducers.at(i) != NULL)
                 return m_baseTrackProducers.at(i);
@@ -431,8 +513,13 @@ Mlt::Producer *DocClipBase::producer(int track) {
         int i;
         for (i = 0; i < m_baseTrackProducers.count(); i++)
             if (m_baseTrackProducers.at(i) != NULL) break;
+
         if (i >= m_baseTrackProducers.count()) return NULL;
         m_baseTrackProducers[track] = new Mlt::Producer(*m_baseTrackProducers.at(i)->profile(), m_baseTrackProducers.at(i)->get("resource"));
+
+        // special case for placeholder clips
+        if (m_baseTrackProducers[track] == NULL) return NULL;
+
         if (m_properties.contains("force_aspect_ratio")) m_baseTrackProducers[track]->set("force_aspect_ratio", m_properties.value("force_aspect_ratio").toDouble());
         if (m_properties.contains("threads")) m_baseTrackProducers[track]->set("threads", m_properties.value("threads").toInt());
         if (m_properties.contains("video_index")) m_baseTrackProducers[track]->set("video_index", m_properties.value("video_index").toInt());
@@ -448,21 +535,24 @@ Mlt::Producer *DocClipBase::producer(int track) {
     return m_baseTrackProducers.at(track);
 }
 
-void DocClipBase::setProducerProperty(const char *name, int data) {
+void DocClipBase::setProducerProperty(const char *name, int data)
+{
     for (int i = 0; i < m_baseTrackProducers.count(); i++) {
         if (m_baseTrackProducers.at(i) != NULL)
             m_baseTrackProducers[i]->set(name, data);
     }
 }
 
-void DocClipBase::setProducerProperty(const char *name, const char *data) {
+void DocClipBase::setProducerProperty(const char *name, const char *data)
+{
     for (int i = 0; i < m_baseTrackProducers.count(); i++) {
         if (m_baseTrackProducers.at(i) != NULL)
             m_baseTrackProducers[i]->set(name, data);
     }
 }
 
-const char *DocClipBase::producerProperty(const char *name) const {
+const char *DocClipBase::producerProperty(const char *name) const
+{
     for (int i = 0; i < m_baseTrackProducers.count(); i++) {
         if (m_baseTrackProducers.at(i) != NULL) {
             return m_baseTrackProducers.at(i)->get(name);
@@ -472,7 +562,8 @@ const char *DocClipBase::producerProperty(const char *name) const {
 }
 
 
-void DocClipBase::slotRefreshProducer() {
+void DocClipBase::slotRefreshProducer()
+{
     if (m_baseTrackProducers.count() == 0) return;
     kDebug() << "////////////   REFRESH CLIP !!!!!!!!!!!!!!!!";
     if (m_clipType == SLIDESHOW) {
@@ -491,21 +582,21 @@ void DocClipBase::slotRefreshProducer() {
             int ct = 0;
             Mlt::Filter *filter = clipService.filter(ct);
             while (filter) {
-                if (filter->get("mlt_service") == "luma") {
+                if (strcmp(filter->get("mlt_service"), "luma") == 0) {
                     break;
                 }
                 ct++;
                 filter = clipService.filter(ct);
             }
 
-            if (filter && filter->get("mlt_service") == "luma") {
+            if (filter && strcmp(filter->get("mlt_service"), "luma") == 0) {
                 filter->set("period", getProperty("ttl").toInt() - 1);
                 filter->set("luma.out", getProperty("luma_duration").toInt());
                 QString resource = getProperty("luma_file");
                 char *tmp = (char *) qstrdup(resource.toUtf8().data());
                 filter->set("luma.resource", tmp);
                 delete[] tmp;
-                if (getProperty("softness") != QString()) {
+                if (!getProperty("softness").isEmpty()) {
                     int soft = getProperty("softness").toInt();
                     filter->set("luma.softness", (double) soft / 100.0);
                 }
@@ -518,7 +609,7 @@ void DocClipBase::slotRefreshProducer() {
                 char *tmp = (char *) qstrdup(resource.toUtf8().data());
                 filter->set("luma.resource", tmp);
                 delete[] tmp;
-                if (getProperty("softness") != QString()) {
+                if (!getProperty("softness").isEmpty()) {
                     int soft = getProperty("softness").toInt();
                     filter->set("luma.softness", (double) soft / 100.0);
                 }
@@ -530,7 +621,7 @@ void DocClipBase::slotRefreshProducer() {
             int ct = 0;
             Mlt::Filter *filter = clipService.filter(0);
             while (filter) {
-                if (filter->get("mlt_service") == "luma") {
+                if (strcmp(filter->get("mlt_service"), "luma") == 0) {
                     clipService.detach(*filter);
                 } else ct++;
                 filter = clipService.filter(ct);
@@ -539,7 +630,8 @@ void DocClipBase::slotRefreshProducer() {
     }
 }
 
-void DocClipBase::setProperties(QMap <QString, QString> properties) {
+void DocClipBase::setProperties(QMap <QString, QString> properties)
+{
     // changing clip type is not allowed
     properties.remove("type");
     QMapIterator<QString, QString> i(properties);
@@ -554,19 +646,23 @@ void DocClipBase::setProperties(QMap <QString, QString> properties) {
     if (refreshProducer) slotRefreshProducer();
 }
 
-void DocClipBase::setMetadata(QMap <QString, QString> properties) {
+void DocClipBase::setMetadata(QMap <QString, QString> properties)
+{
     m_metadata = properties;
 }
 
-QMap <QString, QString> DocClipBase::metadata() const {
+QMap <QString, QString> DocClipBase::metadata() const
+{
     return m_metadata;
 }
 
-void DocClipBase::clearProperty(const QString &key) {
+void DocClipBase::clearProperty(const QString &key)
+{
     m_properties.remove(key);
 }
 
-void DocClipBase::getFileHash(const QString &url) {
+void DocClipBase::getFileHash(const QString url)
+{
     if (m_clipType == SLIDESHOW) return;
     QFile file(url);
     if (file.open(QIODevice::ReadOnly)) { // write size and hash only if resource points to a file
@@ -591,7 +687,8 @@ void DocClipBase::getFileHash(const QString &url) {
     }
 }
 
-QString DocClipBase::getClipHash() const {
+QString DocClipBase::getClipHash() const
+{
     QString hash;
     if (m_clipType == SLIDESHOW) hash = QCryptographicHash::hash(m_properties.value("resource").toAscii().data(), QCryptographicHash::Md5).toHex();
     else if (m_clipType == COLOR) hash = QCryptographicHash::hash(m_properties.value("colour").toAscii().data(), QCryptographicHash::Md5).toHex();
@@ -599,11 +696,13 @@ QString DocClipBase::getClipHash() const {
     return hash;
 }
 
-void DocClipBase::refreshThumbUrl() {
+void DocClipBase::refreshThumbUrl()
+{
     if (m_thumbProd) m_thumbProd->updateThumbUrl(m_properties.value("file_hash"));
 }
 
-void DocClipBase::setProperty(const QString &key, const QString &value) {
+void DocClipBase::setProperty(const QString &key, const QString &value)
+{
     m_properties.insert(key, value);
     if (key == "resource") {
         getFileHash(value);
@@ -639,11 +738,13 @@ void DocClipBase::setProperty(const QString &key, const QString &value) {
     }
 }
 
-QMap <QString, QString> DocClipBase::properties() const {
+QMap <QString, QString> DocClipBase::properties() const
+{
     return m_properties;
 }
 
-bool DocClipBase::slotGetAudioThumbs() {
+bool DocClipBase::slotGetAudioThumbs()
+{
     if (m_thumbProd == NULL) return false;
     if (!KdenliveSettings::audiothumbnails()) {
         if (m_audioTimer != NULL) m_audioTimer->stop();
@@ -660,5 +761,8 @@ bool DocClipBase::slotGetAudioThumbs() {
     return true;
 }
 
-
+bool DocClipBase::isPlaceHolder() const
+{
+    return m_placeHolder;
+}
 
