@@ -17,16 +17,18 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
-#include "QApplication"
-#include "QMouseEvent"
-#include <QMenu>
-
-#include "KDebug"
 
 #include "effectslistwidget.h"
 #include "effectslist.h"
 #include "mainwindow.h"
 
+#include "KDebug"
+
+#include "QApplication"
+#include "QMouseEvent"
+#include <QMenu>
+
+
 static const int EFFECT_VIDEO = 1;
 static const int EFFECT_AUDIO = 2;
 static const int EFFECT_CUSTOM = 3;
@@ -34,8 +36,10 @@ static const int EFFECT_CUSTOM = 3;
 const int TypeRole = Qt::UserRole;
 const int IdRole = TypeRole + 1;
 
-EffectsListWidget::EffectsListWidget(QMenu *menu, QWidget *parent)
-        : KListWidget(parent), m_menu(menu) {
+EffectsListWidget::EffectsListWidget(QMenu *menu, QWidget *parent) :
+        KListWidget(parent),
+        m_menu(menu)
+{
     //setSelectionMode(QAbstractItemView::ExtendedSelection);
     //setDragDropMode(QAbstractItemView::DragDrop);
     setDropIndicatorShown(true);
@@ -46,10 +50,12 @@ EffectsListWidget::EffectsListWidget(QMenu *menu, QWidget *parent)
     initList();
 }
 
-EffectsListWidget::~EffectsListWidget() {
+EffectsListWidget::~EffectsListWidget()
+{
 }
 
-void EffectsListWidget::initList() {
+void EffectsListWidget::initList()
+{
     clear();
     QListWidgetItem *item;
     QString effectName;
@@ -87,11 +93,13 @@ void EffectsListWidget::initList() {
     }
 }
 
-QDomElement EffectsListWidget::currentEffect() {
+QDomElement EffectsListWidget::currentEffect()
+{
     return itemEffect(currentItem());
 }
 
-QDomElement EffectsListWidget::itemEffect(QListWidgetItem *item) {
+QDomElement EffectsListWidget::itemEffect(QListWidgetItem *item)
+{
     QDomElement effect;
     if (!item) return effect;
     QStringList effectInfo = item->data(IdRole).toStringList();
@@ -111,7 +119,8 @@ QDomElement EffectsListWidget::itemEffect(QListWidgetItem *item) {
 }
 
 
-QString EffectsListWidget::currentInfo() {
+QString EffectsListWidget::currentInfo()
+{
     QListWidgetItem *item = currentItem();
     if (!item) return QString();
     QString info;
@@ -131,16 +140,18 @@ QString EffectsListWidget::currentInfo() {
 }
 
 // virtual
-void EffectsListWidget::mousePressEvent(QMouseEvent *event) {
+void EffectsListWidget::mousePressEvent(QMouseEvent *event)
+{
     if (event->button() == Qt::LeftButton) {
-        this->m_DragStartPosition = event->pos();
+        m_DragStartPosition = event->pos();
         m_dragStarted = true;
     }
     KListWidget::mousePressEvent(event);
 }
 
 // virtual
-void EffectsListWidget::mouseMoveEvent(QMouseEvent *event) {
+void EffectsListWidget::mouseMoveEvent(QMouseEvent *event)
+{
     if (!m_dragStarted) return;
     if ((event->pos() - m_DragStartPosition).manhattanLength()
             < QApplication::startDragDistance())
@@ -170,7 +181,8 @@ void EffectsListWidget::mouseMoveEvent(QMouseEvent *event) {
     }
 }
 
-void EffectsListWidget::dragMoveEvent(QDragMoveEvent * event) {
+void EffectsListWidget::dragMoveEvent(QDragMoveEvent * event)
+{
     event->setDropAction(Qt::IgnoreAction);
     //if (item) {
     event->setDropAction(Qt::MoveAction);
@@ -181,7 +193,8 @@ void EffectsListWidget::dragMoveEvent(QDragMoveEvent * event) {
 }
 
 //virtual
-void EffectsListWidget::contextMenuEvent(QContextMenuEvent * event) {
+void EffectsListWidget::contextMenuEvent(QContextMenuEvent * event)
+{
     QListWidgetItem *item = itemAt(event->pos());
     if (item && item->data(TypeRole).toInt() == EFFECT_CUSTOM) m_menu->popup(event->globalPos());
 }
