@@ -15,16 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <QVBoxLayout>
-#include <QSlider>
-#include <QLabel>
-#include <QPushButton>
-#include <QCheckBox>
-#include <QScrollArea>
-
-#include <KDebug>
-#include <KLocale>
-
+#include "effectstackedit.h"
 #include "ui_constval_ui.h"
 #include "ui_listval_ui.h"
 #include "ui_boolval_ui.h"
@@ -32,14 +23,46 @@
 #include "ui_positionval_ui.h"
 #include "ui_wipeval_ui.h"
 #include "complexparameter.h"
-#include "effectstackedit.h"
 #include "geometryval.h"
-
 #include "kdenlivesettings.h"
 
+#include <KDebug>
+#include <KLocale>
+
+#include <QVBoxLayout>
+#include <QSlider>
+#include <QLabel>
+#include <QPushButton>
+#include <QCheckBox>
+#include <QScrollArea>
+
+
+class Boolval: public EffectStackEdit::UiItem, public Ui::Boolval_UI {
+};
+
+class Colorval: public EffectStackEdit::UiItem, public Ui::Colorval_UI {
+};
+
+class Constval: public EffectStackEdit::UiItem, public Ui::Constval_UI {
+};
+
+class Listval: public EffectStackEdit::UiItem, public Ui::Listval_UI {
+};
+
+class Positionval: public EffectStackEdit::UiItem, public Ui::Positionval_UI {
+};
+
+class Wipeval: public EffectStackEdit::UiItem, public Ui::Wipeval_UI {
+};
+
+
 QMap<QString, QImage> EffectStackEdit::iconCache;
 
-EffectStackEdit::EffectStackEdit(QWidget *parent): QWidget(parent), m_in(0), m_out(0) {
+EffectStackEdit::EffectStackEdit(QWidget *parent) :
+        QWidget(parent),
+        m_in(0),
+        m_out(0)
+{
     setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding));
     QVBoxLayout *vbox1 = new QVBoxLayout(parent);
     vbox1->setContentsMargins(0, 0, 0, 0);
@@ -55,35 +78,43 @@ EffectStackEdit::EffectStackEdit(QWidget *parent): QWidget(parent), m_in(0), m_o
     vbox1->addWidget(area);
     area->setWidget(wid);
     area->setWidgetResizable(true);
-    vbox = new QVBoxLayout(wid);
-    vbox->setContentsMargins(0, 0, 0, 0);
-    vbox->setSpacing(0);
+    m_vbox = new QVBoxLayout(wid);
+    m_vbox->setContentsMargins(0, 0, 0, 0);
+    m_vbox->setSpacing(0);
     wid->show();
 
 }
 
-EffectStackEdit::~EffectStackEdit() {
+EffectStackEdit::~EffectStackEdit()
+{
     iconCache.clear();
 }
 
-void EffectStackEdit::updateProjectFormat(MltVideoProfile profile, Timecode t) {
+void EffectStackEdit::updateProjectFormat(MltVideoProfile profile, Timecode t)
+{
     m_profile = profile;
     m_timecode = t;
 }
 
-void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out) {
+void EffectStackEdit::updateParameter(const QString &name, const QString &value)
+{
+    m_params.setAttribute(name, value);
+}
+
+void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out)
+{
     kDebug() << "in";
-    params = d;
+    m_params = d;
     m_in = in;
     m_out = out;
     clearAllItems();
-    if (params.isNull()) return;
+    if (m_params.isNull()) return;
 
     QDomDocument doc;
-    doc.appendChild(doc.importNode(params, true));
+    doc.appendChild(doc.importNode(m_params, true));
     //kDebug() << "IMPORTED TRANS: " << doc.toString();
-    QDomNodeList namenode = params.elementsByTagName("parameter");
-    QDomElement e = params.toElement();
+    QDomNodeList namenode = m_params.elementsByTagName("parameter");
+    QDomElement e = m_params.toElement();
     const int minFrame = e.attribute("start").toInt();
     const int maxFrame = e.attribute("end").toInt();
 
@@ -114,45 +145,44 @@ void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out) {
             delete toFillin;
             toFillin = NULL;
         } else if (type == "list") {
-            Ui::Listval_UI *lsval = new Ui::Listval_UI;
+            Listval *lsval = new Listval;
             lsval->setupUi(toFillin);
-            QStringList listitems = pa.attribute("paramlist").split(",");
-            QStringList listitemsdisplay = pa.attribute("paramlistdisplay").split(",");
+            QStringList listitems = pa.attribute("paramlist").split(',');
+            QStringList listitemsdisplay = pa.attribute("paramlistdisplay").split(',');
             if (listitemsdisplay.count() != listitems.count()) listitemsdisplay = listitems;
             //lsval->list->addItems(listitems);
+            lsval->list->setIconSize(QSize(30, 30));
             for (int i = 0;i < listitems.count();i++) {
                 lsval->list->addItem(listitemsdisplay.at(i), listitems.at(i));
-            }
-            lsval->list->setCurrentIndex(listitems.indexOf(value));
-            for (int i = 0;i < lsval->list->count();i++) {
-                QString entry = lsval->list->itemData(i).toString();
+                QString entry = listitems.at(i);
                 if (!entry.isEmpty() && (entry.endsWith(".png") || entry.endsWith(".pgm"))) {
                     if (!EffectStackEdit::iconCache.contains(entry)) {
                         QImage pix(entry);
                         EffectStackEdit::iconCache[entry] = pix.scaled(30, 30);
                     }
-                    lsval->list->setIconSize(QSize(30, 30));
                     lsval->list->setItemIcon(i, QPixmap::fromImage(iconCache[entry]));
                 }
             }
+            if (!value.isEmpty()) lsval->list->setCurrentIndex(listitems.indexOf(value));
+
             connect(lsval->list, SIGNAL(currentIndexChanged(int)) , this, SLOT(collectAllParameters()));
             lsval->title->setTitle(paramName);
-            valueItems[paramName] = lsval;
-            uiItems.append(lsval);
+            m_valueItems[paramName] = lsval;
+            m_uiItems.append(lsval);
         } else if (type == "bool") {
-            Ui::Boolval_UI *bval = new Ui::Boolval_UI;
+            Boolval *bval = new Boolval;
             bval->setupUi(toFillin);
             bval->checkBox->setCheckState(value == "0" ? Qt::Unchecked : Qt::Checked);
 
             connect(bval->checkBox, SIGNAL(stateChanged(int)) , this, SLOT(collectAllParameters()));
             bval->checkBox->setText(paramName);
-            valueItems[paramName] = bval;
-            uiItems.append(bval);
+            m_valueItems[paramName] = bval;
+            m_uiItems.append(bval);
         } else if (type == "complex") {
-            /*QStringList names=nodeAtts.namedItem("name").nodeValue().split(";");
-            QStringList max=nodeAtts.namedItem("max").nodeValue().split(";");
-            QStringList min=nodeAtts.namedItem("min").nodeValue().split(";");
-            QStringList val=value.split(";");
+            /*QStringList names=nodeAtts.namedItem("name").nodeValue().split(';');
+            QStringList max=nodeAtts.namedItem("max").nodeValue().split(';');
+            QStringList min=nodeAtts.namedItem("min").nodeValue().split(';');
+            QStringList val=value.split(';');
             kDebug() << "in complex"<<names.size() << " " << max.size() << " " << min.size() << " " << val.size()  ;
             if ( (names.size() == max.size() ) &&
                  (names.size()== min.size()) &&
@@ -165,19 +195,19 @@ void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out) {
             ComplexParameter *pl = new ComplexParameter;
             connect(pl, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
             pl->setupParam(d, pa.attribute("name"), 0, 100);
-            vbox->addWidget(pl);
-            valueItems[paramName+"complex"] = pl;
-            items.append(pl);
+            m_vbox->addWidget(pl);
+            m_valueItems[paramName+"complex"] = pl;
+            m_items.append(pl);
         } else if (type == "geometry") {
             Geometryval *geo = new Geometryval(m_profile);
             connect(geo, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
             connect(geo, SIGNAL(seekToPos(int)), this, SLOT(slotSeekToPos(int)));
             geo->setupParam(pa, minFrame, maxFrame);
-            vbox->addWidget(geo);
-            valueItems[paramName+"geometry"] = geo;
-            items.append(geo);
+            m_vbox->addWidget(geo);
+            m_valueItems[paramName+"geometry"] = geo;
+            m_items.append(geo);
         } else if (type == "color") {
-            Ui::Colorval_UI *cval = new Ui::Colorval_UI;
+            Colorval *cval = new Colorval;
             cval->setupUi(toFillin);
             bool ok;
             cval->kcolorbutton->setColor(value.toUInt(&ok, 16));
@@ -185,25 +215,25 @@ void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out) {
 
             connect(cval->kcolorbutton, SIGNAL(clicked()) , this, SLOT(collectAllParameters()));
             cval->label->setText(paramName);
-            valueItems[paramName] = cval;
-            uiItems.append(cval);
+            m_valueItems[paramName] = cval;
+            m_uiItems.append(cval);
         } else if (type == "position") {
-            Ui::Positionval_UI *pval = new Ui::Positionval_UI;
+            Positionval *pval = new Positionval;
             pval->setupUi(toFillin);
             int pos = value.toInt();
-            if (d.attribute("id") == "fadein") {
+            if (d.attribute("id") == "fadein" || d.attribute("id") == "fade_from_black") {
                 pos = pos - m_in;
-            } else if (d.attribute("id") == "fadeout") {
+            } else if (d.attribute("id") == "fadeout" || d.attribute("id") == "fade_to_black") {
                 // fadeout position starts from clip end
                 pos = m_out - (pos - m_in);
             }
             pval->krestrictedline->setText(m_timecode.getTimecodeFromFrames(pos));
             connect(pval->krestrictedline, SIGNAL(editingFinished()), this, SLOT(collectAllParameters()));
             pval->label->setText(paramName);
-            valueItems[paramName + "position"] = pval;
-            uiItems.append(pval);
+            m_valueItems[paramName + "position"] = pval;
+            m_uiItems.append(pval);
         } else if (type == "wipe") {
-            Ui::Wipeval_UI *wpval = new Ui::Wipeval_UI;
+            Wipeval *wpval = new Wipeval;
             wpval->setupUi(toFillin);
             wipeInfo w = getWipeInfo(value);
             switch (w.start) {
@@ -256,34 +286,36 @@ void EffectStackEdit::transferParamDesc(const QDomElement& d, int in, int out) {
             connect(wpval->start_transp, SIGNAL(valueChanged(int)), this, SLOT(collectAllParameters()));
             connect(wpval->end_transp, SIGNAL(valueChanged(int)), this, SLOT(collectAllParameters()));
             //wpval->title->setTitle(na.toElement().text());
-            valueItems[paramName] = wpval;
-            uiItems.append(wpval);
+            m_valueItems[paramName] = wpval;
+            m_uiItems.append(wpval);
         } else {
             delete toFillin;
             toFillin = NULL;
         }
 
         if (toFillin) {
-            items.append(toFillin);
-            vbox->addWidget(toFillin);
+            m_items.append(toFillin);
+            m_vbox->addWidget(toFillin);
         }
     }
-    vbox->addStretch();
+    m_vbox->addStretch();
 }
 
-void EffectStackEdit::slotSeekToPos(int pos) {
+void EffectStackEdit::slotSeekToPos(int pos)
+{
     emit seekTimeline(m_in + pos);
 }
 
-wipeInfo EffectStackEdit::getWipeInfo(QString value) {
+wipeInfo EffectStackEdit::getWipeInfo(QString value)
+{
     wipeInfo info;
-    QString start = value.section(";", 0, 0);
-    QString end = value.section(";", 1, 1).section("=", 1, 1);
+    QString start = value.section(';', 0, 0);
+    QString end = value.section(';', 1, 1).section('=', 1, 1);
     if (start.startsWith("-100%,0")) info.start = LEFT;
     else if (start.startsWith("100%,0")) info.start = RIGHT;
     else if (start.startsWith("0%,100%")) info.start = DOWN;
     else if (start.startsWith("0%,-100%")) info.start = UP;
-    else if (start.startsWith("0%,0%")) info.start = CENTER;
+    else info.start = CENTER;
     if (start.count(':') == 2) info.startTransparency = start.section(':', -1).toInt();
     else info.startTransparency = 100;
 
@@ -291,13 +323,14 @@ wipeInfo EffectStackEdit::getWipeInfo(QString value) {
     else if (end.startsWith("100%,0")) info.end = RIGHT;
     else if (end.startsWith("0%,100%")) info.end = DOWN;
     else if (end.startsWith("0%,-100%")) info.end = UP;
-    else if (end.startsWith("0%,0%")) info.end = CENTER;
+    else info.end = CENTER;
     if (end.count(':') == 2) info.endTransparency = end.section(':', -1).toInt();
     else info.endTransparency = 100;
     return info;
 }
 
-QString EffectStackEdit::getWipeString(wipeInfo info) {
+QString EffectStackEdit::getWipeString(wipeInfo info)
+{
 
     QString start;
     QString end;
@@ -318,7 +351,7 @@ QString EffectStackEdit::getWipeString(wipeInfo info) {
         start = "0%,0%:100%x100%";
         break;
     }
-    start.append(":" + QString::number(info.startTransparency));
+    start.append(':' + QString::number(info.startTransparency));
 
     switch (info.end) {
     case LEFT:
@@ -337,13 +370,14 @@ QString EffectStackEdit::getWipeString(wipeInfo info) {
         end = "0%,0%:100%x100%";
         break;
     }
-    end.append(":" + QString::number(info.endTransparency));
+    end.append(':' + QString::number(info.endTransparency));
     return QString(start + ";-1=" + end);
 }
 
-void EffectStackEdit::collectAllParameters() {
-    QDomElement oldparam = params.cloneNode().toElement();
-    QDomNodeList namenode = params.elementsByTagName("parameter");
+void EffectStackEdit::collectAllParameters()
+{
+    QDomElement oldparam = m_params.cloneNode().toElement();
+    QDomNodeList namenode = m_params.elementsByTagName("parameter");
 
     for (int i = 0;i < namenode.count() ;i++) {
         QDomNode pa = namenode.item(i);
@@ -353,34 +387,33 @@ void EffectStackEdit::collectAllParameters() {
 
         QString setValue;
         if (type == "double" || type == "constant") {
-            QSlider* slider = ((Ui::Constval_UI*)valueItems[paramName])->horizontalSlider;
+            QSlider* slider = ((Constval*)m_valueItems[paramName])->horizontalSlider;
             setValue = QString::number(slider->value());
         } else if (type == "list") {
-            KComboBox *box = ((Ui::Listval_UI*)valueItems[paramName])->list;
+            KComboBox *box = ((Listval*)m_valueItems[paramName])->list;
             setValue = box->itemData(box->currentIndex()).toString();
         } else if (type == "bool") {
-            QCheckBox *box = ((Ui::Boolval_UI*)valueItems[paramName])->checkBox;
+            QCheckBox *box = ((Boolval*)m_valueItems[paramName])->checkBox;
             setValue = box->checkState() == Qt::Checked ? "1" : "0" ;
         } else if (type == "color") {
-            KColorButton *color = ((Ui::Colorval_UI*)valueItems[paramName])->kcolorbutton;
+            KColorButton *color = ((Colorval*)m_valueItems[paramName])->kcolorbutton;
             setValue = color->color().name();
-            setValue.replace('#', "0x");
         } else if (type == "complex") {
-            ComplexParameter *complex = ((ComplexParameter*)valueItems[paramName+"complex"]);
+            ComplexParameter *complex = ((ComplexParameter*)m_valueItems[paramName+"complex"]);
             namenode.item(i) = complex->getParamDesc();
         } else if (type == "geometry") {
-            Geometryval *geom = ((Geometryval*)valueItems[paramName+"geometry"]);
+            Geometryval *geom = ((Geometryval*)m_valueItems[paramName+"geometry"]);
             namenode.item(i) = geom->getParamDesc();
         } else if (type == "position") {
-            KRestrictedLine *line = ((Ui::Positionval_UI*)valueItems[paramName+"position"])->krestrictedline;
+            KRestrictedLine *line = ((Positionval*)m_valueItems[paramName+"position"])->krestrictedline;
             int pos = m_timecode.getFrameCount(line->text(), KdenliveSettings::project_fps());
-            if (params.attribute("id") == "fadein") {
+            if (m_params.attribute("id") == "fadein" || m_params.attribute("id") == "fade_from_black") {
                 pos += m_in;
                 if (pos > m_out) {
                     pos = m_out;
                     line->setText(m_timecode.getTimecodeFromFrames(pos));
                 }
-            } else if (params.attribute("id") == "fadeout") {
+            } else if (m_params.attribute("id") == "fadeout" || m_params.attribute("id") == "fade_to_black") {
                 pos = m_out - (pos - m_in);
                 if (pos > m_out - m_in) {
                     pos = m_out - m_in;
@@ -389,19 +422,21 @@ void EffectStackEdit::collectAllParameters() {
             }
             setValue = QString::number(pos);
         } else if (type == "wipe") {
-            Ui::Wipeval_UI *wp = (Ui::Wipeval_UI*)valueItems[paramName];
+            Wipeval *wp = (Wipeval*)m_valueItems[paramName];
             wipeInfo info;
             if (wp->start_left->isChecked()) info.start = LEFT;
             else if (wp->start_right->isChecked()) info.start = RIGHT;
             else if (wp->start_up->isChecked()) info.start = UP;
             else if (wp->start_down->isChecked()) info.start = DOWN;
             else if (wp->start_center->isChecked()) info.start = CENTER;
+            else info.start = LEFT;
             info.startTransparency = wp->start_transp->value();
             if (wp->end_left->isChecked()) info.end = LEFT;
             else if (wp->end_right->isChecked()) info.end = RIGHT;
             else if (wp->end_up->isChecked()) info.end = UP;
             else if (wp->end_down->isChecked()) info.end = DOWN;
             else if (wp->end_center->isChecked()) info.end = CENTER;
+            else info.end = RIGHT;
             info.endTransparency = wp->end_transp->value();
             setValue = getWipeString(info);
         }
@@ -410,12 +445,13 @@ void EffectStackEdit::collectAllParameters() {
             pa.attributes().namedItem("value").setNodeValue(setValue);
         }
     }
-    emit parameterChanged(oldparam, params);
+    emit parameterChanged(oldparam, m_params);
 }
 
-void EffectStackEdit::createSliderItem(const QString& name, int val , int min, int max) {
+void EffectStackEdit::createSliderItem(const QString& name, int val , int min, int max)
+{
     QWidget* toFillin = new QWidget;
-    Ui::Constval_UI *ctval = new Ui::Constval_UI;
+    Constval *ctval = new Constval;
     ctval->setupUi(toFillin);
 
     ctval->horizontalSlider->setMinimum(min);
@@ -425,29 +461,29 @@ void EffectStackEdit::createSliderItem(const QString& name, int val , int min, i
     ctval->horizontalSlider->setPageStep((int)(max - min) / 10);
     ctval->horizontalSlider->setValue(val);
     ctval->label->setText(name);
-    valueItems[name] = ctval;
-    uiItems.append(ctval);
+    m_valueItems[name] = ctval;
+    m_uiItems.append(ctval);
     connect(ctval->horizontalSlider, SIGNAL(valueChanged(int)) , this, SLOT(collectAllParameters()));
-    items.append(toFillin);
-    vbox->addWidget(toFillin);
+    m_items.append(toFillin);
+    m_vbox->addWidget(toFillin);
 }
 
-void EffectStackEdit::slotSliderMoved(int) {
+void EffectStackEdit::slotSliderMoved(int)
+{
     collectAllParameters();
 }
 
-void EffectStackEdit::clearAllItems() {
-    qDeleteAll(items);
-    foreach(void *p, uiItems) {
-        delete p;
-    }
-    uiItems.clear();
-    items.clear();
-    valueItems.clear();
-    QLayoutItem *item = vbox->itemAt(0);
+void EffectStackEdit::clearAllItems()
+{
+    qDeleteAll(m_items);
+    qDeleteAll(m_uiItems);
+    m_uiItems.clear();
+    m_items.clear();
+    m_valueItems.clear();
+    QLayoutItem *item = m_vbox->itemAt(0);
     while (item) {
-        vbox->removeItem(item);
+        m_vbox->removeItem(item);
         delete item;
-        item = vbox->itemAt(0);
+        item = m_vbox->itemAt(0);
     }
 }
