@@ -17,39 +17,51 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
-#include <QMouseEvent>
-#include <QStylePainter>
-#include <QFrame>
-#include <QWidget>
-#include <QPainter>
-#include <QAction>
+
+#include "headertrack.h"
+#include "kdenlivesettings.h"
 
 #include <KIcon>
 #include <KLocale>
 #include <KDebug>
 
-#include "kdenlivesettings.h"
-#include "headertrack.h"
+#include <QMouseEvent>
+#include <QWidget>
+#include <QPainter>
+#include <QAction>
 
-HeaderTrack::HeaderTrack(int index, TrackInfo info, QWidget *parent)
-        : QWidget(parent), m_index(index), m_type(info.type) {
+HeaderTrack::HeaderTrack(int index, TrackInfo info, QWidget *parent) :
+        QWidget(parent),
+        m_index(index),
+        m_type(info.type)
+{
     setFixedHeight(KdenliveSettings::trackheight());
-    view.setupUi(this);
-    view.track_number->setText(QString::number(m_index));
-    view.buttonVideo->setChecked(!info.isBlind);
-    view.buttonAudio->setChecked(!info.isMute);
+    m_view.setupUi(this);
+    m_view.track_number->setText(QString::number(m_index));
+    m_view.buttonVideo->setChecked(!info.isBlind);
+    m_view.buttonVideo->setToolTip(i18n("Hide track"));
+    m_view.buttonAudio->setChecked(!info.isMute);
+    m_view.buttonAudio->setToolTip(i18n("Mute track"));
+    m_view.buttonLock->setChecked(info.isLocked);
+    m_view.buttonLock->setToolTip(i18n("Lock track"));
+
     if (m_type == VIDEOTRACK) {
-        view.frame->setBackgroundRole(QPalette::AlternateBase);
-        view.frame->setAutoFillBackground(true);
-        if (!info.isBlind) view.buttonVideo->setIcon(KIcon("kdenlive-show-video"));
-        else view.buttonVideo->setIcon(KIcon("kdenlive-hide-video"));
+        m_view.frame->setBackgroundRole(QPalette::AlternateBase);
+        m_view.frame->setAutoFillBackground(true);
+        if (!info.isBlind) m_view.buttonVideo->setIcon(KIcon("kdenlive-show-video"));
+        else m_view.buttonVideo->setIcon(KIcon("kdenlive-hide-video"));
     } else {
-        view.buttonVideo->setHidden(true);
+        m_view.buttonVideo->setHidden(true);
     }
-    if (!info.isMute) view.buttonAudio->setIcon(KIcon("kdenlive-show-audio"));
-    else view.buttonAudio->setIcon(KIcon("kdenlive-hide-audio"));
-    connect(view.buttonVideo, SIGNAL(clicked()), this, SLOT(switchVideo()));
-    connect(view.buttonAudio, SIGNAL(clicked()), this, SLOT(switchAudio()));
+    if (!info.isMute) m_view.buttonAudio->setIcon(KIcon("kdenlive-show-audio"));
+    else m_view.buttonAudio->setIcon(KIcon("kdenlive-hide-audio"));
+
+    if (!info.isLocked) m_view.buttonLock->setIcon(KIcon("kdenlive-unlock"));
+    else m_view.buttonLock->setIcon(KIcon("kdenlive-lock"));
+
+    connect(m_view.buttonVideo, SIGNAL(clicked()), this, SLOT(switchVideo()));
+    connect(m_view.buttonAudio, SIGNAL(clicked()), this, SLOT(switchAudio()));
+    connect(m_view.buttonLock, SIGNAL(clicked()), this, SLOT(switchLock()));
 
     m_contextMenu = new QMenu(this);
 
@@ -66,42 +78,66 @@ HeaderTrack::HeaderTrack(int index, TrackInfo info, QWidget *parent)
     connect(changeAction, SIGNAL(triggered()), this, SLOT(slotChangeTrack()));
 }
 
-HeaderTrack::~HeaderTrack() {
-    if (m_contextMenu) delete m_contextMenu;
+HeaderTrack::~HeaderTrack()
+{
+    delete m_contextMenu;
 }
 
-void HeaderTrack::switchVideo() {
-    if (view.buttonVideo->isChecked()) {
-        view.buttonVideo->setIcon(KIcon("kdenlive-show-video"));
+void HeaderTrack::switchVideo()
+{
+    if (m_view.buttonVideo->isChecked()) {
+        m_view.buttonVideo->setIcon(KIcon("kdenlive-show-video"));
     } else {
-        view.buttonVideo->setIcon(KIcon("kdenlive-hide-video"));
+        m_view.buttonVideo->setIcon(KIcon("kdenlive-hide-video"));
     }
     emit switchTrackVideo(m_index);
 }
 
-void HeaderTrack::switchAudio() {
-    if (view.buttonAudio->isChecked()) {
-        view.buttonAudio->setIcon(KIcon("kdenlive-show-audio"));
+void HeaderTrack::switchAudio()
+{
+    if (m_view.buttonAudio->isChecked()) {
+        m_view.buttonAudio->setIcon(KIcon("kdenlive-show-audio"));
     } else {
-        view.buttonAudio->setIcon(KIcon("kdenlive-hide-audio"));
+        m_view.buttonAudio->setIcon(KIcon("kdenlive-hide-audio"));
     }
     emit switchTrackAudio(m_index);
 }
 
-void HeaderTrack::slotDeleteTrack() {
+void HeaderTrack::switchLock(bool emitSignal)
+{
+    if (m_view.buttonLock->isChecked()) {
+        m_view.buttonLock->setIcon(KIcon("kdenlive-lock"));
+    } else {
+        m_view.buttonLock->setIcon(KIcon("kdenlive-unlock"));
+    }
+    if (emitSignal) emit switchTrackLock(m_index);
+}
+
+
+void HeaderTrack::setLock(bool lock)
+{
+    m_view.buttonLock->setChecked(lock);
+    switchLock(false);
+}
+
+void HeaderTrack::slotDeleteTrack()
+{
     emit deleteTrack(m_index);
 }
 
-void HeaderTrack::slotAddTrack() {
+void HeaderTrack::slotAddTrack()
+{
     emit insertTrack(m_index);
 }
 
-void HeaderTrack::slotChangeTrack() {
+void HeaderTrack::slotChangeTrack()
+{
     emit changeTrack(m_index);
 }
 
 // virtual
-void HeaderTrack::contextMenuEvent(QContextMenuEvent * event) {
+void HeaderTrack::contextMenuEvent(QContextMenuEvent * event)
+{
     m_contextMenu->popup(event->globalPos());
 }
 
