@@ -45,7 +45,8 @@ class DocClipBase;
 class MainWindow;
 class TrackInfo;
 
-class KdenliveDoc: public QObject {
+class KdenliveDoc: public QObject
+{
 Q_OBJECT public:
 
     KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup *undoGroup, const QString &profileName, const QPoint tracks, Render *render, MainWindow *parent = 0);
@@ -61,18 +62,14 @@ Q_OBJECT public:
     //void setRenderer(Render *render);
     QUndoStack *commandStack();
     QString producerName(const QString &id);
-    void setProducerDuration(const QString &id, int duration);
-    int getProducerDuration(const QString &id);
     Render *renderer();
-    QDomElement m_guidesXml;
+    QDomDocument m_guidesXml;
     QDomElement guidesXml() const;
     ClipManager *clipManager();
     void addClip(QDomElement elem, QString clipId, bool createClipItem = true);
     void addClipInfo(QDomElement elem, QDomElement orig, QString clipId);
     void slotAddClipFile(const KUrl url, const QString group, const QString &groupId = QString());
     void slotAddClipList(const KUrl::List urls, const QString group, const QString &groupId = QString());
-    void slotAddColorClipFile(const QString name, const QString color, QString duration, const QString group, const QString &groupId = QString());
-    void slotAddSlideshowClipFile(const QString name, const QString path, int count, const QString duration, const bool loop, const bool fade, const QString &luma_duration, const QString &luma_file, const int softness, const QString group, const QString &groupId = QString());
     void deleteClip(const QString &clipId);
     int getFramePos(QString duration);
     DocClipBase *getBaseClip(const QString &clipId);
@@ -80,12 +77,12 @@ Q_OBJECT public:
     void deleteProjectClip(QList <QString> ids);
     /** Inform application of the audio thumbnails generation progress */
     void setThumbsProgress(const QString &message, int progress);
-    QString profilePath() const;
+    const QString &profilePath() const;
     MltVideoProfile mltProfile() const;
-    QString description() const;
+    const QString description() const;
     void setUrl(KUrl url);
     void setProfilePath(QString path);
-    const QString &getFreeClipId();
+    const QString getFreeClipId();
     /** does the document need saving */
     bool isModified() const;
     /** Returns project folder, used to store project files (titles, effects,...) */
@@ -95,9 +92,9 @@ Q_OBJECT public:
     void syncGuides(QList <Guide *> guides);
     void setZoom(int factor);
     int zoom() const;
-    const double dar();
+    double dar();
     double projectDuration() const;
-    bool saveSceneList(const QString &path, QDomDocument sceneList);
+    bool saveSceneList(const QString &path, const QString &scene);
     int tracksCount() const;
     TrackInfo trackInfoAt(int ix) const;
     void insertTrack(int ix, TrackInfo type);
@@ -105,9 +102,9 @@ Q_OBJECT public:
     void setTrackType(int ix, TrackInfo type);
     const QList <TrackInfo> tracksList() const;
     QPoint getTracksCount() const;
-    QString getTracksInfo() const;
     void switchTrackVideo(int ix, bool hide);
     void switchTrackAudio(int ix, bool hide);
+    void switchTrackLock(int ix, bool lock);
     void cachePixmap(const QString &fileId, const QPixmap &pix) const;
     void setProjectFolder(KUrl url);
     QString getLadspaFile() const;
@@ -115,11 +112,11 @@ Q_OBJECT public:
     QPoint zone() const;
     void setSceneList();
     void updatePreviewSettings();
+    bool isTrackLocked(int ix) const;
 
 private:
     KUrl m_url;
     QDomDocument m_document;
-    QString m_projectName;
     double m_fps;
     int m_zoom;
     /** Cursor position at document opening */
@@ -129,7 +126,6 @@ private:
     Timecode m_timecode;
     Render *m_render;
     QUndoStack *m_commandStack;
-    QDomDocument generateSceneList();
     ClipManager *m_clipManager;
     MltVideoProfile m_profile;
     QTimer *m_autoSaveTimer;
@@ -149,7 +145,7 @@ private:
     bool convertDocument(double version);
     QDomDocument createEmptyDocument(const int videotracks, const int audiotracks);
     QString colorToString(const QColor& c);
-    void checkProjectClips();
+
     void setNewClipResource(const QString &id, const QString &path);
     QString searchFileRecursively(const QDir &dir, const QString &matchSize, const QString &matchHash) const;
     void moveProjectData(KUrl url);
@@ -158,6 +154,7 @@ public slots:
     void slotCreateTextClip(QString group, const QString &groupId);
     /** Set to true if document needs saving, false otherwise */
     void setModified(bool mod = true);
+    void checkProjectClips();
 
 private slots:
     void slotAutoSave();
@@ -169,7 +166,7 @@ signals:
     void updateClipDisplay(const QString&);
     void deleteTimelineClip(const QString&);
     void progressInfo(const QString &, int);
-    /** emited when the document state has been modified (= needs saving or not) */
+    /** emitted when the document state has been modified (= needs saving or not) */
     void docModified(bool);
     void selectLastAddedClip(const QString &);
     void guidesUpdated();
