@@ -17,13 +17,19 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
-#include <QDir>
-#include <QTimer>
+#include "kdenlivesettingsdialog.h"
+#include "profilesdialog.h"
+#include "kdenlivesettings.h"
 
 #include <KStandardDirs>
 #include <KDebug>
 #include <kopenwithdialog.h>
 #include <KConfigDialogManager>
+#include <kde_file.h>
+#include <KIO/NetAccess>
+
+#include <QDir>
+#include <QTimer>
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -33,22 +39,21 @@
 #include <linux/input.h>
 #endif /* NO_JOGSHUTTLE */
 
-#include "profilesdialog.h"
-#include "kdenlivesettings.h"
-#include "kdenlivesettingsdialog.h"
 
-KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent): KConfigDialog(parent, "settings", KdenliveSettings::self()) {
+KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent) :
+        KConfigDialog(parent, "settings", KdenliveSettings::self())
+{
 
     QWidget *p1 = new QWidget;
     m_configMisc.setupUi(p1);
-    page1 = addPage(p1, i18n("Misc"), "configure");
+    m_page1 = addPage(p1, i18n("Misc"), "configure");
 
     // Hide multi tab option until Kdenlive really supports it
     m_configMisc.kcfg_activatetabs->setVisible(false);
 
     QWidget *p3 = new QWidget;
     m_configDisplay.setupUi(p3);
-    page3 = addPage(p3, i18n("Display"), "display");
+    m_page3 = addPage(p3, i18n("Display"), "video-display");
 
     QWidget *p2 = new QWidget;
     m_configEnv.setupUi(p2);
@@ -61,11 +66,11 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent): KConfigDialog(
     m_configEnv.projecturl->lineEdit()->setObjectName("kcfg_defaultprojectfolder");
     m_configEnv.capturefolderurl->setMode(KFile::Directory);
     m_configEnv.capturefolderurl->lineEdit()->setObjectName("kcfg_capturefolder");
-    page2 = addPage(p2, i18n("Environment"), "terminal");
+    m_page2 = addPage(p2, i18n("Environment"), "terminal");
 
     QWidget *p4 = new QWidget;
     m_configCapture.setupUi(p4);
-    page4 = addPage(p4, i18n("Capture"), "audio-card");
+    m_page4 = addPage(p4, i18n("Capture"), "audio-card");
     m_configCapture.tabWidget->setCurrentIndex(KdenliveSettings::defaultcapture());
 
     QWidget *p5 = new QWidget;
@@ -79,11 +84,11 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent): KConfigDialog(
     m_configShuttle.kcfg_enableshuttle->hide();
     m_configShuttle.kcfg_enableshuttle->setDisabled(true);
 #endif /* NO_JOGSHUTTLE */
-    page5 = addPage(p5, i18n("JogShuttle"), "input-mouse");
+    m_page5 = addPage(p5, i18n("JogShuttle"), "input-mouse");
 
     QWidget *p6 = new QWidget;
     m_configSdl.setupUi(p6);
-    page6 = addPage(p6, i18n("Playback"), "audio-card");
+    m_page6 = addPage(p6, i18n("Playback"), "audio-card");
 
     QStringList actions;
     actions << i18n("Do nothing");
@@ -110,17 +115,11 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent): KConfigDialog(
     connect(m_configEnv.kp_audio, SIGNAL(clicked()), this, SLOT(slotEditAudioApplication()));
     connect(m_configEnv.kp_player, SIGNAL(clicked()), this, SLOT(slotEditVideoApplication()));
 
-    QMap <QString, QString> profilesInfo = ProfilesDialog::getProfilesInfo();
-    QMapIterator<QString, QString> i(profilesInfo);
-    while (i.hasNext()) {
-        i.next();
-        m_configMisc.kcfg_profiles_list->addItem(i.key(), i.value());
-    }
-
     checkProfile();
 
     slotUpdateDisplay();
 
+    connect(m_configSdl.kcfg_audio_driver, SIGNAL(currentIndexChanged(int)), this, SLOT(slotCheckAlsaDriver()));
     initDevices();
     connect(m_configMisc.kcfg_profiles_list, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateDisplay()));
     connect(m_configCapture.kcfg_rmd_capture_type, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateRmdRegionStatus()));
@@ -149,7 +148,7 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent): KConfigDialog(
 
             kDebug() << "// FOUND DVGRAB VERSION: " << dvgrabVersion;
         }
-        if (versionCheck) delete versionCheck;
+        delete versionCheck;
         if (dvgrabVersion < 3.3) {
             KdenliveSettings::setFirewiretimestamp(false);
             m_configCapture.kcfg_firewiretimestamp->setEnabled(false);
@@ -167,11 +166,21 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent): KConfigDialog(
 
 KdenliveSettingsDialog::~KdenliveSettingsDialog() {}
 
-void KdenliveSettingsDialog::slotUpdateRmdRegionStatus() {
+void KdenliveSettingsDialog::slotUpdateRmdRegionStatus()
+{
     m_configCapture.region_group->setHidden(m_configCapture.kcfg_rmd_capture_type->currentIndex() != 1);
 }
 
-void KdenliveSettingsDialog::checkProfile() {
+void KdenliveSettingsDialog::checkProfile()
+{
+    m_configMisc.kcfg_profiles_list->clear();
+    QMap <QString, QString> profilesInfo = ProfilesDialog::getProfilesInfo();
+    QMapIterator<QString, QString> i(profilesInfo);
+    while (i.hasNext()) {
+        i.next();
+        m_configMisc.kcfg_profiles_list->addItem(i.key(), i.value());
+    }
+
     if (!KdenliveSettings::default_profile().isEmpty()) {
         for (int i = 0; i < m_configMisc.kcfg_profiles_list->count(); i++) {
             if (m_configMisc.kcfg_profiles_list->itemData(i).toString() == KdenliveSettings::default_profile()) {
@@ -183,7 +192,8 @@ void KdenliveSettingsDialog::checkProfile() {
     }
 }
 
-void KdenliveSettingsDialog::initDevices() {
+void KdenliveSettingsDialog::initDevices()
+{
     // Fill audio drivers
     m_configSdl.kcfg_audio_driver->addItem(i18n("Automatic"), QString());
     m_configSdl.kcfg_audio_driver->addItem(i18n("OSS"), "dsp");
@@ -216,7 +226,7 @@ void KdenliveSettingsDialog::initDevices() {
     // Fill the list of audio playback devices
     m_configSdl.kcfg_audio_device->addItem(i18n("Default"), QString());
     m_configCapture.kcfg_rmd_alsa_device->addItem(i18n("Default"), QString());
-    if (KStandardDirs::findExe("aplay") != QString::null) {
+    if (!KStandardDirs::findExe("aplay").isEmpty()) {
         m_readProcess.setOutputChannelMode(KProcess::OnlyStdoutChannel);
         m_readProcess.setProgram("aplay", QStringList() << "-l");
         connect(&m_readProcess, SIGNAL(readyReadStandardOutput()) , this, SLOT(slotReadAudioDevices()));
@@ -231,12 +241,12 @@ void KdenliveSettingsDialog::initDevices() {
             while (!stream.atEnd()) {
                 line = stream.readLine();
                 if (line.contains("playback")) {
-                    deviceId = line.section(":", 0, 0);
-                    m_configSdl.kcfg_audio_device->addItem(line.section(":", 1, 1), "plughw:" + QString::number(deviceId.section("-", 0, 0).toInt()) + "," + QString::number(deviceId.section("-", 1, 1).toInt()));
+                    deviceId = line.section(':', 0, 0);
+                    m_configSdl.kcfg_audio_device->addItem(line.section(':', 1, 1), "plughw:" + QString::number(deviceId.section('-', 0, 0).toInt()) + ',' + QString::number(deviceId.section('-', 1, 1).toInt()));
                 }
                 if (line.contains("capture")) {
-                    deviceId = line.section(":", 0, 0);
-                    m_configCapture.kcfg_rmd_alsa_device->addItem(line.section(":", 1, 1), "plughw:" + QString::number(deviceId.section("-", 0, 0).toInt()) + "," + QString::number(deviceId.section("-", 1, 1).toInt()));
+                    deviceId = line.section(':', 0, 0);
+                    m_configCapture.kcfg_rmd_alsa_device->addItem(line.section(':', 1, 1), "plughw:" + QString::number(deviceId.section('-', 0, 0).toInt()) + ',' + QString::number(deviceId.section('-', 1, 1).toInt()));
                 }
             }
             file.close();
@@ -257,45 +267,48 @@ void KdenliveSettingsDialog::initDevices() {
 }
 
 
-void KdenliveSettingsDialog::slotReadAudioDevices() {
+void KdenliveSettingsDialog::slotReadAudioDevices()
+{
     QString result = QString(m_readProcess.readAllStandardOutput());
     kDebug() << "// / / / / / READING APLAY: ";
     kDebug() << result;
     QStringList lines = result.split('\n');
-    foreach(QString data, lines) {
+    foreach(const QString &data, lines) {
         kDebug() << "// READING LINE: " << data;
         if (data.simplified().startsWith("card")) {
-            QString card = data.section(":", 0, 0).section(" ", -1);
-            QString device = data.section(":", 1, 1).section(" ", -1);
-            m_configSdl.kcfg_audio_device->addItem(data.section(":", -1), "plughw:" + card + "," + device);
-            m_configCapture.kcfg_rmd_alsa_device->addItem(data.section(":", -1), "plughw:" + card + "," + device);
+            QString card = data.section(':', 0, 0).section(' ', -1);
+            QString device = data.section(':', 1, 1).section(' ', -1);
+            m_configSdl.kcfg_audio_device->addItem(data.section(':', -1), "plughw:" + card + ',' + device);
+            m_configCapture.kcfg_rmd_alsa_device->addItem(data.section(':', -1), "plughw:" + card + ',' + device);
         }
     }
 }
 
-void KdenliveSettingsDialog::showPage(int page, int option) {
+void KdenliveSettingsDialog::showPage(int page, int option)
+{
     switch (page) {
     case 1:
-        setCurrentPage(page1);
+        setCurrentPage(m_page1);
         break;
     case 2:
-        setCurrentPage(page2);
+        setCurrentPage(m_page2);
         break;
     case 3:
-        setCurrentPage(page3);
+        setCurrentPage(m_page3);
         break;
     case 4:
-        setCurrentPage(page4);
+        setCurrentPage(m_page4);
         m_configCapture.tabWidget->setCurrentIndex(option);
         break;
     case 5:
-        setCurrentPage(page5);
+        setCurrentPage(m_page5);
         break;
 
     }
 }
 
-void KdenliveSettingsDialog::slotEditVideoApplication() {
+void KdenliveSettingsDialog::slotEditVideoApplication()
+{
     KService::Ptr service;
     KOpenWithDialog dlg(KUrl::List(), i18n("Select default video player"), m_configEnv.kcfg_defaultplayerapp->text(), this);
     if (dlg.exec() != QDialog::Accepted)
@@ -305,7 +318,8 @@ void KdenliveSettingsDialog::slotEditVideoApplication() {
     m_configEnv.kcfg_defaultplayerapp->setText(service->exec());
 }
 
-void KdenliveSettingsDialog::slotEditAudioApplication() {
+void KdenliveSettingsDialog::slotEditAudioApplication()
+{
     KService::Ptr service;
     KOpenWithDialog dlg(KUrl::List(), i18n("Select default audio editor"), m_configEnv.kcfg_defaultaudioapp->text(), this);
     if (dlg.exec() != QDialog::Accepted)
@@ -315,7 +329,8 @@ void KdenliveSettingsDialog::slotEditAudioApplication() {
     m_configEnv.kcfg_defaultaudioapp->setText(service->exec());
 }
 
-void KdenliveSettingsDialog::slotEditImageApplication() {
+void KdenliveSettingsDialog::slotEditImageApplication()
+{
     KService::Ptr service;
     KOpenWithDialog dlg(KUrl::List(), i18n("Select default image editor"), m_configEnv.kcfg_defaultimageapp->text(), this);
     if (dlg.exec() != QDialog::Accepted)
@@ -326,7 +341,8 @@ void KdenliveSettingsDialog::slotEditImageApplication() {
 }
 
 #ifndef NO_JOGSHUTTLE
-void KdenliveSettingsDialog::slotCheckShuttle(int state) {
+void KdenliveSettingsDialog::slotCheckShuttle(int state)
+{
     m_configShuttle.config_group->setEnabled(state);
     if (m_configShuttle.shuttledevicelist->count() == 0) {
         // parse devices
@@ -337,7 +353,7 @@ void KdenliveSettingsDialog::slotCheckShuttle(int state) {
             kDebug() << "/// CHECKING OFR: " << filename;
 
             char name[256] = "unknown";
-            fd = ::open((char *) filename.toUtf8().data(), O_RDONLY);
+            fd = KDE_open((char *) filename.toUtf8().data(), O_RDONLY);
             if (fd >= 0 && ioctl(fd, EVIOCGNAME(sizeof(name)), name) >= 0) {
                 m_configShuttle.shuttledevicelist->addItem(name, filename);
             }
@@ -347,14 +363,16 @@ void KdenliveSettingsDialog::slotCheckShuttle(int state) {
     }
 }
 
-void KdenliveSettingsDialog::slotUpdateShuttleDevice(int ix) {
+void KdenliveSettingsDialog::slotUpdateShuttleDevice(int ix)
+{
     QString device = m_configShuttle.shuttledevicelist->itemData(ix).toString();
     //KdenliveSettings::setShuttledevice(device);
     m_configShuttle.kcfg_shuttledevice->setText(device);
 }
 #endif /* NO_JOGSHUTTLE */
 
-void KdenliveSettingsDialog::rebuildVideo4Commands() {
+void KdenliveSettingsDialog::rebuildVideo4Commands()
+{
     QString captureCommand;
     if (!m_configCapture.kcfg_video4adevice->text().isEmpty()) captureCommand = "-f " + m_configCapture.kcfg_video4aformat->text() + " -i " + m_configCapture.kcfg_video4adevice->text();
 
@@ -363,19 +381,21 @@ void KdenliveSettingsDialog::rebuildVideo4Commands() {
 }
 
 
-void KdenliveSettingsDialog::updateSettings() {
+void KdenliveSettingsDialog::updateSettings()
+{
     kDebug() << "// // // KCONFIG UPDATE called";
     m_defaultProfile = m_configMisc.kcfg_profiles_list->currentText();
     KdenliveSettings::setDefault_profile(m_defaultPath);
 
     bool resetProfile = false;
-    QString value = m_configSdl.kcfg_audio_device->itemData(m_configSdl.kcfg_audio_device->currentIndex()).toString();
-    if (value != KdenliveSettings::audiodevicename()) {
-        KdenliveSettings::setAudiodevicename(value);
-        resetProfile = true;
+
+    if (m_configEnv.capturefolderurl->url().path() != KdenliveSettings::capturefolder()) {
+        kDebug() << "/// CAPT FOLDER UPDATED";
+        KdenliveSettings::setCapturefolder(m_configEnv.capturefolderurl->url().path());
+        emit updateCaptureFolder();
     }
 
-    value = m_configCapture.kcfg_rmd_alsa_device->itemData(m_configCapture.kcfg_rmd_alsa_device->currentIndex()).toString();
+    QString value = m_configCapture.kcfg_rmd_alsa_device->itemData(m_configCapture.kcfg_rmd_alsa_device->currentIndex()).toString();
     if (value != KdenliveSettings::rmd_alsadevicename()) {
         KdenliveSettings::setRmd_alsadevicename(value);
     }
@@ -393,6 +413,18 @@ void KdenliveSettingsDialog::updateSettings() {
         resetProfile = true;
     }
 
+    if (value == "alsa") {
+        // Audio device setting is only valid for alsa driver
+        value = m_configSdl.kcfg_audio_device->itemData(m_configSdl.kcfg_audio_device->currentIndex()).toString();
+        if (value != KdenliveSettings::audiodevicename()) {
+            KdenliveSettings::setAudiodevicename(value);
+            resetProfile = true;
+        }
+    } else if (KdenliveSettings::audiodevicename().isEmpty() == false) {
+        KdenliveSettings::setAudiodevicename(QString::null);
+        resetProfile = true;
+    }
+
     value = m_configSdl.kcfg_video_driver->itemData(m_configSdl.kcfg_video_driver->currentIndex()).toString();
     if (value != KdenliveSettings::videodrivername()) {
         KdenliveSettings::setVideodrivername(value);
@@ -410,19 +442,25 @@ void KdenliveSettingsDialog::updateSettings() {
     if (updatePreview) emit updatePreviewSettings();
 }
 
-void KdenliveSettingsDialog::slotUpdateDisplay() {
+void KdenliveSettingsDialog::slotUpdateDisplay()
+{
     QString currentProfile = m_configMisc.kcfg_profiles_list->itemData(m_configMisc.kcfg_profiles_list->currentIndex()).toString();
     QMap< QString, QString > values = ProfilesDialog::getSettingsFromFile(currentProfile);
-    m_configMisc.p_size->setText(values.value("width") + "x" + values.value("height"));
-    m_configMisc.p_fps->setText(values.value("frame_rate_num") + "/" + values.value("frame_rate_den"));
-    m_configMisc.p_aspect->setText(values.value("sample_aspect_num") + "/" + values.value("sample_aspect_den"));
-    m_configMisc.p_display->setText(values.value("display_aspect_num") + "/" + values.value("display_aspect_den"));
+    m_configMisc.p_size->setText(values.value("width") + 'x' + values.value("height"));
+    m_configMisc.p_fps->setText(values.value("frame_rate_num") + '/' + values.value("frame_rate_den"));
+    m_configMisc.p_aspect->setText(values.value("sample_aspect_num") + '/' + values.value("sample_aspect_den"));
+    m_configMisc.p_display->setText(values.value("display_aspect_num") + '/' + values.value("display_aspect_den"));
     if (values.value("progressive").toInt() == 0) m_configMisc.p_progressive->setText(i18n("Interlaced"));
     else m_configMisc.p_progressive->setText(i18n("Progressive"));
     m_defaultProfile = m_configMisc.kcfg_profiles_list->itemText(m_configMisc.kcfg_profiles_list->currentIndex());
     m_defaultPath = currentProfile;
 }
 
+void KdenliveSettingsDialog::slotCheckAlsaDriver()
+{
+    QString value = m_configSdl.kcfg_audio_driver->itemData(m_configSdl.kcfg_audio_driver->currentIndex()).toString();
+    m_configSdl.kcfg_audio_device->setEnabled(value == "alsa");
+}
 
 #include "kdenlivesettingsdialog.moc"
 
