@@ -32,13 +32,14 @@
 /**KRender encapsulates the client side of the interface to a renderer.
 From Kdenlive's point of view, you treat the KRender object as the
 renderer, and simply use it as if it was local. Calls are asyncrhonous -
-you send a call out, and then recieve the return value through the
+you send a call out, and then receive the return value through the
 relevant signal that get's emitted once the call completes.
   *@author Jason Wood
   */
 
 
-namespace Mlt {
+namespace Mlt
+{
 class Miracle;
 class Consumer;
 class Producer;
@@ -50,11 +51,12 @@ class ClipManager;
 
 
 
-class MyThread : public QThread {
+class MyThread : public QThread
+{
     Q_OBJECT
 public:
     virtual void run();
-    void init(QObject *parent, KUrl url, QString target, double frame, double frameLength, int frequency, int channels, int arrayWidth);
+    void init(KUrl url, QString target, double frame, double frameLength, int frequency, int channels, int arrayWidth);
     bool isWorking();
     bool stop_me;
 
@@ -67,14 +69,14 @@ private:
     int m_channels;
     int m_arrayWidth;
     bool m_isWorking;
-    QObject *m_parent;
 
 signals:
     void audioThumbProgress(const int);
     void audioThumbOver();
 };
 
-class KThumb: public QObject {
+class KThumb: public QObject
+{
 Q_OBJECT public:
 
 
@@ -105,14 +107,13 @@ private slots:
     void slotAudioThumbOver();
 
 private:
-    MyThread audioThumbProducer;
+    MyThread m_audioThumbProducer;
     KUrl m_url;
     QString m_thumbFile;
     double m_dar;
     Mlt::Producer *m_producer;
     ClipManager *m_clipManager;
     QString m_id;
-    int m_mainFrame;
 
 signals:
     void thumbReady(int, QPixmap);
