@@ -18,21 +18,24 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
+#include "kdenlive-config.h"
+#include "mainwindow.h"
+
 #include <KApplication>
 #include <KAboutData>
 #include <KDebug>
 #include <KCmdLineArgs>
 #include <KUrl> //new
 
-#include "mainwindow.h"
 
-#ifdef __APPLE_KDE__ || __DARWIN__
+#if defined(__APPLE_KDE__) || defined(__DARWIN__)
 #include <SDL/SDL.h>
 #endif
 
-int main(int argc, char *argv[]) {
+int main(int argc, char *argv[])
+{
     KAboutData aboutData(QByteArray("kdenlive"), QByteArray("kdenlive"),
-                         ki18n("Kdenlive"), QByteArray("0.7.2.1"),
+                         ki18n("Kdenlive"), VERSION,
                          ki18n("An open source video editor."),
                          KAboutData::License_GPL,
                          ki18n("Copyright (c) 2008 Development team"));
