@@ -61,7 +61,8 @@ class DocClipBase;
 class Render;
 class Transition;
 
-class MainWindow : public KXmlGuiWindow {
+class MainWindow : public KXmlGuiWindow
+{
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kdenlive.MainWindow")
 
@@ -74,7 +75,7 @@ public:
      * The constructor inits the main window. If Url is present, it will be opened.
      * If Url is not present, and openLastproject is set, last project will be set
      * If no file is open after trying this, a default "newfile" will be created. */
-    MainWindow(const QString &MltPath = QString(), const KUrl & Url = KUrl(), QWidget *parent = 0);
+    explicit MainWindow(const QString &MltPath = QString(), const KUrl & Url = KUrl(), QWidget *parent = 0);
     void parseProfiles(const QString &mltPath = QString());
 
     static EffectsList videoEffects;
@@ -103,43 +104,40 @@ protected:
 
 private:
     KTabWidget* m_timelineArea;
-    QProgressBar *statusProgressBar;
+    QProgressBar *m_statusProgressBar;
     void setupActions();
     KdenliveDoc *m_activeDocument;
     TrackView *m_activeTimeline;
     MonitorManager *m_monitorManager;
 
-    QDockWidget *projectListDock;
+    QDockWidget *m_projectListDock;
     ProjectList *m_projectList;
 
-    QDockWidget *effectListDock;
+    QDockWidget *m_effectListDock;
     EffectsListView *m_effectList;
     //KListWidget *m_effectList;
 
-    QDockWidget *effectStackDock;
-    EffectStackView *effectStack;
+    QDockWidget *m_effectStackDock;
+    EffectStackView *m_effectStack;
 
-    QDockWidget *transitionConfigDock;
-    TransitionSettings *transitionConfig;
+    QDockWidget *m_transitionConfigDock;
+    TransitionSettings *m_transitionConfig;
 
-    QDockWidget *clipMonitorDock;
+    QDockWidget *m_clipMonitorDock;
     Monitor *m_clipMonitor;
 
-    QDockWidget *projectMonitorDock;
+    QDockWidget *m_projectMonitorDock;
     Monitor *m_projectMonitor;
 
-    QDockWidget *recMonitorDock;
+    QDockWidget *m_recMonitorDock;
     RecMonitor *m_recMonitor;
 
-    QDockWidget *undoViewDock;
+    QDockWidget *m_undoViewDock;
     QUndoView *m_undoView;
     QUndoGroup *m_commandStack;
 
     KComboBox *m_timecodeFormat;
 
-    QDockWidget *overviewDock;
-    CustomTrackView *m_overView;
-
     QMenu *m_customEffectsMenu;
     QMenu *m_timelineContextMenu;
     QMenu *m_timelineContextClipMenu;
@@ -167,14 +165,14 @@ private:
     KAction *m_saveAction;
     KAction *m_closeAction;
     QSlider *m_zoomSlider;
-    QAction *m_loopZone;
-    QAction *m_playZone;
+    KAction *m_loopZone;
+    KAction *m_playZone;
     StatusBarMessageLabel *m_messageLabel;
+    QActionGroup *m_clipTypeGroup;
 
     bool m_findActivated;
     QString m_findString;
     QTimer m_findTimer;
-    bool m_initialized;
 
     void readOptions();
     void saveOptions();
@@ -193,6 +191,7 @@ private:
                    QActionGroup *actionGroup);
     void aboutPlugins();
     QStringList m_pluginFileNames;
+    QByteArray m_timelineState;
 
 public slots:
     void openFile(const KUrl &url);
@@ -214,7 +213,7 @@ private slots:
     void updateConfiguration();
     void slotConnectMonitors();
     void slotRaiseMonitor(bool clipMonitor);
-    void slotSetClipDuration(const QString &id, int duration);
+    void slotUpdateClip(const QString &id);
     void slotUpdateMousePosition(int pos);
     void slotAddEffect(QDomElement effect, GenTime pos = GenTime(), int track = -1);
     void slotEditProfiles();
@@ -225,7 +224,7 @@ private slots:
     void slotSwitchMarkersComments();
     void slotSwitchSnap();
     void slotRenderProject();
-    void slotDoRender(const QString &dest, const QString &render, const QStringList &overlay_args, const QStringList &avformat_args, bool zoneOnly, bool playAfter, double guideStart, double guideEnd, bool resizeProfile);
+    void slotDoRender(const QString &dest, const QString &render, const QStringList &overlay_args, const QStringList &avformat_args, bool zoneOnly, bool playAfter, double guideStart, double guideEnd, bool resizeProfile, const QString &scriptExport);
     void slotFullScreen();
     void slotUpdateDocumentState(bool modified);
     void slotZoomIn();
@@ -283,13 +282,21 @@ private slots:
     void slotInsertTrack(int ix = 0);
     void slotDeleteTrack(int ix = 0);
     void slotChangeTrack(int ix = 0);
-    void slotGetNewStuff();
+    void slotGetNewLumaStuff();
+    void slotGetNewRenderStuff();
+    void slotGetNewMltProfileStuff();
     void slotAutoTransition();
     void slotRunWizard();
     void generateClip();
     void slotZoneMoved(int start, int end);
     void slotUpdatePreviewSettings();
     void slotDvdWizard(const QString &url = QString(), const QString &profile = "dv_pal");
+    void slotGroupClips();
+    void slotUnGroupClips();
+    void slotSplitAudio();
+    void slotUpdateClipType(QAction *action);
+    void slotShowTimeline(bool show);
+    void slotMaximizeCurrent(bool show);
 
 signals:
     Q_SCRIPTABLE void abortRenderJob(const QString &url);
