@@ -18,6 +18,19 @@
  ***************************************************************************/
 
 
+#include "monitor.h"
+#include "renderer.h"
+#include "monitormanager.h"
+#include "smallruler.h"
+#include "docclipbase.h"
+#include "kdenlivesettings.h"
+
+#include <KDebug>
+#include <KLocale>
+#include <KFileDialog>
+#include <KApplication>
+#include <KMessageBox>
+
 #include <QMouseEvent>
 #include <QStylePainter>
 #include <QMenu>
@@ -26,27 +39,24 @@
 #include <QDesktopWidget>
 #include <QLabel>
 
-#include <KDebug>
-#include <KLocale>
-#include <KFileDialog>
-#include <KApplication>
-#include <KMessageBox>
 
-#include "monitor.h"
-#include "renderer.h"
-#include "monitormanager.h"
-#include "smallruler.h"
-#include "docclipbase.h"
-
-Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent)
-        : QWidget(parent), render(NULL), m_monitorManager(manager), m_name(name), m_isActive(false), m_currentClip(NULL), m_dragStarted(false) {
-    ui.setupUi(this);
+Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent) :
+        QWidget(parent),
+        render(NULL),
+        m_monitorManager(manager),
+        m_name(name),
+        m_isActive(false),
+        m_currentClip(NULL),
+        m_dragStarted(false),
+        m_overlay(NULL)
+{
+    m_ui.setupUi(this);
     m_scale = 1;
     m_ruler = new SmallRuler();
     QVBoxLayout *layout = new QVBoxLayout;
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(m_ruler);
-    ui.ruler_frame->setLayout(layout);
+    m_ui.ruler_frame->setLayout(layout);
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     setMinimumHeight(200);
     QToolBar *toolbar = new QToolBar(name, this);
@@ -56,8 +66,8 @@ Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent)
     m_playIcon = KIcon("media-playback-start");
     m_pauseIcon = KIcon("media-playback-pause");
 
-    QAction *zoneStart = toolbar->addAction(KIcon("kdenlive-zone-start"), i18n("Set zone start"), this, SLOT(slotSetZoneStart()));
-    QAction *zoneEnd = toolbar->addAction(KIcon("kdenlive-zone-end"), i18n("Set zone end"), this, SLOT(slotSetZoneEnd()));
+    toolbar->addAction(KIcon("kdenlive-zone-start"), i18n("Set zone start"), this, SLOT(slotSetZoneStart()));
+    toolbar->addAction(KIcon("kdenlive-zone-end"), i18n("Set zone end"), this, SLOT(slotSetZoneEnd()));
 
     toolbar->addAction(KIcon("media-seek-backward"), i18n("Rewind"), this, SLOT(slotRewind()));
     toolbar->addAction(KIcon("media-skip-backward"), i18n("Rewind 1 frame"), this, SLOT(slotRewindOneFrame()));
@@ -95,24 +105,19 @@ Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent)
     connect(m_timePos, SIGNAL(editingFinished()), this, SLOT(slotSeek()));
 
     layout2->addWidget(toolbar);
-    ui.button_frame->setLayout(layout2);
+    m_ui.button_frame->setLayout(layout2);
     const int toolHeight = toolbar->height();
-    ui.button_frame->setMinimumHeight(toolHeight);
+    m_ui.button_frame->setMinimumHeight(toolHeight);
 
     //m_ruler->setPixelPerMark(3);
 
-    QVBoxLayout *rendererBox = new QVBoxLayout(ui.video_frame);
+    QVBoxLayout *rendererBox = new QVBoxLayout(m_ui.video_frame);
     rendererBox->setContentsMargins(0, 0, 0, 0);
-    m_monitorRefresh = new MonitorRefresh(ui.video_frame);
+    m_monitorRefresh = new MonitorRefresh(m_ui.video_frame);
     rendererBox->addWidget(m_monitorRefresh);
     render = new Render(m_name, (int) m_monitorRefresh->winId(), -1, this);
     m_monitorRefresh->setRenderer(render);
 
-    m_overlay = new Overlay(m_monitorRefresh);
-    m_overlay->raise();
-    m_overlay->setHidden(true);
-
-
     connect(m_ruler, SIGNAL(seekRenderer(int)), this, SLOT(slotSeek(int)));
     connect(render, SIGNAL(durationChanged(int)), this, SLOT(adjustRulerSize(int)));
     connect(render, SIGNAL(rendererPosition(int)), this, SLOT(seekCursor(int)));
@@ -121,7 +126,7 @@ Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent)
     m_configMenu->addSeparator();
     m_configMenu->addAction(KIcon("transform-scale"), i18n("Resize (100%)"), this, SLOT(slotSetSizeOneToOne()));
     m_configMenu->addAction(KIcon("transform-scale"), i18n("Resize (50%)"), this, SLOT(slotSetSizeOneToTwo()));
-    //render->createVideoXWindow(ui.video_frame->winId(), -1);
+    //render->createVideoXWindow(m_ui.video_frame->winId(), -1);
     m_length = 0;
 
     if (name != "clip") {
@@ -132,24 +137,27 @@ Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent)
         connect(m_ruler, SIGNAL(zoneChanged(QPoint)), this, SLOT(setClipZone(QPoint)));
     }
     m_monitorRefresh->show();
-    kDebug() << "/////// BUILDING MONITOR, ID: " << ui.video_frame->winId();
+    kDebug() << "/////// BUILDING MONITOR, ID: " << m_ui.video_frame->winId();
 }
 
-Monitor::~Monitor() {
+Monitor::~Monitor()
+{
     delete m_ruler;
     delete m_timePos;
     delete m_overlay;
     delete m_monitorRefresh;
 }
 
-QString Monitor::name() const {
+QString Monitor::name() const
+{
     return m_name;
 }
 
-void Monitor::setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMenu *markerMenu) {
+void Monitor::setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMenu *markerMenu)
+{
     m_contextMenu = new QMenu(this);
     m_contextMenu->addMenu(m_playMenu);
-    m_contextMenu->addMenu(goMenu);
+    if (goMenu) m_contextMenu->addMenu(goMenu);
     if (markerMenu) m_contextMenu->addMenu(markerMenu);
 
     m_playMenu->addAction(playZone);
@@ -162,7 +170,7 @@ void Monitor::setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMe
     m_contextMenu->addAction(extractFrame);
 
     if (m_name != "clip") {
-        QAction *splitView = m_contextMenu->addAction(KIcon("document-new"), i18n("Split view"), render, SLOT(slotSplitView(bool)));
+        QAction *splitView = m_contextMenu->addAction(KIcon("view-split-left-right"), i18n("Split view"), render, SLOT(slotSplitView(bool)));
         splitView->setCheckable(true);
         m_configMenu->addAction(splitView);
     } else {
@@ -170,9 +178,16 @@ void Monitor::setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMe
         m_configMenu->addAction(setThumbFrame);
     }
 
+    QAction *showTips = m_contextMenu->addAction(KIcon("help-hint"), i18n("Monitor overlay infos"));
+    showTips->setCheckable(true);
+    connect(showTips, SIGNAL(toggled(bool)), this, SLOT(slotSwitchMonitorInfo(bool)));
+    showTips->setChecked(KdenliveSettings::displayMonitorInfo());
+    m_configMenu->addAction(showTips);
+
 }
 
-void Monitor::slotSetSizeOneToOne() {
+void Monitor::slotSetSizeOneToOne()
+{
     QRect r = QApplication::desktop()->screenGeometry();
     const int maxWidth = r.width() - 20;
     const int maxHeight = r.height() - 20;
@@ -184,14 +199,15 @@ void Monitor::slotSetSizeOneToOne() {
         height = height * 0.8;
     }
     kDebug() << "// MONITOR; set SIZE: " << width << ", " << height;
-    ui.video_frame->setFixedSize(width, height);
+    m_ui.video_frame->setFixedSize(width, height);
     updateGeometry();
     adjustSize();
-    //ui.video_frame->setMinimumSize(0, 0);
+    //m_ui.video_frame->setMinimumSize(0, 0);
     emit adjustMonitorSize();
 }
 
-void Monitor::slotSetSizeOneToTwo() {
+void Monitor::slotSetSizeOneToTwo()
+{
     QRect r = QApplication::desktop()->screenGeometry();
     const int maxWidth = r.width() - 20;
     const int maxHeight = r.height() - 20;
@@ -203,34 +219,40 @@ void Monitor::slotSetSizeOneToTwo() {
         height = height * 0.8;
     }
     kDebug() << "// MONITOR; set SIZE: " << width << ", " << height;
-    ui.video_frame->setFixedSize(width, height);
+    m_ui.video_frame->setFixedSize(width, height);
     updateGeometry();
     adjustSize();
-    //ui.video_frame->setMinimumSize(0, 0);
+    //m_ui.video_frame->setMinimumSize(0, 0);
     emit adjustMonitorSize();
 }
 
-void Monitor::resetSize() {
-    ui.video_frame->setMinimumSize(0, 0);
+void Monitor::resetSize()
+{
+    m_ui.video_frame->setMinimumSize(0, 0);
 }
 
-DocClipBase *Monitor::activeClip() {
+DocClipBase *Monitor::activeClip()
+{
     return m_currentClip;
 }
 
-void Monitor::slotSeekToPreviousSnap() {
+void Monitor::slotSeekToPreviousSnap()
+{
     if (m_currentClip) slotSeek(getSnapForPos(true).frames(m_monitorManager->timecode().fps()));
 }
 
-void Monitor::slotSeekToNextSnap() {
+void Monitor::slotSeekToNextSnap()
+{
     if (m_currentClip) slotSeek(getSnapForPos(false).frames(m_monitorManager->timecode().fps()));
 }
 
-GenTime Monitor::position() {
+GenTime Monitor::position()
+{
     return GenTime(m_position, m_monitorManager->timecode().fps());
 }
 
-GenTime Monitor::getSnapForPos(bool previous) {
+GenTime Monitor::getSnapForPos(bool previous)
+{
     QList <GenTime> snaps;
     QList < GenTime > markers = m_currentClip->snapMarkers();
     for (int i = 0; i < markers.size(); ++i) {
@@ -258,20 +280,23 @@ GenTime Monitor::getSnapForPos(bool previous) {
 
 
 
-void Monitor::slotZoneMoved(int start, int end) {
+void Monitor::slotZoneMoved(int start, int end)
+{
     m_ruler->setZone(start, end);
     checkOverlay();
     setClipZone(m_ruler->zone());
 }
 
-void Monitor::slotSetZoneStart() {
+void Monitor::slotSetZoneStart()
+{
     m_ruler->setZone(m_position, -1);
     emit zoneUpdated(m_ruler->zone());
     checkOverlay();
     setClipZone(m_ruler->zone());
 }
 
-void Monitor::slotSetZoneEnd() {
+void Monitor::slotSetZoneEnd()
+{
     m_ruler->setZone(-1, m_position);
     emit zoneUpdated(m_ruler->zone());
     checkOverlay();
@@ -279,9 +304,10 @@ void Monitor::slotSetZoneEnd() {
 }
 
 // virtual
-void Monitor::mousePressEvent(QMouseEvent * event) {
+void Monitor::mousePressEvent(QMouseEvent * event)
+{
     if (event->button() != Qt::RightButton) {
-        if (ui.video_frame->underMouse()) {
+        if (m_ui.video_frame->underMouse()) {
             m_dragStarted = true;
             m_DragStartPosition = event->pos();
         }
@@ -289,9 +315,10 @@ void Monitor::mousePressEvent(QMouseEvent * event) {
 }
 
 // virtual
-void Monitor::mouseReleaseEvent(QMouseEvent * event) {
+void Monitor::mouseReleaseEvent(QMouseEvent * event)
+{
     if (m_dragStarted) {
-        if (ui.video_frame->underMouse()) {
+        if (m_ui.video_frame->underMouse()) {
             slotPlay();
         } else QWidget::mouseReleaseEvent(event);
         m_dragStarted = false;
@@ -300,7 +327,8 @@ void Monitor::mouseReleaseEvent(QMouseEvent * event) {
 
 
 // virtual
-void Monitor::mouseMoveEvent(QMouseEvent *event) {
+void Monitor::mouseMoveEvent(QMouseEvent *event)
+{
     // kDebug() << "// DRAG STARTED, MOUSE MOVED: ";
     if (!m_dragStarted || m_currentClip == NULL) return;
 
@@ -349,7 +377,8 @@ Qt::DropActions Monitor::supportedDropActions() const {
     return Qt::MoveAction;
 }*/
 
-QStringList Monitor::mimeTypes() const {
+QStringList Monitor::mimeTypes() const
+{
     QStringList qstrList;
     // list of accepted mime types for drop
     qstrList.append("kdenlive/clip");
@@ -366,7 +395,8 @@ QStringList Monitor::mimeTypes() const {
  * Ctrl+wheel moves single frame, without Ctrl moves a second.
  *
  * See also http://www.kdenlive.org/mantis/view.php?id=265 */
-void Monitor::wheelEvent(QWheelEvent * event) {
+void Monitor::wheelEvent(QWheelEvent * event)
+{
     if (event->modifiers() == Qt::ControlModifier) {
         int delta = m_monitorManager->timecode().fps();
         if (event->delta() < 0) delta = 0 - delta;
@@ -377,7 +407,8 @@ void Monitor::wheelEvent(QWheelEvent * event) {
     }
 }
 
-void Monitor::slotSetThumbFrame() {
+void Monitor::slotSetThumbFrame()
+{
     if (m_currentClip == NULL) {
         return;
     }
@@ -385,7 +416,8 @@ void Monitor::slotSetThumbFrame() {
     emit refreshClipThumbnail(m_currentClip->getId());
 }
 
-void Monitor::slotExtractCurrentFrame() {
+void Monitor::slotExtractCurrentFrame()
+{
     QPixmap frame = render->extractFrame(m_position);
     QString outputFile = KFileDialog::getSaveFileName(KUrl(), "image/png");
     if (!outputFile.isEmpty()) {
@@ -394,20 +426,24 @@ void Monitor::slotExtractCurrentFrame() {
     }
 }
 
-bool Monitor::isActive() const {
+bool Monitor::isActive() const
+{
     return m_isActive;
 }
 
-void Monitor::activateMonitor() {
+void Monitor::activateMonitor()
+{
     if (!m_isActive) m_monitorManager->switchMonitors(); //m_monitorManager->activateMonitor(m_name);
 }
 
-void Monitor::slotSeek() {
+void Monitor::slotSeek()
+{
     const int frames = m_monitorManager->timecode().getFrameCount(m_timePos->text(), m_monitorManager->timecode().fps());
     slotSeek(frames);
 }
 
-void Monitor::slotSeek(int pos) {
+void Monitor::slotSeek(int pos)
+{
     activateMonitor();
     if (render == NULL) return;
     m_position = pos;
@@ -417,7 +453,9 @@ void Monitor::slotSeek(int pos) {
     m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(m_position));
 }
 
-void Monitor::checkOverlay() {
+void Monitor::checkOverlay()
+{
+    if (m_overlay == NULL) return;
     QPoint zone = m_ruler->zone();
     if (m_position == zone.x()) m_overlay->setOverlayText(i18n("In Point"));
     else if (m_position == zone.y()) m_overlay->setOverlayText(i18n("Out Point"));
@@ -430,7 +468,8 @@ void Monitor::checkOverlay() {
     }
 }
 
-void Monitor::slotStart() {
+void Monitor::slotStart()
+{
     activateMonitor();
     render->play(0);
     m_position = 0;
@@ -439,7 +478,8 @@ void Monitor::slotStart() {
     m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(m_position));
 }
 
-void Monitor::slotEnd() {
+void Monitor::slotEnd()
+{
     activateMonitor();
     render->play(0);
     m_position = render->getLength();
@@ -448,7 +488,8 @@ void Monitor::slotEnd() {
     m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(m_position));
 }
 
-void Monitor::slotZoneStart() {
+void Monitor::slotZoneStart()
+{
     activateMonitor();
     render->play(0);
     m_position = m_ruler->zone().x();
@@ -457,7 +498,8 @@ void Monitor::slotZoneStart() {
     m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(m_position));
 }
 
-void Monitor::slotZoneEnd() {
+void Monitor::slotZoneEnd()
+{
     activateMonitor();
     render->play(0);
     m_position = m_ruler->zone().y();
@@ -466,7 +508,8 @@ void Monitor::slotZoneEnd() {
     m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(m_position));
 }
 
-void Monitor::slotRewind(double speed) {
+void Monitor::slotRewind(double speed)
+{
     activateMonitor();
     if (speed == 0) {
         double currentspeed = render->playSpeed();
@@ -477,7 +520,8 @@ void Monitor::slotRewind(double speed) {
     m_playAction->setIcon(m_pauseIcon);
 }
 
-void Monitor::slotForward(double speed) {
+void Monitor::slotForward(double speed)
+{
     activateMonitor();
     if (speed == 0) {
         double currentspeed = render->playSpeed();
@@ -488,7 +532,8 @@ void Monitor::slotForward(double speed) {
     m_playAction->setIcon(m_pauseIcon);
 }
 
-void Monitor::slotRewindOneFrame(int diff) {
+void Monitor::slotRewindOneFrame(int diff)
+{
     activateMonitor();
     render->play(0);
     if (m_position < 1) return;
@@ -500,7 +545,8 @@ void Monitor::slotRewindOneFrame(int diff) {
     checkOverlay();
 }
 
-void Monitor::slotForwardOneFrame(int diff) {
+void Monitor::slotForwardOneFrame(int diff)
+{
     activateMonitor();
     render->play(0);
     if (m_position >= m_length) return;
@@ -512,25 +558,29 @@ void Monitor::slotForwardOneFrame(int diff) {
     checkOverlay();
 }
 
-void Monitor::seekCursor(int pos) {
+void Monitor::seekCursor(int pos)
+{
     activateMonitor();
+    checkOverlay();
     m_position = pos;
     m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
     m_ruler->slotNewValue(pos);
 }
 
-void Monitor::rendererStopped(int pos) {
+void Monitor::rendererStopped(int pos)
+{
     //int rulerPos = (int)(pos * m_scale);
     m_ruler->slotNewValue(pos);
     m_position = pos;
-    checkOverlay();
+    //checkOverlay();
     m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
     m_playAction->setChecked(false);
     m_playAction->setIcon(m_playIcon);
 }
 
-void Monitor::initMonitor() {
-    kDebug() << "/////// INITING MONITOR, ID: " << ui.video_frame->winId();
+void Monitor::initMonitor()
+{
+    kDebug() << "/////// INITING MONITOR, ID: " << m_ui.video_frame->winId();
 }
 
 // virtual
@@ -541,7 +591,8 @@ void Monitor::initMonitor() {
     //
 }*/
 
-void Monitor::adjustRulerSize(int length) {
+void Monitor::adjustRulerSize(int length)
+{
     if (length > 0) m_length = length;
     m_ruler->adjustScale(m_length);
     if (m_currentClip != NULL) {
@@ -550,26 +601,30 @@ void Monitor::adjustRulerSize(int length) {
     }
 }
 
-void Monitor::stop() {
+void Monitor::stop()
+{
     m_isActive = false;
     if (render) render->stop();
     //kDebug()<<"/// MONITOR RENDER STOP";
 }
 
-void Monitor::start() {
+void Monitor::start()
+{
     m_isActive = true;
     if (render) render->start();
     //kDebug()<<"/// MONITOR RENDER START";
 }
 
-void Monitor::refreshMonitor(bool visible) {
+void Monitor::refreshMonitor(bool visible)
+{
     if (visible && render) {
         activateMonitor();
         render->doRefresh(); //askForRefresh();
     }
 }
 
-void Monitor::pause() {
+void Monitor::pause()
+{
     if (render == NULL) return;
     activateMonitor();
     render->pause();
@@ -577,7 +632,8 @@ void Monitor::pause() {
     //m_playAction->setIcon(m_pauseIcon);
 }
 
-void Monitor::slotPlay() {
+void Monitor::slotPlay()
+{
     if (render == NULL) return;
     activateMonitor();
     if (render->playSpeed() == 0) {
@@ -590,7 +646,8 @@ void Monitor::slotPlay() {
     render->switchPlay();
 }
 
-void Monitor::slotPlayZone() {
+void Monitor::slotPlayZone()
+{
     if (render == NULL) return;
     activateMonitor();
     QPoint p = m_ruler->zone();
@@ -599,7 +656,8 @@ void Monitor::slotPlayZone() {
     m_playAction->setIcon(m_pauseIcon);
 }
 
-void Monitor::slotLoopZone() {
+void Monitor::slotLoopZone()
+{
     if (render == NULL) return;
     activateMonitor();
     QPoint p = m_ruler->zone();
@@ -608,7 +666,8 @@ void Monitor::slotLoopZone() {
     m_playAction->setIcon(m_pauseIcon);
 }
 
-void Monitor::slotSetXml(DocClipBase *clip, const int position) {
+void Monitor::slotSetXml(DocClipBase *clip, const int position)
+{
     if (render == NULL) return;
     activateMonitor();
     if (!clip && m_currentClip != NULL) {
@@ -623,7 +682,8 @@ void Monitor::slotSetXml(DocClipBase *clip, const int position) {
     } else if (position != -1) render->seek(GenTime(position, render->fps()));
 }
 
-void Monitor::slotOpenFile(const QString &file) {
+void Monitor::slotOpenFile(const QString &file)
+{
     if (render == NULL) return;
     activateMonitor();
     QDomDocument doc;
@@ -636,7 +696,8 @@ void Monitor::slotOpenFile(const QString &file) {
     render->setSceneList(doc, 0);
 }
 
-void Monitor::slotSaveZone() {
+void Monitor::slotSaveZone()
+{
     if (render == NULL) return;
     emit saveZone(render, m_ruler->zone());
 
@@ -644,51 +705,75 @@ void Monitor::slotSaveZone() {
 }
 
 
-void Monitor::resetProfile() {
+void Monitor::resetProfile()
+{
     if (render == NULL) return;
     render->resetProfile();
 }
 
-void Monitor::saveSceneList(QString path, QDomElement info) {
+void Monitor::saveSceneList(QString path, QDomElement info)
+{
     if (render == NULL) return;
     render->saveSceneList(path, info);
 }
 
-QDomDocument Monitor::sceneList() {
-    if (render == NULL) return QDomDocument();
-    QDomDocument doc;
-    doc.setContent(render->sceneList());
-    return doc;
+const QString Monitor::sceneList()
+{
+    if (render == NULL) return QString();
+    return render->sceneList();
 }
 
 
-void Monitor::setClipZone(QPoint pos) {
+void Monitor::setClipZone(QPoint pos)
+{
     if (m_currentClip == NULL) return;
     m_currentClip->setZone(pos);
 }
 
-MonitorRefresh::MonitorRefresh(QWidget* parent): QWidget(parent), m_renderer(NULL) {
+void Monitor::slotSwitchMonitorInfo(bool show)
+{
+    KdenliveSettings::setDisplayMonitorInfo(show);
+    if (show) {
+        if (m_overlay) return;
+        m_overlay = new Overlay(m_monitorRefresh);
+        m_overlay->raise();
+        m_overlay->setHidden(true);
+    } else {
+        delete m_overlay;
+        m_overlay = NULL;
+    }
+}
+
+MonitorRefresh::MonitorRefresh(QWidget* parent) : \
+        QWidget(parent),
+        m_renderer(NULL)
+{
     setAttribute(Qt::WA_PaintOnScreen);
     setAttribute(Qt::WA_OpaquePaintEvent); //setAttribute(Qt::WA_NoSystemBackground);
 }
 
-void MonitorRefresh::setRenderer(Render* render) {
+void MonitorRefresh::setRenderer(Render* render)
+{
     m_renderer = render;
 }
 
-void MonitorRefresh::paintEvent(QPaintEvent * event) {
+void MonitorRefresh::paintEvent(QPaintEvent * /*event*/)
+{
     if (m_renderer) m_renderer->doRefresh();
 }
 
 
-Overlay::Overlay(QWidget* parent): QLabel(parent) {
+Overlay::Overlay(QWidget* parent) :
+        QLabel(parent)
+{
     setAttribute(Qt::WA_TransparentForMouseEvents);
     setAttribute(Qt::WA_OpaquePaintEvent);
     //setAttribute(Qt::WA_NoSystemBackground);
     setAutoFillBackground(false);
 }
 
-void Overlay::paintEvent(QPaintEvent * event) {
+void Overlay::paintEvent(QPaintEvent * /*event*/)
+{
     QPainter painter(this);
     QColor col;
     painter.setPen(Qt::white);
@@ -700,7 +785,8 @@ void Overlay::paintEvent(QPaintEvent * event) {
 
 
 
-void Overlay::setOverlayText(const QString &text, bool isZone) {
+void Overlay::setOverlayText(const QString &text, bool isZone)
+{
     setHidden(true);
     m_isZone = isZone;
     setText(' ' + text + ' ');
@@ -708,6 +794,4 @@ void Overlay::setOverlayText(const QString &text, bool isZone) {
     update();
 }
 
-
-
 #include "monitor.moc"
