@@ -36,7 +36,8 @@ class Render;
 class SmallRuler;
 class DocClipBase;
 
-class MonitorRefresh : public QWidget {
+class MonitorRefresh : public QWidget
+{
     Q_OBJECT
 public:
     MonitorRefresh(QWidget* parent);
@@ -47,7 +48,8 @@ private:
     Render *m_renderer;
 };
 
-class Overlay : public QLabel {
+class Overlay : public QLabel
+{
     Q_OBJECT
 public:
     Overlay(QWidget* parent);
@@ -58,7 +60,8 @@ private:
     bool m_isZone;
 };
 
-class Monitor : public QWidget {
+class Monitor : public QWidget
+{
     Q_OBJECT
 
 public:
@@ -71,7 +74,7 @@ public:
     bool isActive() const;
     void pause();
     void setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMenu *markerMenu = NULL);
-    QDomDocument sceneList();
+    const QString sceneList();
     DocClipBase *activeClip();
     GenTime position();
     void checkOverlay();
@@ -89,7 +92,7 @@ protected:
 //    virtual void paintEvent(QPaintEvent * event);
 
 private:
-    Ui::Monitor_UI ui;
+    Ui::Monitor_UI m_ui;
     MonitorManager *m_monitorManager;
     MonitorRefresh *m_monitorRefresh;
     QString m_name;
@@ -121,6 +124,7 @@ private slots:
     void slotSaveZone();
     void slotSeek();
     void setClipZone(QPoint pos);
+    void slotSwitchMonitorInfo(bool show);
 
 public slots:
     void slotOpenFile(const QString &);
