@@ -18,29 +18,29 @@
  ***************************************************************************/
 
 
-#include <QMouseEvent>
-#include <QStylePainter>
-#include <QLabel>
-#include <QLayout>
+#include "projectitem.h"
+#include "timecode.h"
+#include "kdenlivesettings.h"
+#include "docclipbase.h"
 
 #include <KDebug>
 #include <KLocale>
 #include <KIcon>
 
 
-#include "projectitem.h"
-#include "timecode.h"
-#include "kdenlivesettings.h"
-#include "docclipbase.h"
-
 const int NameRole = Qt::UserRole;
 const int DurationRole = NameRole + 1;
 const int UsageRole = NameRole + 2;
 
 
 // folder
-ProjectItem::ProjectItem(QTreeWidget * parent, const QStringList & strings, const QString &clipId)
-        : QTreeWidgetItem(parent, strings), m_clipType(FOLDER), m_clipId(clipId), m_clip(NULL), m_groupname(strings.at(1)) {
+ProjectItem::ProjectItem(QTreeWidget * parent, const QStringList & strings, const QString &clipId) :
+        QTreeWidgetItem(parent, strings),
+        m_groupname(strings.at(1)),
+        m_clipType(FOLDER),
+        m_clipId(clipId),
+        m_clip(NULL)
+{
     setSizeHint(0, QSize(65, 45));
     setFlags(Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled | Qt::ItemIsEditable);
     setIcon(0, KIcon("folder"));
@@ -48,8 +48,9 @@ ProjectItem::ProjectItem(QTreeWidget * parent, const QStringList & strings, cons
     //kDebug() << "Constructed as folder, with clipId: " << m_clipId << ", and groupname: " << m_groupname;
 }
 
-ProjectItem::ProjectItem(QTreeWidget * parent, DocClipBase *clip)
-        : QTreeWidgetItem(parent) {
+ProjectItem::ProjectItem(QTreeWidget * parent, DocClipBase *clip) :
+        QTreeWidgetItem(parent)
+{
     setSizeHint(0, QSize(65, 45));
     setFlags(Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled | Qt::ItemIsEditable);
     m_clip = clip;
@@ -61,12 +62,15 @@ ProjectItem::ProjectItem(QTreeWidget * parent, DocClipBase *clip)
     setText(1, name);
     setText(2, m_clip->description());
     if ((m_clip->clipType() == AV || m_clip->clipType() == AUDIO) && KdenliveSettings::audiothumbnails()) m_clip->askForAudioThumbs();
+    GenTime duration = m_clip->duration();
+    if (duration != GenTime()) setData(1, DurationRole, Timecode::getEasyTimecode(duration, KdenliveSettings::project_fps()));
     //setFlags(Qt::NoItemFlags);
     //kDebug() << "Constructed with clipId: " << m_clipId;
 }
 
-ProjectItem::ProjectItem(QTreeWidgetItem * parent, DocClipBase *clip)
-        : QTreeWidgetItem(parent) {
+ProjectItem::ProjectItem(QTreeWidgetItem * parent, DocClipBase *clip) :
+        QTreeWidgetItem(parent)
+{
     setSizeHint(0, QSize(65, 45));
     setFlags(Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled | Qt::ItemIsEditable);
     m_clip = clip;
@@ -77,36 +81,45 @@ ProjectItem::ProjectItem(QTreeWidgetItem * parent, DocClipBase *clip)
     setText(1, name);
     setText(2, m_clip->description());
     if ((m_clip->clipType() == AV || m_clip->clipType() == AUDIO) && KdenliveSettings::audiothumbnails()) m_clip->askForAudioThumbs();
+    GenTime duration = m_clip->duration();
+    if (duration != GenTime()) setData(1, DurationRole, Timecode::getEasyTimecode(duration, KdenliveSettings::project_fps()));
     //setFlags(Qt::NoItemFlags);
     //kDebug() << "Constructed with clipId: " << m_clipId;
 }
 
 
-ProjectItem::~ProjectItem() {
+ProjectItem::~ProjectItem()
+{
 }
 
-int ProjectItem::numReferences() const {
+int ProjectItem::numReferences() const
+{
     if (!m_clip) return 0;
     return m_clip->numReferences();
 }
 
-const QString &ProjectItem::clipId() const {
+const QString &ProjectItem::clipId() const
+{
     return m_clipId;
 }
 
-CLIPTYPE ProjectItem::clipType() const {
+CLIPTYPE ProjectItem::clipType() const
+{
     return m_clipType;
 }
 
-int ProjectItem::clipMaxDuration() const {
+int ProjectItem::clipMaxDuration() const
+{
     return m_clip->getProperty("duration").toInt();
 }
 
-bool ProjectItem::isGroup() const {
+bool ProjectItem::isGroup() const
+{
     return m_clipType == FOLDER;
 }
 
-QStringList ProjectItem::names() const {
+QStringList ProjectItem::names() const
+{
     QStringList result;
     result.append(text(0));
     result.append(text(1));
@@ -114,54 +127,65 @@ QStringList ProjectItem::names() const {
     return result;
 }
 
-QDomElement ProjectItem::toXml() const {
+QDomElement ProjectItem::toXml() const
+{
     return m_clip->toXML();
 }
 
-const KUrl ProjectItem::clipUrl() const {
+const KUrl ProjectItem::clipUrl() const
+{
     if (m_clipType != COLOR && m_clipType != VIRTUAL && m_clipType != UNKNOWN && m_clipType != FOLDER)
         return KUrl(m_clip->getProperty("resource"));
     else return KUrl();
 }
 
-void ProjectItem::changeDuration(int frames) {
+void ProjectItem::changeDuration(int frames)
+{
     setData(1, DurationRole, Timecode::getEasyTimecode(GenTime(frames, KdenliveSettings::project_fps()), KdenliveSettings::project_fps()));
 }
 
-void ProjectItem::setProperties(QMap <QString, QString> props) {
+void ProjectItem::setProperties(QMap <QString, QString> props)
+{
     if (m_clip == NULL) return;
     m_clip->setProperties(props);
 }
 
-QString ProjectItem::getClipHash() const {
+QString ProjectItem::getClipHash() const
+{
     if (m_clip == NULL) return QString();
     return m_clip->getClipHash();
 }
 
-void ProjectItem::setProperty(const QString &key, const QString &value) {
+void ProjectItem::setProperty(const QString &key, const QString &value)
+{
     if (m_clip == NULL) return;
     m_clip->setProperty(key, value);
 }
 
-void ProjectItem::clearProperty(const QString &key) {
+void ProjectItem::clearProperty(const QString &key)
+{
     if (m_clip == NULL) return;
     m_clip->clearProperty(key);
 }
 
-const QString ProjectItem::groupName() const {
+const QString ProjectItem::groupName() const
+{
     return m_groupname;
 }
 
-void ProjectItem::setGroupName(const QString name) {
+void ProjectItem::setGroupName(const QString name)
+{
     m_groupname = name;
     setText(1, name);
 }
 
-DocClipBase *ProjectItem::referencedClip() {
+DocClipBase *ProjectItem::referencedClip()
+{
     return m_clip;
 }
 
-void ProjectItem::slotSetToolTip() {
+void ProjectItem::slotSetToolTip()
+{
     QString tip = "<b>";
     switch (m_clipType) {
     case AUDIO:
@@ -180,10 +204,10 @@ void ProjectItem::slotSetToolTip() {
         tip.append(i18n("Image clip") + "</b><br />" + clipUrl().path());
         break;
     case TEXT:
-        tip.append(i18n("Text clip"));
+        tip.append(i18n("Text clip") + "</b><br />" + clipUrl().path());
         break;
     case SLIDESHOW:
-        tip.append(i18n("Slideshow clip"));
+        tip.append(i18n("Slideshow clip") + "</b><br />" + clipUrl().directory());
         break;
     case VIRTUAL:
         tip.append(i18n("Virtual clip"));
@@ -200,13 +224,12 @@ void ProjectItem::slotSetToolTip() {
 }
 
 
-void ProjectItem::setProperties(const QMap < QString, QString > &attributes, const QMap < QString, QString > &metadata) {
+void ProjectItem::setProperties(const QMap < QString, QString > &attributes, const QMap < QString, QString > &metadata)
+{
     if (m_clip == NULL) return;
     //setFlags(Qt::ItemIsSelectable | Qt::ItemIsEditable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled);
     if (attributes.contains("duration")) {
-        //if (m_clipType == AUDIO || m_clipType == VIDEO || m_clipType == AV)
-        //m_clip->setProperty("duration", attributes["duration"]);
-        GenTime duration = GenTime(attributes["duration"].toInt(), KdenliveSettings::project_fps());
+        GenTime duration = GenTime(attributes.value("duration").toInt(), KdenliveSettings::project_fps());
         setData(1, DurationRole, Timecode::getEasyTimecode(duration, KdenliveSettings::project_fps()));
         m_clip->setDuration(duration);
         //kDebug() << "//// LOADED CLIP, DURATIONÂ SET TO: " << duration.frames(KdenliveSettings::project_fps());
@@ -218,18 +241,13 @@ void ProjectItem::setProperties(const QMap < QString, QString > &attributes, con
     //extend attributes -reh
 
     if (m_clipType == UNKNOWN) {
-        if (attributes.contains("type")) {
-            if (attributes["type"] == "audio")
-                m_clipType = AUDIO;
-            else if (attributes["type"] == "video")
-                m_clipType = VIDEO;
-            else if (attributes["type"] == "av")
-                m_clipType = AV;
-            else if (attributes["type"] == "playlist")
-                m_clipType = PLAYLIST;
-        } else {
-            m_clipType = AV;
-        }
+        QString cliptype = attributes.value("type");
+        if (cliptype == "audio") m_clipType = AUDIO;
+        else if (cliptype == "video") m_clipType = VIDEO;
+        else if (cliptype == "av") m_clipType = AV;
+        else if (cliptype == "playlist") m_clipType = PLAYLIST;
+        else m_clipType = AV;
+
         m_clip->setClipType(m_clipType);
         slotSetToolTip();
     }
@@ -239,10 +257,10 @@ void ProjectItem::setProperties(const QMap < QString, QString > &attributes, con
 
     if (m_clip->description().isEmpty()) {
         if (metadata.contains("description")) {
-            m_clip->setProperty("description", metadata["description"]);
+            m_clip->setProperty("description", metadata.value("description"));
             setText(2, m_clip->description());
         } else if (metadata.contains("comment")) {
-            m_clip->setProperty("description", metadata["comment"]);
+            m_clip->setProperty("description", metadata.value("comment"));
             setText(2, m_clip->description());
         }
     }
