@@ -17,25 +17,6 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
-
-#include <QMouseEvent>
-#include <QStylePainter>
-#include <QPixmap>
-#include <QIcon>
-#include <QDialog>
-#include <QtGui>
-
-#include <KDebug>
-#include <KAction>
-#include <KLocale>
-#include <KFileDialog>
-#include <KInputDialog>
-#include <KMessageBox>
-
-#include <nepomuk/global.h>
-#include <nepomuk/resourcemanager.h>
-//#include <nepomuk/tag.h>
-
 #include "projectlist.h"
 #include "projectitem.h"
 #include "addfoldercommand.h"
@@ -53,47 +34,72 @@
 #include "editclipcommand.h"
 #include "editfoldercommand.h"
 
-ProjectList::ProjectList(QWidget *parent)
-        : QWidget(parent), m_render(NULL), m_fps(-1), m_commandStack(NULL), m_selectedItem(NULL), m_infoQueue(QMap <QString, QDomElement> ()), m_thumbnailQueue(QList <QString> ()), m_refreshed(false) {
 
-    QWidget *vbox = new QWidget;
-    listView = new ProjectListView(this);;
+#include <KDebug>
+#include <KAction>
+#include <KLocale>
+#include <KFileDialog>
+#include <KInputDialog>
+#include <KMessageBox>
+
+#include <nepomuk/global.h>
+#include <nepomuk/resourcemanager.h>
+//#include <nepomuk/tag.h>
+
+#include <QMouseEvent>
+#include <QStylePainter>
+#include <QPixmap>
+#include <QIcon>
+#include <QMenu>
+#include <QProcess>
+#include <QHeaderView>
+
+ProjectList::ProjectList(QWidget *parent) :
+        QWidget(parent),
+        m_render(NULL),
+        m_fps(-1),
+        m_commandStack(NULL),
+        m_editAction(NULL),
+        m_deleteAction(NULL),
+        m_openAction(NULL),
+        m_reloadAction(NULL),
+        m_selectedItem(NULL),
+        m_refreshed(false),
+        m_infoQueue(),
+        m_thumbnailQueue()
+{
+
+    m_listView = new ProjectListView(this);;
     QVBoxLayout *layout = new QVBoxLayout;
     layout->setContentsMargins(0, 0, 0, 0);
-    // mbd: I think this has died at some point: m_clipIdCounter = 0;
+
     // setup toolbar
-    searchView = new KTreeWidgetSearchLine(this);
+    KTreeWidgetSearchLine *searchView = new KTreeWidgetSearchLine(this);
     m_toolbar = new QToolBar("projectToolBar", this);
     m_toolbar->addWidget(searchView);
+    searchView->setTreeWidget(m_listView);
 
     m_addButton = new QToolButton(m_toolbar);
     m_addButton->setPopupMode(QToolButton::MenuButtonPopup);
     m_toolbar->addWidget(m_addButton);
 
-    m_deleteAction = m_toolbar->addAction(KIcon("edit-delete"), i18n("Delete Clip"));
-    connect(m_deleteAction, SIGNAL(triggered()), this, SLOT(slotRemoveClip()));
-
-    m_editAction = m_toolbar->addAction(KIcon("document-properties"), i18n("Edit Clip"));
-    connect(m_editAction, SIGNAL(triggered()), this, SLOT(slotEditClip()));
-
     layout->addWidget(m_toolbar);
-    layout->addWidget(listView);
+    layout->addWidget(m_listView);
     setLayout(layout);
-    //m_toolbar->setEnabled(false);
+    
 
-    searchView->setTreeWidget(listView);
 
-    connect(listView, SIGNAL(itemSelectionChanged()), this, SLOT(slotClipSelected()));
-    connect(listView, SIGNAL(focusMonitor()), this, SLOT(slotClipSelected()));
-    connect(listView, SIGNAL(pauseMonitor()), this, SLOT(slotPauseMonitor()));
-    connect(listView, SIGNAL(requestMenu(const QPoint &, QTreeWidgetItem *)), this, SLOT(slotContextMenu(const QPoint &, QTreeWidgetItem *)));
-    connect(listView, SIGNAL(addClip()), this, SLOT(slotAddClip()));
-    connect(listView, SIGNAL(addClip(KUrl, const QString &)), this, SLOT(slotAddClip(KUrl, const QString &)));
-    connect(listView, SIGNAL(itemChanged(QTreeWidgetItem *, int)), this, SLOT(slotItemEdited(QTreeWidgetItem *, int)));
-    connect(listView, SIGNAL(showProperties(DocClipBase *)), this, SIGNAL(showClipProperties(DocClipBase *)));
+    connect(m_listView, SIGNAL(itemSelectionChanged()), this, SLOT(slotClipSelected()));
+    connect(m_listView, SIGNAL(focusMonitor()), this, SLOT(slotClipSelected()));
+    connect(m_listView, SIGNAL(pauseMonitor()), this, SLOT(slotPauseMonitor()));
+    connect(m_listView, SIGNAL(requestMenu(const QPoint &, QTreeWidgetItem *)), this, SLOT(slotContextMenu(const QPoint &, QTreeWidgetItem *)));
+    connect(m_listView, SIGNAL(addClip()), this, SLOT(slotAddClip()));
+    connect(m_listView, SIGNAL(addClip(const QList <QUrl>, const QString &)), this, SLOT(slotAddClip(const QList <QUrl>, const QString &)));
+    connect(m_listView, SIGNAL(itemChanged(QTreeWidgetItem *, int)), this, SLOT(slotItemEdited(QTreeWidgetItem *, int)));
+    connect(m_listView, SIGNAL(showProperties(DocClipBase *)), this, SIGNAL(showClipProperties(DocClipBase *)));
 
-    ItemDelegate *listViewDelegate = new ItemDelegate(listView);
-    listView->setItemDelegate(listViewDelegate);
+    ItemDelegate *listViewDelegate = new ItemDelegate(m_listView);
+    m_listView->setItemDelegate(listViewDelegate);
 
     if (KdenliveSettings::activate_nepomuk()) {
         Nepomuk::ResourceManager::instance()->init();
@@ -104,19 +110,47 @@ ProjectList::ProjectList(QWidget *parent)
     }
 }
 
-ProjectList::~ProjectList() {
+ProjectList::~ProjectList()
+{
     delete m_menu;
     delete m_toolbar;
 }
 
-void ProjectList::setupMenu(QMenu *addMenu, QAction *defaultAction) {
-    m_addButton->setMenu(addMenu);
+void ProjectList::setupMenu(QMenu *addMenu, QAction *defaultAction)
+{
+    QList <QAction *> actions = addMenu->actions();
+    for (int i = 0; i < actions.count(); i++) {
+        if (actions.at(i)->data().toString() == "clip_properties") {
+            m_editAction = actions.at(i);
+            m_toolbar->addAction(m_editAction);
+            actions.removeAt(i);
+            i--;
+        } else if (actions.at(i)->data().toString() == "delete_clip") {
+            m_deleteAction = actions.at(i);
+            m_toolbar->addAction(m_deleteAction);
+            actions.removeAt(i);
+            i--;
+        } else if (actions.at(i)->data().toString() == "edit_clip") {
+            m_openAction = actions.at(i);
+            actions.removeAt(i);
+            i--;
+        } else if (actions.at(i)->data().toString() == "reload_clip") {
+            m_reloadAction = actions.at(i);
+            actions.removeAt(i);
+            i--;
+        }
+    }
+
+    QMenu *m = new QMenu();
+    m->addActions(actions);
+    m_addButton->setMenu(m);
     m_addButton->setDefaultAction(defaultAction);
     m_menu = new QMenu();
     m_menu->addActions(addMenu->actions());
 }
 
-void ProjectList::setupGeneratorMenu(QMenu *addMenu) {
+void ProjectList::setupGeneratorMenu(QMenu *addMenu)
+{
     if (!addMenu) return;
     QMenu *menu = m_addButton->menu();
     menu->addMenu(addMenu);
@@ -124,56 +158,100 @@ void ProjectList::setupGeneratorMenu(QMenu *addMenu) {
 
     m_menu->addMenu(addMenu);
     if (addMenu->isEmpty()) addMenu->setEnabled(false);
+    m_menu->addAction(m_reloadAction);
     m_menu->addAction(m_editAction);
+    m_menu->addAction(m_openAction);
     m_menu->addAction(m_deleteAction);
     m_menu->insertSeparator(m_deleteAction);
 }
 
 
-QByteArray ProjectList::headerInfo() {
-    return listView->header()->saveState();
+QByteArray ProjectList::headerInfo()
+{
+    return m_listView->header()->saveState();
 }
 
-void ProjectList::setHeaderInfo(const QByteArray &state) {
-    listView->header()->restoreState(state);
+void ProjectList::setHeaderInfo(const QByteArray &state)
+{
+    m_listView->header()->restoreState(state);
 }
 
-void ProjectList::slotEditClip() {
-    ProjectItem *item = static_cast <ProjectItem*>(listView->currentItem());
+void ProjectList::slotEditClip()
+{
+    ProjectItem *item = static_cast <ProjectItem*>(m_listView->currentItem());
+    if (!(item->flags() & Qt::ItemIsDragEnabled)) return;
     if (item && !item->isGroup()) {
         emit clipSelected(item->referencedClip());
         emit showClipProperties(item->referencedClip());
     }
 }
 
-
-
-void ProjectList::setRenderer(Render *projectRender) {
-    m_render = projectRender;
-    listView->setIconSize(QSize(40 * m_render->dar(), 40));
+void ProjectList::slotOpenClip()
+{
+    ProjectItem *item = static_cast <ProjectItem*>(m_listView->currentItem());
+    if (item && !item->isGroup()) {
+        if (item->clipType() == IMAGE) {
+            if (KdenliveSettings::defaultimageapp().isEmpty()) KMessageBox::sorry(this, i18n("Please set a default application to open images in the Settings dialog"));
+            else QProcess::startDetached(KdenliveSettings::defaultimageapp(), QStringList() << item->clipUrl().path());
+        }
+        if (item->clipType() == AUDIO) {
+            if (KdenliveSettings::defaultaudioapp().isEmpty()) KMessageBox::sorry(this, i18n("Please set a default application to open audio files in the Settings dialog"));
+            else QProcess::startDetached(KdenliveSettings::defaultaudioapp(), QStringList() << item->clipUrl().path());
+        }
+    }
 }
 
-void ProjectList::slotClipSelected() {
-    if (listView->currentItem()) {
-        ProjectItem *clip = static_cast <ProjectItem*>(listView->currentItem());
+void ProjectList::slotReloadClip()
+{
+    ProjectItem *item = static_cast <ProjectItem*>(m_listView->currentItem());
+    if (item && !item->isGroup()) {
+        if (item->clipType() == IMAGE) {
+            item->referencedClip()->producer()->set("force_reload", 1);
+        }
+        emit getFileProperties(item->toXml(), item->clipId(), false);
+    }
+}
+
+void ProjectList::setRenderer(Render *projectRender)
+{
+    m_render = projectRender;
+    m_listView->setIconSize(QSize(40 * m_render->dar(), 40));
+}
+
+void ProjectList::slotClipSelected()
+{
+    if (m_listView->currentItem()) {
+        ProjectItem *clip = static_cast <ProjectItem*>(m_listView->currentItem());
         if (!clip->isGroup()) {
             m_selectedItem = clip;
             emit clipSelected(clip->referencedClip());
         }
         m_editAction->setEnabled(true);
         m_deleteAction->setEnabled(true);
+        m_reloadAction->setEnabled(true);
+        if (clip->clipType() == IMAGE && !KdenliveSettings::defaultimageapp().isEmpty()) {
+            m_openAction->setIcon(KIcon(KdenliveSettings::defaultimageapp()));
+            m_openAction->setEnabled(true);
+        } else if (clip->clipType() == AUDIO && !KdenliveSettings::defaultaudioapp().isEmpty()) {
+            m_openAction->setIcon(KIcon(KdenliveSettings::defaultaudioapp()));
+            m_openAction->setEnabled(true);
+        } else m_openAction->setEnabled(false);
     } else {
         emit clipSelected(NULL);
         m_editAction->setEnabled(false);
         m_deleteAction->setEnabled(false);
+        m_openAction->setEnabled(false);
+        m_reloadAction->setEnabled(false);
     }
 }
 
-void ProjectList::slotPauseMonitor() {
+void ProjectList::slotPauseMonitor()
+{
     if (m_render) m_render->pause();
 }
 
-void ProjectList::slotUpdateClipProperties(const QString &id, QMap <QString, QString> properties) {
+void ProjectList::slotUpdateClipProperties(const QString &id, QMap <QString, QString> properties)
+{
     ProjectItem *item = getItemById(id);
     if (item) {
         slotUpdateClipProperties(item, properties);
@@ -182,20 +260,21 @@ void ProjectList::slotUpdateClipProperties(const QString &id, QMap <QString, QSt
     }
 }
 
-void ProjectList::slotUpdateClipProperties(ProjectItem *clip, QMap <QString, QString> properties) {
+void ProjectList::slotUpdateClipProperties(ProjectItem *clip, QMap <QString, QString> properties)
+{
     if (!clip) return;
     if (!clip->isGroup()) clip->setProperties(properties);
     if (properties.contains("name")) {
-        listView->blockSignals(true);
+        m_listView->blockSignals(true);
         clip->setText(1, properties.value("name"));
-        listView->blockSignals(false);
+        m_listView->blockSignals(false);
         emit clipNameChanged(clip->clipId(), properties.value("name"));
     }
     if (properties.contains("description")) {
         CLIPTYPE type = clip->clipType();
-        listView->blockSignals(true);
+        m_listView->blockSignals(true);
         clip->setText(2, properties.value("description"));
-        listView->blockSignals(false);
+        m_listView->blockSignals(false);
         if (KdenliveSettings::activate_nepomuk() && (type == AUDIO || type == VIDEO || type == AV || type == IMAGE || type == PLAYLIST)) {
             // Use Nepomuk system to store clip description
             Nepomuk::Resource f(clip->clipUrl().path());
@@ -205,7 +284,8 @@ void ProjectList::slotUpdateClipProperties(ProjectItem *clip, QMap <QString, QSt
     }
 }
 
-void ProjectList::slotItemEdited(QTreeWidgetItem *item, int column) {
+void ProjectList::slotItemEdited(QTreeWidgetItem *item, int column)
+{
     ProjectItem *clip = static_cast <ProjectItem*>(item);
     if (column == 2) {
         if (clip->referencedClip()) {
@@ -242,21 +322,34 @@ void ProjectList::slotItemEdited(QTreeWidgetItem *item, int column) {
     }
 }
 
-void ProjectList::slotContextMenu(const QPoint &pos, QTreeWidgetItem *item) {
+void ProjectList::slotContextMenu(const QPoint &pos, QTreeWidgetItem *item)
+{
     bool enable = false;
     if (item) {
         enable = true;
     }
     m_editAction->setEnabled(enable);
     m_deleteAction->setEnabled(enable);
+    m_reloadAction->setEnabled(enable);
+    if (enable) {
+        ProjectItem *clip = static_cast <ProjectItem*>(item);
+        if (clip->clipType() == IMAGE && !KdenliveSettings::defaultimageapp().isEmpty()) {
+            m_openAction->setIcon(KIcon(KdenliveSettings::defaultimageapp()));
+            m_openAction->setEnabled(true);
+        } else if (clip->clipType() == AUDIO && !KdenliveSettings::defaultaudioapp().isEmpty()) {
+            m_openAction->setIcon(KIcon(KdenliveSettings::defaultaudioapp()));
+            m_openAction->setEnabled(true);
+        } else m_openAction->setEnabled(false);
+    } else m_openAction->setEnabled(false);
     m_menu->popup(pos);
 }
 
-void ProjectList::slotRemoveClip() {
-    if (!listView->currentItem()) return;
+void ProjectList::slotRemoveClip()
+{
+    if (!m_listView->currentItem()) return;
     QList <QString> ids;
     QMap <QString, QString> folderids;
-    QList<QTreeWidgetItem *> selected = listView->selectedItems();
+    QList<QTreeWidgetItem *> selected = m_listView->selectedItems();
     ProjectItem *item;
     for (int i = 0; i < selected.count(); i++) {
         item = static_cast <ProjectItem *>(selected.at(i));
@@ -275,42 +368,47 @@ void ProjectList::slotRemoveClip() {
     }
     if (!ids.isEmpty()) m_doc->deleteProjectClip(ids);
     if (!folderids.isEmpty()) deleteProjectFolder(folderids);
-    if (listView->topLevelItemCount() == 0) {
+    if (m_listView->topLevelItemCount() == 0) {
         m_editAction->setEnabled(false);
         m_deleteAction->setEnabled(false);
+        m_openAction->setEnabled(false);
+        m_reloadAction->setEnabled(false);
     }
 }
 
-void ProjectList::selectItemById(const QString &clipId) {
+void ProjectList::selectItemById(const QString &clipId)
+{
     ProjectItem *item = getItemById(clipId);
-    if (item) listView->setCurrentItem(item);
+    if (item) m_listView->setCurrentItem(item);
 }
 
 
-void ProjectList::slotDeleteClip(const QString &clipId) {
+void ProjectList::slotDeleteClip(const QString &clipId)
+{
     ProjectItem *item = getItemById(clipId);
-    QTreeWidgetItem *p = item->parent();
-    if (p) {
-        kDebug() << "///////  DELETED CLIP HAS A PARENT... " << p->indexOfChild(item);
-        QTreeWidgetItem *clone = p->takeChild(p->indexOfChild(item));
-    } else if (item) {
-        delete item;
+    if (!item) {
+        kDebug() << "/// Cannot find clip to delete";
+        return;
     }
+    delete item;
 }
 
 
-void ProjectList::editFolder(const QString folderName, const QString oldfolderName, const QString &clipId) {
+void ProjectList::editFolder(const QString folderName, const QString oldfolderName, const QString &clipId)
+{
     EditFolderCommand *command = new EditFolderCommand(this, folderName, oldfolderName, clipId, false);
     m_commandStack->push(command);
     m_doc->setModified(true);
 }
 
-void ProjectList::slotAddFolder() {
+void ProjectList::slotAddFolder()
+{
     AddFolderCommand *command = new AddFolderCommand(this, i18n("Folder"), QString::number(m_doc->clipManager()->getFreeFolderId()), true);
     m_commandStack->push(command);
 }
 
-void ProjectList::slotAddFolder(const QString foldername, const QString &clipId, bool remove, bool edit) {
+void ProjectList::slotAddFolder(const QString foldername, const QString &clipId, bool remove, bool edit)
+{
     if (remove) {
         ProjectItem *item = getFolderItemById(clipId);
         if (item) {
@@ -320,11 +418,11 @@ void ProjectList::slotAddFolder(const QString foldername, const QString &clipId,
     } else {
         if (edit) {
             ProjectItem *item = getFolderItemById(clipId);
-            QTreeWidgetItemIterator it(listView);
+            QTreeWidgetItemIterator it(m_listView);
             if (item) {
-                listView->blockSignals(true);
+                m_listView->blockSignals(true);
                 item->setGroupName(foldername);
-                listView->blockSignals(false);
+                m_listView->blockSignals(false);
                 m_doc->clipManager()->addFolder(clipId, foldername);
                 const int children = item->childCount();
                 for (int i = 0; i < children; i++) {
@@ -335,17 +433,18 @@ void ProjectList::slotAddFolder(const QString foldername, const QString &clipId,
         } else {
             QStringList text;
             text << QString() << foldername;
-            listView->blockSignals(true);
-            (void) new ProjectItem(listView, text, clipId);
+            m_listView->blockSignals(true);
+            (void) new ProjectItem(m_listView, text, clipId);
             m_doc->clipManager()->addFolder(clipId, foldername);
-            listView->blockSignals(false);
+            m_listView->blockSignals(false);
         }
     }
 }
 
 
 
-void ProjectList::deleteProjectFolder(QMap <QString, QString> map) {
+void ProjectList::deleteProjectFolder(QMap <QString, QString> map)
+{
     QMapIterator<QString, QString> i(map);
     QUndoCommand *delCommand = new QUndoCommand();
     delCommand->setText(i18n("Delete Folder"));
@@ -357,9 +456,10 @@ void ProjectList::deleteProjectFolder(QMap <QString, QString> map) {
     m_doc->setModified(true);
 }
 
-void ProjectList::slotAddClip(DocClipBase *clip, bool getProperties) {
-    if (getProperties) listView->setEnabled(false);
-    listView->blockSignals(true);
+void ProjectList::slotAddClip(DocClipBase *clip, bool getProperties)
+{
+    if (getProperties) m_listView->setEnabled(false);
+    m_listView->blockSignals(true);
     const QString parent = clip->getProperty("groupid");
     kDebug() << "Adding clip with groupid: " << parent;
     ProjectItem *item = NULL;
@@ -371,13 +471,13 @@ void ProjectList::slotAddClip(DocClipBase *clip, bool getProperties) {
             //kDebug() << "Adding clip to new group: " << groupName;
             if (groupName.isEmpty()) groupName = i18n("Folder");
             text << QString() << groupName;
-            parentitem = new ProjectItem(listView, text, parent);
+            parentitem = new ProjectItem(m_listView, text, parent);
         } else {
             //kDebug() << "Adding clip to existing group: " << parentitem->groupName();
         }
         if (parentitem) item = new ProjectItem(parentitem, clip);
     }
-    if (item == NULL) item = new ProjectItem(listView, clip);
+    if (item == NULL) item = new ProjectItem(m_listView, clip);
 
     KUrl url = clip->fileURL();
     if (!url.isEmpty() && KdenliveSettings::activate_nepomuk()) {
@@ -387,27 +487,30 @@ void ProjectList::slotAddClip(DocClipBase *clip, bool getProperties) {
         if (!annotation.isEmpty()) item->setText(2, annotation);
         item->setText(3, QString::number(f.rating()));
     }
-    listView->blockSignals(false);
+    m_listView->blockSignals(false);
 }
 
-void ProjectList::slotResetProjectList() {
-    listView->clear();
+void ProjectList::slotResetProjectList()
+{
+    m_listView->clear();
     emit clipSelected(NULL);
     m_thumbnailQueue.clear();
     m_infoQueue.clear();
     m_refreshed = false;
 }
 
-void ProjectList::requestClipInfo(const QDomElement xml, const QString id) {
+void ProjectList::requestClipInfo(const QDomElement xml, const QString id)
+{
     kDebug() << " PRG LIST REQUEST CLP INFO: " << id;
     m_infoQueue.insert(id, xml);
-    listView->setEnabled(false);
+    m_listView->setEnabled(false);
     if (m_infoQueue.count() == 1) QTimer::singleShot(300, this, SLOT(slotProcessNextClipInQueue()));
 }
 
-void ProjectList::slotProcessNextClipInQueue() {
+void ProjectList::slotProcessNextClipInQueue()
+{
     if (m_infoQueue.isEmpty()) {
-        listView->setEnabled(true);
+        m_listView->setEnabled(true);
         return;
     }
     QMap<QString, QDomElement>::const_iterator i = m_infoQueue.constBegin();
@@ -415,20 +518,22 @@ void ProjectList::slotProcessNextClipInQueue() {
         const QDomElement dom = i.value();
         const QString id = i.key();
         m_infoQueue.remove(i.key());
-        emit getFileProperties(dom, id);
+        emit getFileProperties(dom, id, true);
     }
-    if (m_infoQueue.isEmpty()) listView->setEnabled(true);
+    if (m_infoQueue.isEmpty()) m_listView->setEnabled(true);
 }
 
-void ProjectList::slotUpdateClip(const QString &id) {
+void ProjectList::slotUpdateClip(const QString &id)
+{
     ProjectItem *item = getItemById(id);
-    listView->blockSignals(true);
+    m_listView->blockSignals(true);
     if (item) item->setData(1, UsageRole, QString::number(item->numReferences()));
-    listView->blockSignals(false);
+    m_listView->blockSignals(false);
 }
 
-void ProjectList::updateAllClips() {
-    QTreeWidgetItemIterator it(listView);
+void ProjectList::updateAllClips()
+{
+    QTreeWidgetItemIterator it(m_listView);
     while (*it) {
         ProjectItem *item = static_cast <ProjectItem *>(*it);
         if (!item->isGroup()) {
@@ -444,22 +549,26 @@ void ProjectList::updateAllClips() {
                     pix.save(clip->fileURL().path());
                     delete dia_ui;
                 }
-                requestClipInfo(clip->toXML(), clip->getId());
+                if (clip->isPlaceHolder() == false) requestClipInfo(clip->toXML(), clip->getId());
+                else item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
             } else {
                 QString cachedPixmap = m_doc->projectFolder().path() + "/thumbs/" + item->getClipHash() + ".png";
                 if (QFile::exists(cachedPixmap)) {
                     //kDebug()<<"// USING CACHED PIX: "<<cachedPixmap;
-                    listView->blockSignals(true);
+                    m_listView->blockSignals(true);
                     item->setIcon(0, QPixmap(cachedPixmap));
-                    listView->blockSignals(false);
+                    m_listView->blockSignals(false);
                 } else requestClipThumbnail(item->clipId());
-                listView->blockSignals(true);
-                item->changeDuration(item->referencedClip()->producer()->get_playtime());
-                listView->blockSignals(false);
+
+                if (item->data(1, DurationRole).toString().isEmpty()) {
+                    m_listView->blockSignals(true);
+                    item->changeDuration(item->referencedClip()->producer()->get_playtime());
+                    m_listView->blockSignals(false);
+                }
             }
-            listView->blockSignals(true);
+            m_listView->blockSignals(true);
             item->setData(1, UsageRole, QString::number(item->numReferences()));
-            listView->blockSignals(false);
+            m_listView->blockSignals(false);
             qApp->processEvents();
         }
         ++it;
@@ -467,17 +576,35 @@ void ProjectList::updateAllClips() {
     QTimer::singleShot(500, this, SLOT(slotCheckForEmptyQueue()));
 }
 
-void ProjectList::slotAddClip(KUrl givenUrl, QString group) {
+void ProjectList::slotAddClip(const QList <QUrl> givenList, QString group)
+{
     if (!m_commandStack) kDebug() << "!!!!!!!!!!!!!!!! NO CMD STK";
     KUrl::List list;
-    if (givenUrl.isEmpty()) {
-        list = KFileDialog::getOpenUrls(KUrl("kfiledialog:///clipfolder"), "application/x-kdenlive video/x-flv application/vnd.rn-realmedia video/x-dv video/dv video/x-msvideo video/mpeg video/x-ms-wmv audio/mpeg audio/x-mp3 audio/x-wav application/ogg video/mp4 video/quicktime image/gif image/jpeg image/png image/x-bmp image/svg+xml image/tiff image/x-xcf-gimp image/x-vnd.adobe.photoshop image/x-pcx image/x-exr video/mlt-playlist audio/x-flac audio/mp4", this);
-    } else list.append(givenUrl);
+    if (givenList.isEmpty()) {
+        // Build list of mime types
+        QStringList mimeTypes = QStringList() << "application/x-kdenlive" << "video/x-flv" << "application/vnd.rn-realmedia" << "video/x-dv" << "video/dv" << "video/x-msvideo" << "video/mpeg" << "video/x-ms-wmv" << "audio/mpeg" << "audio/x-mp3" << "audio/x-wav" << "application/ogg" << "video/mp4" << "video/quicktime" << "image/gif" << "image/jpeg" << "image/png" << "image/x-tga" << "image/x-bmp" << "image/svg+xml" << "image/tiff" << "image/x-xcf-gimp" << "image/x-vnd.adobe.photoshop" << "image/x-pcx" << "image/x-exr" << "video/mlt-playlist" << "audio/x-flac" << "audio/mp4" << "video/x-matroska" << "audio/x-matroska";
+
+        QString allExtensions;
+        foreach(const QString& mimeType, mimeTypes) {
+            KMimeType::Ptr mime(KMimeType::mimeType(mimeType));
+            if (mime) {
+                allExtensions.append(mime->patterns().join(" "));
+                allExtensions.append(' ');
+            }
+        }
+        QString dialogFilter = allExtensions + ' ' + QLatin1Char('|') + i18n("All Supported Files");
+        dialogFilter.append("\n*" + QLatin1Char('|') + i18n("All Files"));
+        list = KFileDialog::getOpenUrls(KUrl("kfiledialog:///clipfolder"), dialogFilter, this);
+
+    } else {
+        for (int i = 0; i < givenList.count(); i++)
+            list << givenList.at(i);
+    }
     if (list.isEmpty()) return;
 
-    QString groupId = QString();
+    QString groupId;
     if (group.isEmpty()) {
-        ProjectItem *item = static_cast <ProjectItem*>(listView->currentItem());
+        ProjectItem *item = static_cast <ProjectItem*>(m_listView->currentItem());
         if (item && !item->isGroup()) {
             while (item->parent()) {
                 item = static_cast <ProjectItem*>(item->parent());
@@ -492,7 +619,8 @@ void ProjectList::slotAddClip(KUrl givenUrl, QString group) {
     m_doc->slotAddClipList(list, group, groupId);
 }
 
-void ProjectList::slotRemoveInvalidClip(const QString &id) {
+void ProjectList::slotRemoveInvalidClip(const QString &id)
+{
     ProjectItem *item = getItemById(id);
     if (item) {
         const QString path = item->referencedClip()->fileURL().path();
@@ -502,10 +630,11 @@ void ProjectList::slotRemoveInvalidClip(const QString &id) {
         m_doc->deleteProjectClip(ids);
     }
     if (!m_infoQueue.isEmpty()) QTimer::singleShot(300, this, SLOT(slotProcessNextClipInQueue()));
-    else listView->setEnabled(true);
+    else m_listView->setEnabled(true);
 }
 
-void ProjectList::slotAddColorClip() {
+void ProjectList::slotAddColorClip()
+{
     if (!m_commandStack) kDebug() << "!!!!!!!!!!!!!!!! NO CMD STK";
     QDialog *dia = new QDialog(this);
     Ui::ColorClip_UI *dia_ui = new Ui::ColorClip_UI();
@@ -516,9 +645,9 @@ void ProjectList::slotAddColorClip() {
         QString color = dia_ui->clip_color->color().name();
         color = color.replace(0, 1, "0x") + "ff";
 
-        QString group = QString();
-        QString groupId = QString();
-        ProjectItem *item = static_cast <ProjectItem*>(listView->currentItem());
+        QString group;
+        QString groupId;
+        ProjectItem *item = static_cast <ProjectItem*>(m_listView->currentItem());
         if (item && !item->isGroup()) {
             while (item->parent()) {
                 item = static_cast <ProjectItem*>(item->parent());
@@ -530,22 +659,24 @@ void ProjectList::slotAddColorClip() {
             groupId = item->clipId();
         }
 
-        m_doc->slotAddColorClipFile(dia_ui->clip_name->text(), color, dia_ui->clip_duration->text(), group, groupId);
+        m_doc->clipManager()->slotAddColorClipFile(dia_ui->clip_name->text(), color, dia_ui->clip_duration->text(), group, groupId);
+        m_doc->setModified(true);
     }
     delete dia_ui;
     delete dia;
 }
 
 
-void ProjectList::slotAddSlideshowClip() {
+void ProjectList::slotAddSlideshowClip()
+{
     if (!m_commandStack) kDebug() << "!!!!!!!!!!!!!!!! NO CMD STK";
     SlideshowClip *dia = new SlideshowClip(this);
 
     if (dia->exec() == QDialog::Accepted) {
 
-        QString group = QString();
-        QString groupId = QString();
-        ProjectItem *item = static_cast <ProjectItem*>(listView->currentItem());
+        QString group;
+        QString groupId;
+        ProjectItem *item = static_cast <ProjectItem*>(m_listView->currentItem());
         if (item && !item->isGroup()) {
             while (item->parent()) {
                 item = static_cast <ProjectItem*>(item->parent());
@@ -557,15 +688,17 @@ void ProjectList::slotAddSlideshowClip() {
             groupId = item->clipId();
         }
 
-        m_doc->slotAddSlideshowClipFile(dia->clipName(), dia->selectedPath(), dia->imageCount(), dia->clipDuration(), dia->loop(), dia->fade(), dia->lumaDuration(), dia->lumaFile(), dia->softness(), group, groupId);
+        m_doc->clipManager()->slotAddSlideshowClipFile(dia->clipName(), dia->selectedPath(), dia->imageCount(), dia->clipDuration(), dia->loop(), dia->fade(), dia->lumaDuration(), dia->lumaFile(), dia->softness(), group, groupId);
+        m_doc->setModified(true);
     }
     delete dia;
 }
 
-void ProjectList::slotAddTitleClip() {
-    QString group = QString();
-    QString groupId = QString();
-    ProjectItem *item = static_cast <ProjectItem*>(listView->currentItem());
+void ProjectList::slotAddTitleClip()
+{
+    QString group;
+    QString groupId;
+    ProjectItem *item = static_cast <ProjectItem*>(m_listView->currentItem());
     if (item && !item->isGroup()) {
         while (item->parent()) {
             item = static_cast <ProjectItem*>(item->parent());
@@ -580,9 +713,10 @@ void ProjectList::slotAddTitleClip() {
     m_doc->slotCreateTextClip(group, groupId);
 }
 
-void ProjectList::setDocument(KdenliveDoc *doc) {
-    listView->blockSignals(true);
-    listView->clear();
+void ProjectList::setDocument(KdenliveDoc *doc)
+{
+    m_listView->blockSignals(true);
+    m_listView->clear();
     emit clipSelected(NULL);
     m_thumbnailQueue.clear();
     m_infoQueue.clear();
@@ -591,7 +725,7 @@ void ProjectList::setDocument(KdenliveDoc *doc) {
     QMapIterator<QString, QString> f(flist);
     while (f.hasNext()) {
         f.next();
-        (void) new ProjectItem(listView, QStringList() << QString() << f.value(), f.key());
+        (void) new ProjectItem(m_listView, QStringList() << QString() << f.value(), f.key());
     }
 
     QList <DocClipBase*> list = doc->clipManager()->documentClipList();
@@ -603,18 +737,19 @@ void ProjectList::setDocument(KdenliveDoc *doc) {
     m_timecode = doc->timecode();
     m_commandStack = doc->commandStack();
     m_doc = doc;
-    QTreeWidgetItem *first = listView->topLevelItem(0);
-    if (first) listView->setCurrentItem(first);
-    listView->blockSignals(false);
+    QTreeWidgetItem *first = m_listView->topLevelItem(0);
+    if (first) m_listView->setCurrentItem(first);
+    m_listView->blockSignals(false);
     m_toolbar->setEnabled(true);
 }
 
-QDomElement ProjectList::producersList() {
+QDomElement ProjectList::producersList()
+{
     QDomDocument doc;
     QDomElement prods = doc.createElement("producerlist");
     doc.appendChild(prods);
     kDebug() << "////////////  PRO LIST BUILD PRDSLIST ";
-    QTreeWidgetItemIterator it(listView);
+    QTreeWidgetItemIterator it(m_listView);
     while (*it) {
         if (!((ProjectItem *)(*it))->isGroup())
             prods.appendChild(doc.importNode(((ProjectItem *)(*it))->toXml(), true));
@@ -623,32 +758,37 @@ QDomElement ProjectList::producersList() {
     return prods;
 }
 
-void ProjectList::slotCheckForEmptyQueue() {
+void ProjectList::slotCheckForEmptyQueue()
+{
     if (!m_refreshed && m_thumbnailQueue.isEmpty() && m_infoQueue.isEmpty()) {
         m_refreshed = true;
         emit loadingIsOver();
     } else QTimer::singleShot(500, this, SLOT(slotCheckForEmptyQueue()));
 }
 
-void ProjectList::requestClipThumbnail(const QString &id) {
+void ProjectList::requestClipThumbnail(const QString &id)
+{
     m_thumbnailQueue.append(id);
     if (m_thumbnailQueue.count() == 1) QTimer::singleShot(300, this, SLOT(slotProcessNextThumbnail()));
 }
 
-void ProjectList::slotProcessNextThumbnail() {
+void ProjectList::slotProcessNextThumbnail()
+{
     if (m_thumbnailQueue.isEmpty()) {
         return;
     }
     slotRefreshClipThumbnail(m_thumbnailQueue.takeFirst(), false);
 }
 
-void ProjectList::slotRefreshClipThumbnail(const QString &clipId, bool update) {
+void ProjectList::slotRefreshClipThumbnail(const QString &clipId, bool update)
+{
     ProjectItem *item = getItemById(clipId);
     if (item) slotRefreshClipThumbnail(item, update);
     else slotProcessNextThumbnail();
 }
 
-void ProjectList::slotRefreshClipThumbnail(ProjectItem *item, bool update) {
+void ProjectList::slotRefreshClipThumbnail(ProjectItem *item, bool update)
+{
     if (item) {
         if (!item->referencedClip()) return;
         int height = 50;
@@ -658,42 +798,49 @@ void ProjectList::slotRefreshClipThumbnail(ProjectItem *item, bool update) {
         QPixmap pix;
         if (clip->clipType() == AUDIO) pix = KIcon("audio-x-generic").pixmap(QSize(width, height));
         else pix = item->referencedClip()->thumbProducer()->extractImage(item->referencedClip()->getClipThumbFrame(), width, height);
-        listView->blockSignals(true);
+        m_listView->blockSignals(true);
         item->setIcon(0, pix);
-        listView->blockSignals(false);
+        m_listView->blockSignals(false);
         m_doc->cachePixmap(item->getClipHash(), pix);
         if (update) emit projectModified();
         if (!m_thumbnailQueue.isEmpty()) QTimer::singleShot(300, this, SLOT(slotProcessNextThumbnail()));
     }
 }
 
-void ProjectList::slotReplyGetFileProperties(const QString &clipId, Mlt::Producer *producer, const QMap < QString, QString > &properties, const QMap < QString, QString > &metadata) {
+void ProjectList::slotReplyGetFileProperties(const QString &clipId, Mlt::Producer *producer, const QMap < QString, QString > &properties, const QMap < QString, QString > &metadata, bool replace)
+{
     ProjectItem *item = getItemById(clipId);
     if (item && producer) {
-        listView->blockSignals(true);
+        m_listView->blockSignals(true);
         item->setProperties(properties, metadata);
         Q_ASSERT_X(item->referencedClip(), "void ProjectList::slotReplyGetFileProperties", QString("Item with groupName %1 does not have a clip associated").arg(item->groupName()).toLatin1());
-        item->referencedClip()->setProducer(producer);
-        emit receivedClipDuration(clipId, item->clipMaxDuration());
-        listView->blockSignals(false);
+        if (replace) item->referencedClip()->setProducer(producer);
+        else {
+            // Check if duration changed.
+            emit receivedClipDuration(clipId);
+            delete producer;
+        }
+        m_listView->blockSignals(false);
     } else kDebug() << "////////  COULD NOT FIND CLIP TO UPDATE PRPS...";
     if (!m_infoQueue.isEmpty()) QTimer::singleShot(300, this, SLOT(slotProcessNextClipInQueue()));
-    else listView->setEnabled(true);
+    else m_listView->setEnabled(true);
 }
 
-void ProjectList::slotReplyGetImage(const QString &clipId, const QPixmap &pix) {
+void ProjectList::slotReplyGetImage(const QString &clipId, const QPixmap &pix)
+{
     ProjectItem *item = getItemById(clipId);
     if (item) {
-        listView->blockSignals(true);
+        m_listView->blockSignals(true);
         item->setIcon(0, pix);
         m_doc->cachePixmap(item->getClipHash(), pix);
-        listView->blockSignals(false);
+        m_listView->blockSignals(false);
     }
 }
 
-ProjectItem *ProjectList::getItemById(const QString &id) {
+ProjectItem *ProjectList::getItemById(const QString &id)
+{
     ProjectItem *item;
-    QTreeWidgetItemIterator it(listView);
+    QTreeWidgetItemIterator it(m_listView);
     while (*it) {
         item = static_cast<ProjectItem *>(*it);
         if (item->clipId() == id && item->clipType() != FOLDER)
@@ -703,9 +850,10 @@ ProjectItem *ProjectList::getItemById(const QString &id) {
     return NULL;
 }
 
-ProjectItem *ProjectList::getFolderItemById(const QString &id) {
+ProjectItem *ProjectList::getFolderItemById(const QString &id)
+{
     ProjectItem *item;
-    QTreeWidgetItemIterator it(listView);
+    QTreeWidgetItemIterator it(m_listView);
     while (*it) {
         item = static_cast<ProjectItem *>(*it);
         if (item->clipId() == id && item->clipType() == FOLDER)
@@ -715,13 +863,22 @@ ProjectItem *ProjectList::getFolderItemById(const QString &id) {
     return NULL;
 }
 
-void ProjectList::slotSelectClip(const QString &ix) {
-    ProjectItem *p = getItemById(ix);
-    if (p) {
-        listView->setCurrentItem(p);
-        listView->scrollToItem(p);
+void ProjectList::slotSelectClip(const QString &ix)
+{
+    ProjectItem *clip = getItemById(ix);
+    if (clip) {
+        m_listView->setCurrentItem(clip);
+        m_listView->scrollToItem(clip);
         m_editAction->setEnabled(true);
         m_deleteAction->setEnabled(true);
+        m_reloadAction->setEnabled(true);
+        if (clip->clipType() == IMAGE && !KdenliveSettings::defaultimageapp().isEmpty()) {
+            m_openAction->setIcon(KIcon(KdenliveSettings::defaultimageapp()));
+            m_openAction->setEnabled(true);
+        } else if (clip->clipType() == AUDIO && !KdenliveSettings::defaultaudioapp().isEmpty()) {
+            m_openAction->setIcon(KIcon(KdenliveSettings::defaultaudioapp()));
+            m_openAction->setEnabled(true);
+        } else m_openAction->setEnabled(false);
     }
 }
 
