@@ -18,8 +18,8 @@
  ***************************************************************************/
 
 
-#ifndef PRJECTLIST_H
-#define PRJECTLIST_H
+#ifndef PROJECTLIST_H
+#define PROJECTLIST_H
 
 #include <QDomNodeList>
 #include <QToolBar>
@@ -39,7 +39,8 @@
 #include "timecode.h"
 #include "kdenlivesettings.h"
 
-namespace Mlt {
+namespace Mlt
+{
 class Producer;
 };
 
@@ -53,7 +54,8 @@ const int NameRole = Qt::UserRole;
 const int DurationRole = NameRole + 1;
 const int UsageRole = NameRole + 2;
 
-class ItemDelegate: public QItemDelegate {
+class ItemDelegate: public QItemDelegate
+{
 public:
     ItemDelegate(QAbstractItemView* parent = 0): QItemDelegate(parent) {
     }
@@ -110,7 +112,8 @@ public:
     }
 };
 
-class ProjectList : public QWidget {
+class ProjectList : public QWidget
+{
     Q_OBJECT
 
 public:
@@ -129,7 +132,7 @@ public:
 public slots:
     void setDocument(KdenliveDoc *doc);
     void slotReplyGetImage(const QString &clipId, const QPixmap &pix);
-    void slotReplyGetFileProperties(const QString &clipId, Mlt::Producer *producer, const QMap < QString, QString > &properties, const QMap < QString, QString > &metadata);
+    void slotReplyGetFileProperties(const QString &clipId, Mlt::Producer *producer, const QMap < QString, QString > &properties, const QMap < QString, QString > &metadata, bool replace);
     void slotAddClip(DocClipBase *clip, bool getProperties);
     void slotDeleteClip(const QString &clipId);
     void slotUpdateClip(const QString &id);
@@ -138,13 +141,15 @@ public slots:
     void slotRemoveInvalidClip(const QString &id);
     void slotSelectClip(const QString &ix);
     void slotRemoveClip();
-    void slotAddClip(KUrl givenUrl = KUrl(), QString group = QString());
+    void slotAddClip(const QList <QUrl> givenList = QList <QUrl> (), QString group = QString());
     void slotAddFolder(const QString foldername, const QString &clipId, bool remove, bool edit = false);
     void slotResetProjectList();
+    void slotOpenClip();
+    void slotEditClip();
+    void slotReloadClip();
 
 private:
-    ProjectListView *listView;
-    KTreeWidgetSearchLine *searchView;
+    ProjectListView *m_listView;
     Render *m_render;
     Timecode m_timecode;
     double m_fps;
@@ -156,6 +161,8 @@ private:
     ProjectItem *getFolderItemById(const QString &id);
     QAction *m_editAction;
     QAction *m_deleteAction;
+    QAction *m_openAction;
+    QAction *m_reloadAction;
     KdenliveDoc *m_doc;
     ProjectItem *m_selectedItem;
     bool m_refreshed;
@@ -168,7 +175,6 @@ private:
     void editFolder(const QString folderName, const QString oldfolderName, const QString &clipId);
 
 private slots:
-    void slotEditClip();
     void slotClipSelected();
     void slotAddColorClip();
     void slotAddSlideshowClip();
@@ -186,8 +192,8 @@ private slots:
 
 signals:
     void clipSelected(DocClipBase *);
-    void getFileProperties(const QDomElement&, const QString &);
-    void receivedClipDuration(const QString &, int);
+    void getFileProperties(const QDomElement&, const QString &, bool);
+    void receivedClipDuration(const QString &);
     void showClipProperties(DocClipBase *);
     void projectModified();
     void loadingIsOver();
