@@ -17,21 +17,19 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
-#include <QDir>
+#include "slideshowclip.h"
+#include "kdenlivesettings.h"
 
 #include <KStandardDirs>
 #include <KDebug>
 #include <KFileItem>
 
-#include "kdenlivesettings.h"
-#include "slideshowclip.h"
+#include <QDir>
 
-static const int TYPE_JPEG = 0;
-static const int TYPE_PNG = 1;
-static const int TYPE_BMP = 2;
-static const int TYPE_GIF = 3;
-
-SlideshowClip::SlideshowClip(QWidget * parent): QDialog(parent), m_count(0) {
+SlideshowClip::SlideshowClip(QWidget * parent) :
+        QDialog(parent),
+        m_count(0)
+{
     setFont(KGlobalSettings::toolBarFont());
     setWindowTitle(i18n("Add Slideshow Clip"));
     m_view.setupUi(this);
@@ -44,10 +42,14 @@ SlideshowClip::SlideshowClip(QWidget * parent): QDialog(parent), m_count(0) {
     connect(m_view.slide_fade, SIGNAL(stateChanged(int)), this, SLOT(slotEnableLuma(int)));
     connect(m_view.luma_fade, SIGNAL(stateChanged(int)), this, SLOT(slotEnableLumaFile(int)));
 
-    m_view.image_type->addItem("JPG");
-    m_view.image_type->addItem("PNG");
-    m_view.image_type->addItem("BMP");
-    m_view.image_type->addItem("GIF");
+    m_view.image_type->addItem("JPG (*.jpg)", "jpg");
+    m_view.image_type->addItem("JPEG (*.jpeg)", "jpeg");
+    m_view.image_type->addItem("PNG (*.png)", "png");
+    m_view.image_type->addItem("BMP (*.bmp)", "bmp");
+    m_view.image_type->addItem("GIF (*.gif)", "gif");
+    m_view.image_type->addItem("TGA (*.tga)", "tga");
+    m_view.image_type->addItem("TIFF (*.tiff)", "tiff");
+    m_view.image_type->addItem("Open EXR (*.exr)", "exr");
     m_view.clip_duration->setText(KdenliveSettings::image_duration());
     m_view.luma_duration->setText("00:00:00:24");
     m_view.folder_url->setUrl(QDir::homePath());
@@ -78,7 +80,8 @@ SlideshowClip::SlideshowClip(QWidget * parent): QDialog(parent), m_count(0) {
     adjustSize();
 }
 
-void SlideshowClip::slotEnableLuma(int state) {
+void SlideshowClip::slotEnableLuma(int state)
+{
     bool enable = false;
     if (state == Qt::Checked) enable = true;
     m_view.luma_duration->setEnabled(enable);
@@ -90,7 +93,8 @@ void SlideshowClip::slotEnableLuma(int state) {
     m_view.luma_softness->setEnabled(m_view.label_softness->isEnabled());
 }
 
-void SlideshowClip::slotEnableLumaFile(int state) {
+void SlideshowClip::slotEnableLumaFile(int state)
+{
     bool enable = false;
     if (state == Qt::Checked) enable = true;
     m_view.luma_file->setEnabled(enable);
@@ -98,27 +102,16 @@ void SlideshowClip::slotEnableLumaFile(int state) {
     m_view.label_softness->setEnabled(enable);
 }
 
-void SlideshowClip::parseFolder() {
+void SlideshowClip::parseFolder()
+{
     m_view.icon_list->clear();
     QDir dir(m_view.folder_url->url().path());
 
     QStringList filters;
-    switch (m_view.image_type->currentIndex()) {
-    case TYPE_PNG:
-        filters << "*.png";
-        break;
-    case TYPE_BMP:
-        filters << "*.bmp";
-        break;
-    case TYPE_GIF:
-        filters << "*.gif";
-        break;
-    default:
-        filters << "*.jpg";
-        // TODO: improve jpeg image detection with extension like jpeg, requires change in MLT image producers
-        // << "*.jpeg";
-        break;
-    }
+    QString filter = m_view.image_type->itemData(m_view.image_type->currentIndex()).toString();
+    filters << "*." + filter;
+    // TODO: improve jpeg image detection with extension like jpeg, requires change in MLT image producers
+    // << "*.jpeg";
 
     dir.setNameFilters(filters);
     const QStringList result = dir.entryList(QDir::Files);
@@ -144,7 +137,8 @@ void SlideshowClip::parseFolder() {
     m_view.icon_list->setCurrentRow(0);
 }
 
-void SlideshowClip::slotSetItemIcon(int row) {
+void SlideshowClip::slotSetItemIcon(int row)
+{
     QListWidgetItem * item = m_view.icon_list->item(row);
     if (item) {
         QString path = item->data(Qt::UserRole).toString();
@@ -156,55 +150,50 @@ void SlideshowClip::slotSetItemIcon(int row) {
     }
 }
 
-QString SlideshowClip::selectedPath() const {
-    QString extension;
-    switch (m_view.image_type->currentIndex()) {
-    case TYPE_PNG:
-        extension = "/.all.png";
-        break;
-    case TYPE_BMP:
-        extension = "/.all.bmp";
-        break;
-    case TYPE_GIF:
-        extension = "/.all.gif";
-        break;
-    default:
-        extension = "/.all.jpg";
-        break;
-    }
+QString SlideshowClip::selectedPath() const
+{
+    QString extension = "/.all." + m_view.image_type->itemData(m_view.image_type->currentIndex()).toString();
     return m_view.folder_url->url().path() + extension;
 }
 
 
-QString SlideshowClip::clipName() const {
+QString SlideshowClip::clipName() const
+{
     return m_view.clip_name->text();
 }
 
-QString SlideshowClip::clipDuration() const {
+QString SlideshowClip::clipDuration() const
+{
     return m_view.clip_duration->text();
 }
 
-int SlideshowClip::imageCount() const {
+int SlideshowClip::imageCount() const
+{
     return m_count;
 }
 
-int SlideshowClip::softness() const {
+int SlideshowClip::softness() const
+{
     return m_view.luma_softness->value();
 }
 
-bool SlideshowClip::loop() const {
+bool SlideshowClip::loop() const
+{
     return m_view.slide_loop->isChecked();
 }
 
-bool SlideshowClip::fade() const {
+bool SlideshowClip::fade() const
+{
     return m_view.slide_fade->isChecked();
 }
 
-QString SlideshowClip::lumaDuration() const {
+QString SlideshowClip::lumaDuration() const
+{
     return m_view.luma_duration->text();
 }
 
-QString SlideshowClip::lumaFile() const {
+QString SlideshowClip::lumaFile() const
+{
     if (!m_view.luma_fade->isChecked() || !m_view.luma_file->isEnabled()) return QString();
     return m_view.luma_file->itemData(m_view.luma_file->currentIndex()).toString();
 }
