@@ -15,28 +15,33 @@
  *                                                                         *
  ***************************************************************************/
 
-
-
-#include <QGraphicsView>
-#include <QDomDocument>
-#include <QGraphicsItem>
-#include <QGraphicsSvgItem>
-#include <QTimer>
-
-#include <QToolBar>
-#include <QMenu>
+#include "titlewidget.h"
+#include "kdenlivesettings.h"
 
 #include <KDebug>
 #include <KGlobalSettings>
 #include <KFileDialog>
 #include <KStandardDirs>
+#include <KMessageBox>
 
-#include "titlewidget.h"
-#include "kdenlivesettings.h"
+#include <QDomDocument>
+#include <QGraphicsItem>
+#include <QGraphicsSvgItem>
+#include <QTimer>
+#include <QToolBar>
+#include <QMenu>
 
 int settingUp = false;
 
-TitleWidget::TitleWidget(KUrl url, QString projectPath, Render *render, QWidget *parent): QDialog(parent), m_render(render), m_count(0), m_projectPath(projectPath), startViewport(NULL), endViewport(NULL) {
+TitleWidget::TitleWidget(KUrl url, QString projectPath, Render *render, QWidget *parent) :
+        QDialog(parent),
+        Ui::TitleWidget_UI(),
+        m_startViewport(NULL),
+        m_endViewport(NULL),
+        m_render(render),
+        m_count(0),
+        m_projectPath(projectPath)
+{
     setupUi(this);
     setFont(KGlobalSettings::toolBarFont());
     //toolBox->setFont(KGlobalSettings::toolBarFont());
@@ -188,14 +193,15 @@ TitleWidget::TitleWidget(KUrl url, QString projectPath, Render *render, QWidget
     kDebug() << "// TITLE WIDGWT: " << graphicsView->viewport()->width() << "x" << graphicsView->viewport()->height();
     toolBox->setItemEnabled(2, false);
     if (!url.isEmpty()) {
-        m_count = m_titledocument.loadDocument(url, startViewport, endViewport) + 1;
+        m_count = m_titledocument.loadDocument(url, m_startViewport, m_endViewport) + 1;
         slotSelectTool();
     } else {
         slotRectTool();
     }
 }
 
-TitleWidget::~TitleWidget() {
+TitleWidget::~TitleWidget()
+{
     delete m_buttonRect;
     delete m_buttonText;
     delete m_buttonImage;
@@ -205,13 +211,14 @@ TitleWidget::~TitleWidget() {
 
     delete m_frameBorder;
     delete m_frameImage;
-    if (startViewport) delete startViewport;
-    if (endViewport) delete endViewport;
+    delete m_startViewport;
+    delete m_endViewport;
     delete m_scene;
 }
 
 //static
-QStringList TitleWidget::getFreeTitleInfo(const KUrl &projectUrl) {
+QStringList TitleWidget::getFreeTitleInfo(const KUrl &projectUrl)
+{
     QStringList result;
     QString titlePath = projectUrl.path() + "/titles/";
     KStandardDirs::makeDir(titlePath);
@@ -227,7 +234,8 @@ QStringList TitleWidget::getFreeTitleInfo(const KUrl &projectUrl) {
     return result;
 }
 
-QString TitleWidget::getTitleResourceFromName(const KUrl &projectUrl, const QString &titleName) {
+QString TitleWidget::getTitleResourceFromName(const KUrl &projectUrl, const QString &titleName)
+{
     QStringList result;
     QString titlePath = projectUrl.path() + "/titles/";
     KStandardDirs::makeDir(titlePath);
@@ -235,11 +243,13 @@ QString TitleWidget::getTitleResourceFromName(const KUrl &projectUrl, const QStr
 }
 
 //virtual
-void TitleWidget::resizeEvent(QResizeEvent * event) {
+void TitleWidget::resizeEvent(QResizeEvent * /*event*/)
+{
     //slotAdjustZoom();
 }
 
-void TitleWidget::slotTextTool() {
+void TitleWidget::slotTextTool()
+{
     rect_properties->setHidden(true);
     text_properties->setHidden(false);
     m_scene->setTool(TITLE_TEXT);
@@ -247,7 +257,8 @@ void TitleWidget::slotTextTool() {
     m_buttonCursor->setChecked(false);
 }
 
-void TitleWidget::slotRectTool() {
+void TitleWidget::slotRectTool()
+{
     text_properties->setHidden(true);
     rect_properties->setHidden(false);
     m_scene->setTool(TITLE_RECTANGLE);
@@ -256,14 +267,16 @@ void TitleWidget::slotRectTool() {
     m_buttonRect->setChecked(true);
 }
 
-void TitleWidget::slotSelectTool() {
+void TitleWidget::slotSelectTool()
+{
     m_scene->setTool(TITLE_SELECT);
     m_buttonCursor->setChecked(true);
     m_buttonText->setChecked(false);
     m_buttonRect->setChecked(false);
 }
 
-void TitleWidget::slotImageTool() {
+void TitleWidget::slotImageTool()
+{
     KUrl url = KFileDialog::getOpenUrl(KUrl(), "*.svg *.png *.jpg *.jpeg *.gif *.raw", this, i18n("Load Image"));
     if (!url.isEmpty()) {
         if (url.path().endsWith(".svg")) {
@@ -288,7 +301,8 @@ void TitleWidget::slotImageTool() {
     m_buttonText->setChecked(false);
 }
 
-void TitleWidget::displayBackgroundFrame() {
+void TitleWidget::displayBackgroundFrame()
+{
     if (!displayBg->isChecked()) {
         QPixmap bg(m_frameWidth / 2, m_frameHeight / 2);
         QPixmap pattern(20, 20);
@@ -309,44 +323,48 @@ void TitleWidget::displayBackgroundFrame() {
     }
 }
 
-void TitleWidget::initViewports() {
-    startViewport = new QGraphicsPolygonItem(QPolygonF(QRectF(0, 0, 0, 0)));
-    endViewport = new QGraphicsPolygonItem(QPolygonF(QRectF(0, 0, 0, 0)));
+void TitleWidget::initViewports()
+{
+    m_startViewport = new QGraphicsPolygonItem(QPolygonF(QRectF(0, 0, 0, 0)));
+    m_endViewport = new QGraphicsPolygonItem(QPolygonF(QRectF(0, 0, 0, 0)));
 
     QPen startpen(Qt::DotLine);
     QPen endpen(Qt::DashDotLine);
     startpen.setColor(QColor(100, 200, 100, 140));
     endpen.setColor(QColor(200, 100, 100, 140));
 
-    startViewport->setPen(startpen);
-    endViewport->setPen(endpen);
+    m_startViewport->setPen(startpen);
+    m_endViewport->setPen(endpen);
 
     startViewportSize->setValue(40);
     endViewportSize->setValue(40);
 
-    startViewport->setZValue(-1000);
-    endViewport->setZValue(-1000);
+    m_startViewport->setZValue(-1000);
+    m_endViewport->setZValue(-1000);
 
-    startViewport->setFlags(/*QGraphicsItem::ItemIsMovable|*/QGraphicsItem::ItemIsSelectable);
-    endViewport->setFlags(/*QGraphicsItem::ItemIsMovable|*/QGraphicsItem::ItemIsSelectable);
+    m_startViewport->setFlags(/*QGraphicsItem::ItemIsMovable|*/QGraphicsItem::ItemIsSelectable);
+    m_endViewport->setFlags(/*QGraphicsItem::ItemIsMovable|*/QGraphicsItem::ItemIsSelectable);
 
-    graphicsView->scene()->addItem(startViewport);
-    graphicsView->scene()->addItem(endViewport);
+    graphicsView->scene()->addItem(m_startViewport);
+    graphicsView->scene()->addItem(m_endViewport);
 }
 
-void TitleWidget::slotUpdateZoom(int pos) {
+void TitleWidget::slotUpdateZoom(int pos)
+{
     m_scene->setZoom((double) pos / 100);
-    zoom_label->setText(QString::number(pos) + "%");
+    zoom_label->setText(QString::number(pos) + '%');
 }
 
-void TitleWidget::slotZoom(bool up) {
+void TitleWidget::slotZoom(bool up)
+{
     int pos = zoom_slider->value();
     if (up) pos++;
     else pos--;
     zoom_slider->setValue(pos);
 }
 
-void TitleWidget::slotAdjustZoom() {
+void TitleWidget::slotAdjustZoom()
+{
     /*double scalex = graphicsView->width() / (double)(m_frameWidth * 1.2);
     double scaley = graphicsView->height() / (double)(m_frameHeight * 1.2);
     if (scalex > scaley) scalex = scaley;
@@ -357,12 +375,14 @@ void TitleWidget::slotAdjustZoom() {
     graphicsView->centerOn(m_frameBorder);
 }
 
-void TitleWidget::slotZoomOneToOne() {
+void TitleWidget::slotZoomOneToOne()
+{
     zoom_slider->setValue(100);
     graphicsView->centerOn(m_frameBorder);
 }
 
-void TitleWidget::slotNewRect(QGraphicsRectItem * rect) {
+void TitleWidget::slotNewRect(QGraphicsRectItem * rect)
+{
     QColor f = rectFColor->color();
     f.setAlpha(rectFAlpha->value());
     QPen penf(f);
@@ -376,9 +396,10 @@ void TitleWidget::slotNewRect(QGraphicsRectItem * rect) {
     //graphicsView->setFocus();
 }
 
-void TitleWidget::slotNewText(QGraphicsTextItem *tt) {
+void TitleWidget::slotNewText(QGraphicsTextItem *tt)
+{
     QFont font = font_family->currentFont();
-    font.setPointSize(font_size->value());
+    font.setPixelSize(font_size->value());
     // mbd: issue 551:
     font.setBold(buttonBold->isChecked());
     font.setItalic(buttonItalic->isChecked());
@@ -392,18 +413,21 @@ void TitleWidget::slotNewText(QGraphicsTextItem *tt) {
     setCurrentItem(tt);
 }
 
-void TitleWidget::setCurrentItem(QGraphicsItem *item) {
+void TitleWidget::setCurrentItem(QGraphicsItem *item)
+{
     m_scene->setSelectedItem(item);
 }
 
-void TitleWidget::zIndexChanged(int v) {
+void TitleWidget::zIndexChanged(int v)
+{
     QList<QGraphicsItem*> l = graphicsView->scene()->selectedItems();
     if (l.size() >= 1) {
         l[0]->setZValue(v);
     }
 }
 
-void TitleWidget::selectionChanged() {
+void TitleWidget::selectionChanged()
+{
     if (m_scene->tool() != TITLE_SELECT) return;
     QList<QGraphicsItem*> l = graphicsView->scene()->selectedItems();
     //toolBox->setItemEnabled(2, false);
@@ -432,7 +456,7 @@ void TitleWidget::selectionChanged() {
 
             QFont font = i->font();
             font_family->setCurrentFont(font);
-            font_size->setValue(font.pointSize());
+            font_size->setValue(font.pixelSize());
             buttonBold->setChecked(font.bold());
             buttonItalic->setChecked(font.italic());
             buttonUnder->setChecked(font.underline());
@@ -486,8 +510,8 @@ void TitleWidget::selectionChanged() {
             frame_properties->setEnabled(false);
         }
         zValue->setValue((int)l[0]->zValue());
-        itemzoom->setValue((int)(transformations[l[0]].scalex * 100));
-        itemrotate->setValue((int)(transformations[l[0]].rotate));
+        itemzoom->setValue((int)(m_transformations[l[0]].scalex * 100));
+        itemrotate->setValue((int)(m_transformations[l[0]].rotate));
         value_x->blockSignals(false);
         value_y->blockSignals(false);
         value_w->blockSignals(false);
@@ -495,7 +519,8 @@ void TitleWidget::selectionChanged() {
     } else frame_properties->setEnabled(false);
 }
 
-void TitleWidget::slotAdjustSelectedItem() {
+void TitleWidget::slotAdjustSelectedItem()
+{
     QList<QGraphicsItem*> l = graphicsView->scene()->selectedItems();
     if (l.size() >= 1) {
         if (l[0]->type() == 3) {
@@ -511,13 +536,15 @@ void TitleWidget::slotAdjustSelectedItem() {
     }
 }
 
-void TitleWidget::slotChangeBackground() {
+void TitleWidget::slotChangeBackground()
+{
     QColor color = kcolorbutton->color();
     color.setAlpha(horizontalSlider->value());
     m_frameBorder->setBrush(QBrush(color));
 }
 
-void TitleWidget::textChanged() {
+void TitleWidget::textChanged()
+{
     QList<QGraphicsItem*> l = graphicsView->scene()->selectedItems();
     if (l.size() == 1 && (l[0])->type() == 8 && !l[0]->hasFocus()) {
         //kDebug() << ktextedit->document()->toHtml();
@@ -525,9 +552,10 @@ void TitleWidget::textChanged() {
     }
 }
 
-void TitleWidget::slotUpdateText() {
+void TitleWidget::slotUpdateText()
+{
     QFont font = font_family->currentFont();
-    font.setPointSize(font_size->value());
+    font.setPixelSize(font_size->value());
     font.setBold(buttonBold->isChecked());
     font.setItalic(buttonItalic->isChecked());
     font.setUnderline(buttonUnder->isChecked());
@@ -560,7 +588,8 @@ void TitleWidget::slotUpdateText() {
     }*/
 }
 
-void TitleWidget::rectChanged() {
+void TitleWidget::rectChanged()
+{
     QList<QGraphicsItem*> l = graphicsView->scene()->selectedItems();
     if (l.size() == 1 && (l[0])->type() == 3 && !settingUp) {
         QGraphicsRectItem *rec = (QGraphicsRectItem*)l[0];
@@ -575,41 +604,45 @@ void TitleWidget::rectChanged() {
     }
 }
 
-void TitleWidget::fontBold() {
+void TitleWidget::fontBold()
+{
     QList<QGraphicsItem*> l = graphicsView->scene()->selectedItems();
     if (l.size() == 1 && (l[0])->type() == 8 && !l[0]->hasFocus()) {
         //ktextedit->document()->setTextOption();
     }
 }
 
-void TitleWidget::itemScaled(int val) {
+void TitleWidget::itemScaled(int val)
+{
     QList<QGraphicsItem*> l = graphicsView->scene()->selectedItems();
     if (l.size() == 1) {
-        Transform x = transformations[l[0]];
+        Transform x = m_transformations[l[0]];
         x.scalex = (double)val / 100.0;
         x.scaley = (double)val / 100.0;
         QTransform qtrans;
         qtrans.scale(x.scalex, x.scaley);
         qtrans.rotate(x.rotate);
         l[0]->setTransform(qtrans);
-        transformations[l[0]] = x;
+        m_transformations[l[0]] = x;
     }
 }
 
-void TitleWidget::itemRotate(int val) {
+void TitleWidget::itemRotate(int val)
+{
     QList<QGraphicsItem*> l = graphicsView->scene()->selectedItems();
     if (l.size() == 1) {
-        Transform x = transformations[l[0]];
+        Transform x = m_transformations[l[0]];
         x.rotate = (double)val;
         QTransform qtrans;
         qtrans.scale(x.scalex, x.scaley);
         qtrans.rotate(x.rotate);
         l[0]->setTransform(qtrans);
-        transformations[l[0]] = x;
+        m_transformations[l[0]] = x;
     }
 }
 
-void TitleWidget::itemHCenter() {
+void TitleWidget::itemHCenter()
+{
     QList<QGraphicsItem*> l = graphicsView->scene()->selectedItems();
     if (l.size() == 1) {
         QGraphicsItem *item = l[0];
@@ -623,7 +656,8 @@ void TitleWidget::itemHCenter() {
     }
 }
 
-void TitleWidget::itemVCenter() {
+void TitleWidget::itemVCenter()
+{
     QList<QGraphicsItem*> l = graphicsView->scene()->selectedItems();
     if (l.size() == 1) {
         QGraphicsItem *item = l[0];
@@ -637,7 +671,8 @@ void TitleWidget::itemVCenter() {
     }
 }
 
-void TitleWidget::setupViewports() {
+void TitleWidget::setupViewports()
+{
     double aspect_ratio = 4.0 / 3.0;//read from project
 
     QRectF sp(0, 0, 0, 0);
@@ -648,37 +683,44 @@ void TitleWidget::setupViewports() {
     sp.adjust(-sv_size, -sv_size / aspect_ratio, sv_size, sv_size / aspect_ratio);
     ep.adjust(-ev_size, -ev_size / aspect_ratio, ev_size, ev_size / aspect_ratio);
 
-    startViewport->setPos(startViewportX->value(), startViewportY->value());
-    endViewport->setPos(endViewportX->value(), endViewportY->value());
+    m_startViewport->setPos(startViewportX->value(), startViewportY->value());
+    m_endViewport->setPos(endViewportX->value(), endViewportY->value());
 
-    startViewport->setPolygon(QPolygonF(sp));
-    endViewport->setPolygon(QPolygonF(ep));
+    m_startViewport->setPolygon(QPolygonF(sp));
+    m_endViewport->setPolygon(QPolygonF(ep));
 
 }
 
-void TitleWidget::loadTitle() {
+void TitleWidget::loadTitle()
+{
     KUrl url = KFileDialog::getOpenUrl(KUrl(m_projectPath), "*.kdenlivetitle", this, i18n("Load Title"));
     if (!url.isEmpty()) {
         QList<QGraphicsItem *> items = m_scene->items();
         for (int i = 0; i < items.size(); i++) {
             if (items.at(i)->zValue() > -1000) delete items.at(i);
         }
-        m_count = m_titledocument.loadDocument(url, startViewport, endViewport) + 1;
+        m_count = m_titledocument.loadDocument(url, m_startViewport, m_endViewport) + 1;
         slotSelectTool();
     }
 }
 
-void TitleWidget::saveTitle(KUrl url) {
+void TitleWidget::saveTitle(KUrl url)
+{
     if (url.isEmpty()) url = KFileDialog::getSaveUrl(KUrl(m_projectPath), "*.kdenlivetitle", this, i18n("Save Title"));
-    if (!url.isEmpty()) m_titledocument.saveDocument(url, startViewport, endViewport);
+    if (!url.isEmpty()) {
+        if (m_titledocument.saveDocument(url, m_startViewport, m_endViewport) == false)
+            KMessageBox::error(this, i18n("Cannot write to file %1", url.path()));
+    }
 }
 
-QDomDocument TitleWidget::xml() {
-    return m_titledocument.xml(startViewport, endViewport);
+QDomDocument TitleWidget::xml()
+{
+    return m_titledocument.xml(m_startViewport, m_endViewport);
 }
 
-void TitleWidget::setXml(QDomDocument doc) {
-    m_count = m_titledocument.loadFromXml(doc, startViewport, endViewport);
+void TitleWidget::setXml(QDomDocument doc)
+{
+    m_count = m_titledocument.loadFromXml(doc, m_startViewport, m_endViewport);
     // mbd: Update the GUI color selectors to match the stuff from the loaded document
     QColor background_color = m_titledocument.getBackgroundColor();
     horizontalSlider->blockSignals(true);
@@ -692,7 +734,8 @@ void TitleWidget::setXml(QDomDocument doc) {
     slotSelectTool();
 }
 
-QImage TitleWidget::renderedPixmap() {
+QImage TitleWidget::renderedPixmap()
+{
     QImage pix(m_frameWidth, m_frameHeight, QImage::Format_ARGB32);
     pix.fill(Qt::transparent);
     QPainter painter(&pix);
@@ -700,32 +743,35 @@ QImage TitleWidget::renderedPixmap() {
     m_scene->clearTextSelection();
     QPen framepen = m_frameBorder->pen();
     m_frameBorder->setPen(Qt::NoPen);
-    startViewport->setVisible(false);
-    endViewport->setVisible(false);
+    m_startViewport->setVisible(false);
+    m_endViewport->setVisible(false);
     m_frameImage->setVisible(false);
 
     m_scene->render(&painter, QRectF(), QRectF(0, 0, m_frameWidth, m_frameHeight));
     painter.end();
     m_frameBorder->setPen(framepen);
-    startViewport->setVisible(true);
-    endViewport->setVisible(true);
+    m_startViewport->setVisible(true);
+    m_endViewport->setVisible(true);
     m_frameImage->setVisible(true);
     return pix;
 }
 
 /** \brief Connected to the accepted signal - calls writeChoices */
-void TitleWidget::slotAccepted() {
+void TitleWidget::slotAccepted()
+{
     writeChoices();
 }
 
 /** \brief Store the current choices of font, background and rect values */
-void TitleWidget::writeChoices() {
+void TitleWidget::writeChoices()
+{
     // Get a pointer to a shared configuration instance, then get the TitleWidget group.
     KSharedConfigPtr config = KGlobal::config();
     KConfigGroup titleConfig(config, "TitleWidget");
     // Write the entries
     titleConfig.writeEntry("font_family", font_family->currentFont());
-    titleConfig.writeEntry("font_size", font_size->value());
+    //titleConfig.writeEntry("font_size", font_size->value());
+    titleConfig.writeEntry("font_pixel_size", font_size->value());
     titleConfig.writeEntry("font_color", fontColorButton->color());
     titleConfig.writeEntry("font_alpha", textAlpha->value());
     titleConfig.writeEntry("font_bold", buttonBold->isChecked());
@@ -746,13 +792,14 @@ void TitleWidget::writeChoices() {
 }
 
 /** \brief Read the last stored choices into the dialog */
-void TitleWidget::readChoices() {
+void TitleWidget::readChoices()
+{
     // Get a pointer to a shared configuration instance, then get the TitleWidget group.
     KSharedConfigPtr config = KGlobal::config();
     KConfigGroup titleConfig(config, "TitleWidget");
     // read the entries
     font_family->setCurrentFont(titleConfig.readEntry("font_family", font_family->currentFont()));
-    font_size->setValue(titleConfig.readEntry("font_size", font_size->value()));
+    font_size->setValue(titleConfig.readEntry("font_pixel_size", font_size->value()));
     fontColorButton->setColor(titleConfig.readEntry("font_color", fontColorButton->color()));
     textAlpha->setValue(titleConfig.readEntry("font_alpha", textAlpha->value()));
     buttonBold->setChecked(titleConfig.readEntry("font_bold", buttonBold->isChecked()));
