@@ -18,14 +18,9 @@
  ***************************************************************************/
 
 
-#include <QScrollBar>
-
-#include <KDebug>
-#include <KMessageBox>
-
+#include "trackview.h"
 #include "definitions.h"
 #include "headertrack.h"
-#include "trackview.h"
 #include "clipitem.h"
 #include "transition.h"
 #include "kdenlivesettings.h"
@@ -36,11 +31,19 @@
 #include "customtrackview.h"
 #include "initeffects.h"
 
-TrackView::TrackView(KdenliveDoc *doc, QWidget *parent)
-        : QWidget(parent), m_doc(doc), m_scale(1.0), m_projectTracks(0) {
+#include <KDebug>
+#include <KMessageBox>
 
-    view = new Ui::TimeLine_UI();
-    view->setupUi(this);
+#include <QScrollBar>
+
+TrackView::TrackView(KdenliveDoc *doc, QWidget *parent) :
+        QWidget(parent),
+        m_scale(1.0),
+        m_projectTracks(0),
+        m_doc(doc)
+{
+
+    m_view.setupUi(this);
 
     m_scene = new CustomTrackScene(doc);
     m_trackview = new CustomTrackView(doc, m_scene, parent);
@@ -51,30 +54,29 @@ TrackView::TrackView(KdenliveDoc *doc, QWidget *parent)
     m_ruler = new CustomRuler(doc->timecode(), m_trackview);
     connect(m_ruler, SIGNAL(zoneMoved(int, int)), this, SIGNAL(zoneMoved(int, int)));
     QHBoxLayout *layout = new QHBoxLayout;
-    view->ruler_frame->setLayout(layout);
-    int left_margin;
-    int right_margin;
-    layout->getContentsMargins(&left_margin, 0, &right_margin, 0);
-    layout->setContentsMargins(left_margin, 0, right_margin, 0);
+    layout->setContentsMargins(m_trackview->frameWidth(), 0, 0, 0);
+    layout->setSpacing(0);
+    m_view.ruler_frame->setLayout(layout);
     layout->addWidget(m_ruler);
 
     QHBoxLayout *tracksLayout = new QHBoxLayout;
     tracksLayout->setContentsMargins(0, 0, 0, 0);
-    view->tracks_frame->setLayout(tracksLayout);
+    tracksLayout->setSpacing(0);
+    m_view.tracks_frame->setLayout(tracksLayout);
 
-    view->headers_area->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    view->headers_area->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    m_view.headers_area->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    m_view.headers_area->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
     m_headersLayout = new QVBoxLayout;
-    m_headersLayout->setContentsMargins(0, 0, 0, 0);
+    m_headersLayout->setContentsMargins(0, m_trackview->frameWidth(), 0, 0);
     m_headersLayout->setSpacing(0);
-    view->headers_container->setLayout(m_headersLayout);
+    m_view.headers_container->setLayout(m_headersLayout);
 
-    connect(view->headers_area->verticalScrollBar(), SIGNAL(valueChanged(int)), m_trackview->verticalScrollBar(), SLOT(setValue(int)));
+    connect(m_view.headers_area->verticalScrollBar(), SIGNAL(valueChanged(int)), m_trackview->verticalScrollBar(), SLOT(setValue(int)));
 
     tracksLayout->addWidget(m_trackview);
 
-    connect(m_trackview->verticalScrollBar(), SIGNAL(valueChanged(int)), view->headers_area->verticalScrollBar(), SLOT(setValue(int)));
+    connect(m_trackview->verticalScrollBar(), SIGNAL(valueChanged(int)), m_view.headers_area->verticalScrollBar(), SLOT(setValue(int)));
     connect(m_trackview, SIGNAL(trackHeightChanged()), this, SLOT(slotRebuildTrackHeaders()));
 
     parseDocument(m_doc->toXml());
@@ -83,44 +85,55 @@ TrackView::TrackView(KdenliveDoc *doc, QWidget *parent)
     connect(m_trackview->horizontalScrollBar(), SIGNAL(valueChanged(int)), m_ruler, SLOT(slotMoveRuler(int)));
     connect(m_trackview, SIGNAL(mousePosition(int)), this, SIGNAL(mousePosition(int)));
     connect(m_trackview, SIGNAL(transitionItemSelected(Transition*, bool)), this, SLOT(slotTransitionItemSelected(Transition*, bool)));
+    connect(m_trackview, SIGNAL(doTrackLock(int, bool)), this, SLOT(slotChangeTrackLock(int, bool)));
+
     slotChangeZoom(m_doc->zoom());
     slotSetZone(m_doc->zone());
 }
 
 
-int TrackView::duration() const {
+int TrackView::duration() const
+{
     return m_trackview->duration();
 }
 
-int TrackView::tracksNumber() const {
+int TrackView::tracksNumber() const
+{
     return m_projectTracks - 1;
 }
 
-int TrackView::inPoint() const {
+int TrackView::inPoint() const
+{
     return m_ruler->inPoint();
 }
 
-int TrackView::outPoint() const {
+int TrackView::outPoint() const
+{
     return m_ruler->outPoint();
 }
 
-void TrackView::slotSetZone(QPoint p) {
+void TrackView::slotSetZone(QPoint p)
+{
     m_ruler->setZone(p);
 }
 
-void TrackView::slotTransitionItemSelected(Transition *t, bool update) {
+void TrackView::slotTransitionItemSelected(Transition *t, bool update)
+{
     emit transitionItemSelected(t, update);
 }
 
-void TrackView::setDuration(int dur) {
+void TrackView::setDuration(int dur)
+{
     m_trackview->setDuration(dur);
     m_ruler->setDuration(dur);
 }
 
-void TrackView::parseDocument(QDomDocument doc) {
-    int cursorPos = 0;
-    m_documentErrors = QString();
-    // kDebug() << "//// DOCUMENT: " << doc.toString();
+void TrackView::parseDocument(QDomDocument doc)
+{
+    //int cursorPos = 0;
+    m_documentErrors.clear();
+
+    //kDebug() << "//// DOCUMENT: " << doc.toString();
     /*QDomNode props = doc.elementsByTagName("properties").item(0);
     if (!props.isNull()) {
         cursorPos = props.toElement().attribute("timeline_position").toInt();
@@ -137,7 +150,40 @@ void TrackView::parseDocument(QDomDocument doc) {
     QDomElement p;
 
     int pos = m_projectTracks - 1;
+    m_invalidProducers.clear();
+    QDomNodeList producers = doc.elementsByTagName("producer");
+    for (int i = 0; i < producers.count(); i++) {
+        // Check for invalid producers
+        QDomNode n = producers.item(i);
+        e = n.toElement();
 
+        /*
+        // Check for invalid markup
+        QDomNodeList params = e.elementsByTagName("property");
+        for (int j = 0; j < params.count(); j++) {
+            QDomElement p = params.item(j).toElement();
+            if (p.attribute("name") == "markup") {
+         QString val = p.text().toUtf8().data();
+         kDebug()<<"//FOUND MARKUP, VAL: "<<val;
+         //e.setAttribute("value", value);
+         n.removeChild(params.item(j));
+         break;
+            }
+        }
+        */
+
+        if (e.hasAttribute("in") == false && e.hasAttribute("out") == false) continue;
+        int in = e.attribute("in").toInt();
+        int out = e.attribute("out").toInt();
+        if (in > out || in == out) {
+            // invalid producer, remove it
+            QString id = e.attribute("id");
+            m_invalidProducers.append(id);
+            m_documentErrors.append(i18n("Invalid clip producer %1\n", id));
+            doc.documentElement().removeChild(producers.at(i));
+            i--;
+        }
+    }
 
     for (int i = 0; i < m_projectTracks; i++) {
         e = tracks.item(i).toElement();
@@ -160,7 +206,8 @@ void TrackView::parseDocument(QDomDocument doc) {
                 m_doc->switchTrackVideo(i - 1, true);
                 m_doc->switchTrackAudio(i - 1, true);
             }
-            trackduration = slotAddProjectTrack(pos, p);
+
+            trackduration = slotAddProjectTrack(pos, p, m_doc->isTrackLocked(i - 1));
             pos--;
             //kDebug() << " PRO DUR: " << trackduration << ", TRACK DUR: " << duration;
             if (trackduration > duration) duration = trackduration;
@@ -215,8 +262,7 @@ void TrackView::parseDocument(QDomDocument doc) {
             QString transitionId;
             if (mlt_service == "composite") {
                 // When adding composite transition, check if it is a wipe transition
-                if (mlt_geometry == "0%,0%:100%x100%") transitionId = "alphatransparency";
-                else if (mlt_geometry.count(';') == 1) {
+                if (mlt_geometry.count(';') == 1) {
                     mlt_geometry.remove(QChar('%'), Qt::CaseInsensitive);
                     mlt_geometry.replace(QChar('x'), QChar(','), Qt::CaseInsensitive);
                     QString start = mlt_geometry.section(';', 0, 0);
@@ -283,6 +329,9 @@ void TrackView::parseDocument(QDomDocument doc) {
                 Transition *tr = new Transition(transitionInfo, a_track, m_doc->fps(), base, isAutomatic);
                 if (forceTrack) tr->setForcedTrack(true, a_track);
                 m_scene->addItem(tr);
+                if (b_track > 0 && m_doc->isTrackLocked(b_track - 1)) {
+                    tr->setItemLocked(true);
+                }
             }
         }
     }
@@ -296,6 +345,10 @@ void TrackView::parseDocument(QDomDocument doc) {
         m_trackview->addGuide(pos, comment);
     }
 
+    // Rebuild groups
+    QDomNodeList groups = doc.elementsByTagName("group");
+    m_trackview->loadGroups(groups);
+
     m_trackview->setDuration(duration);
     kDebug() << "///////////  TOTAL PROJECT DURATION: " << duration;
     slotRebuildTrackHeaders();
@@ -304,26 +357,31 @@ void TrackView::parseDocument(QDomDocument doc) {
     //m_scrollBox->setGeometry(0, 0, 300 * zoomFactor(), m_scrollArea->height());
 }
 
-void TrackView::slotDeleteClip(const QString &clipId) {
+void TrackView::slotDeleteClip(const QString &clipId)
+{
     m_trackview->deleteClip(clipId);
 }
 
-void TrackView::setCursorPos(int pos) {
+void TrackView::setCursorPos(int pos)
+{
     m_trackview->setCursorPos(pos);
 }
 
-void TrackView::moveCursorPos(int pos) {
+void TrackView::moveCursorPos(int pos)
+{
     m_trackview->setCursorPos(pos, false);
 }
 
-void TrackView::slotChangeZoom(int factor) {
+void TrackView::slotChangeZoom(int factor)
+{
     m_doc->setZoom(factor);
     m_ruler->setPixelPerMark(factor);
     m_scale = (double) FRAME_SIZE / m_ruler->comboScale[factor]; // m_ruler->comboScale[m_currentZoom] /
     m_trackview->setScale(m_scale);
 }
 
-int TrackView::fitZoom() const {
+int TrackView::fitZoom() const
+{
     int zoom = (int)((duration() + 20 / m_scale) * FRAME_SIZE / m_trackview->width());
     int i;
     for (i = 0; i < 13; i++)
@@ -331,47 +389,44 @@ int TrackView::fitZoom() const {
     return i;
 }
 
-const double TrackView::zoomFactor() const {
-    return m_scale;
-}
-
-const int TrackView::mapLocalToValue(int x) const {
-    return (int)(x * zoomFactor());
-}
-
-KdenliveDoc *TrackView::document() {
+KdenliveDoc *TrackView::document()
+{
     return m_doc;
 }
 
-void TrackView::refresh() {
+void TrackView::refresh()
+{
     m_trackview->viewport()->update();
 }
 
-void TrackView::slotRebuildTrackHeaders() {
+void TrackView::slotRebuildTrackHeaders()
+{
     QList <TrackInfo> list = m_doc->tracksList();
-    QList<HeaderTrack *> widgets = this->findChildren<HeaderTrack *>();
-    for (int i = 0; i < widgets.count(); i++)
-        delete widgets.at(i);
+    QList<HeaderTrack *> widgets = findChildren<HeaderTrack *>();
+    qDeleteAll(widgets);
     int max = list.count();
     for (int i = 0; i < max; i++) {
         HeaderTrack *header = new HeaderTrack(i, list.at(max - i - 1), this);
         connect(header, SIGNAL(switchTrackVideo(int)), m_trackview, SLOT(slotSwitchTrackVideo(int)));
         connect(header, SIGNAL(switchTrackAudio(int)), m_trackview, SLOT(slotSwitchTrackAudio(int)));
+        connect(header, SIGNAL(switchTrackLock(int)), m_trackview, SLOT(slotSwitchTrackLock(int)));
 
         connect(header, SIGNAL(deleteTrack(int)), this, SIGNAL(deleteTrack(int)));
         connect(header, SIGNAL(insertTrack(int)), this, SIGNAL(insertTrack(int)));
         connect(header, SIGNAL(changeTrack(int)), this, SIGNAL(changeTrack(int)));
         m_headersLayout->addWidget(header);
     }
-    view->headers_container->adjustSize();
+    m_view.headers_container->adjustSize();
 }
 
 
-int TrackView::slotAddProjectTrack(int ix, QDomElement xml) {
-    int trackTop = KdenliveSettings::trackheight() * ix;
+int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
+{
     // parse track
     int position = 0;
-    for (QDomNode n = xml.firstChild(); !n.isNull(); n = n.nextSibling()) {
+    QDomNodeList children = xml.childNodes();
+    for (int nodeindex = 0; nodeindex < children.count(); nodeindex++) {
+        QDomNode n = children.item(nodeindex);
         QDomElement elem = n.toElement();
         if (elem.tagName() == "blank") {
             position += elem.attribute("length").toInt();
@@ -381,18 +436,51 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml) {
             // Found a clip
             int in = elem.attribute("in").toInt();
             int out = elem.attribute("out").toInt();
-            if (in > out || in == out) {
+            if (in > out || in == out || m_invalidProducers.contains(elem.attribute("producer"))) {
                 m_documentErrors.append(i18n("Invalid clip removed from track %1 at %2\n", ix, position));
+                xml.removeChild(children.at(nodeindex));
+                nodeindex--;
                 continue;
             }
             QString idString = elem.attribute("producer");
             QString id = idString;
             double speed = 1.0;
             if (idString.startsWith("slowmotion")) {
-                id = idString.section(":", 1, 1);
-                speed = idString.section(":", 2, 2).toDouble();
+                id = idString.section(':', 1, 1);
+                speed = idString.section(':', 2, 2).toDouble();
             } else id = id.section('_', 0, 0);
             DocClipBase *clip = m_doc->clipManager()->getClipById(id);
+            if (clip == NULL) {
+                // The clip in playlist was not listed in the kdenlive producers,
+                // something went wrong, repair required.
+                kWarning() << "CANNOT INSERT CLIP " << id;
+
+                clip = getMissingProducer(id);
+                if (!clip) {
+                    // We cannot find the producer, something is really wrong, add
+                    // placeholder color clip
+                    QDomDocument doc;
+                    QDomElement producerXml = doc.createElement("producer");
+                    doc.appendChild(producerXml);
+                    producerXml.setAttribute("colour", "0xff0000ff");
+                    producerXml.setAttribute("mlt_service", "colour");
+                    producerXml.setAttribute("length", "15000");
+                    producerXml.setAttribute("name", "INVALID");
+                    producerXml.setAttribute("type", COLOR);
+                    producerXml.setAttribute("id", id);
+                    clip = new DocClipBase(m_doc->clipManager(), doc.documentElement(), id);
+                    xml.insertBefore(producerXml, QDomNode());
+                    m_doc->clipManager()->addClip(clip);
+
+                    m_documentErrors.append(i18n("Broken clip producer %1", id) + '\n');
+                } else {
+                    // Found correct producer
+                    m_documentErrors.append(i18n("Replaced wrong clip producer %1 with %2", id, clip->getId()) + '\n');
+                    elem.setAttribute("producer", clip->getId());
+                }
+                m_doc->setModified(true);
+            }
+
             if (clip != NULL) {
                 ItemInfo clipinfo;
                 clipinfo.startPos = GenTime(position, m_doc->fps());
@@ -401,7 +489,10 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml) {
                 clipinfo.track = ix;
                 //kDebug() << "// INSERTING CLIP: " << in << "x" << out << ", track: " << ix << ", ID: " << id << ", SCALE: " << m_scale << ", FPS: " << m_doc->fps();
                 ClipItem *item = new ClipItem(clip, clipinfo, m_doc->fps(), speed, false);
+                if (idString.endsWith("_video")) item->setVideoOnly(true);
+                else if (idString.endsWith("_audio")) item->setAudioOnly(true);
                 m_scene->addItem(item);
+                if (locked) item->setItemLocked(true);
                 clip->addReference();
                 position += (out - in + 1);
 
@@ -454,7 +545,7 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml) {
                             if (MainWindow::videoEffects.hasKeyFrames(currenteffect)) {
                                 //kDebug() << " * * * * * * * * * * ** CLIP EFF WITH KFR FND  * * * * * * * * * * *";
                                 // effect is key-framable, read all effects to retrieve keyframes
-                                double factor;
+                                double factor = 0;
                                 QString starttag;
                                 QString endtag;
                                 QDomNodeList params = currenteffect.elementsByTagName("parameter");
@@ -470,8 +561,8 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml) {
                                 QString keyframes;
                                 int effectin = effect.attribute("in").toInt();
                                 int effectout = effect.attribute("out").toInt();
-                                double startvalue;
-                                double endvalue;
+                                double startvalue = 0;
+                                double endvalue = 0;
                                 for (QDomNode n3 = effect.firstChild(); !n3.isNull(); n3 = n3.nextSibling()) {
                                     // parse effect parameters
                                     QDomElement effectparam = n3.toElement();
@@ -481,7 +572,7 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml) {
                                         endvalue = effectparam.text().toDouble() * factor;
                                 }
                                 // add first keyframe
-                                keyframes.append(QString::number(effectin) + ":" + QString::number(startvalue) + ";" + QString::number(effectout) + ":" + QString::number(endvalue) + ";");
+                                keyframes.append(QString::number(effectin) + ':' + QString::number(startvalue) + ';' + QString::number(effectout) + ':' + QString::number(endvalue) + ';');
                                 QDomNode lastParsedEffect;
                                 ix++;
                                 QDomNode n2 = effects.at(ix);
@@ -506,7 +597,7 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml) {
                                         }
                                     }
                                     if (continueParsing) {
-                                        keyframes.append(QString::number(effectout) + ":" + QString::number(endvalue) + ";");
+                                        keyframes.append(QString::number(effectout) + ':' + QString::number(endvalue) + ';');
                                         ix++;
                                     }
                                 }
@@ -564,38 +655,6 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml) {
                         }
                     }
                 }
-            } else {
-                // The clip in playlist was not listed in the kdenlive producers,
-                // something went wrong, repair required.
-                kWarning() << "CANNOT INSERT CLIP " << id;
-                int out = elem.attribute("out").toInt();
-
-                ItemInfo clipinfo;
-                clipinfo.startPos = GenTime(position, m_doc->fps());
-                clipinfo.endPos = clipinfo.startPos + GenTime(out - in + 1, m_doc->fps());
-                clipinfo.cropStart = GenTime(in, m_doc->fps());
-                clipinfo.track = ix;
-                //kDebug() << "// INSERTING CLIP: " << in << "x" << out << ", track: " << ix << ", ID: " << id << ", SCALE: " << m_scale << ", FPS: " << m_doc->fps();
-
-                DocClipBase *missingClip = getMissingProducer(id);
-                if (!missingClip) {
-                    // We cannot find the producer, something is really wrong, add
-                    // placeholder color clip
-                    QDomElement producerXml;
-                    producerXml.setTagName("producer");
-                    producerXml.setAttribute("resource", "0xff0000ff");
-                    producerXml.setAttribute("mlt_service", "colour");
-                    producerXml.setAttribute("length", "15000");
-                    producerXml.setAttribute("id", id);
-                    missingClip = new DocClipBase(m_doc->clipManager(), producerXml, id);
-                    m_documentErrors.append(i18n("Boken clip producer %1", id) + '\n');
-                } else m_documentErrors.append(i18n("Replaced wrong clip producer %1 with %2", id, missingClip->getId()) + '\n');
-                ClipItem *item = new ClipItem(missingClip, clipinfo, m_doc->fps(), 1.0, false);
-                m_scene->addItem(item);
-                missingClip->addReference();
-                position += (out - in + 1);
-
-                m_doc->setModified(true);
             }
             //m_clipList.append(clip);
         }
@@ -609,8 +668,9 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml) {
     //track->show();
 }
 
-DocClipBase *TrackView::getMissingProducer(const QString id) const {
-    QDomElement missingXml = QDomElement();
+DocClipBase *TrackView::getMissingProducer(const QString id) const
+{
+    QDomElement missingXml;
     QDomDocument doc = m_doc->toXml();
     QString docRoot = doc.documentElement().attribute("root");
     if (!docRoot.endsWith('/')) docRoot.append('/');
@@ -628,38 +688,46 @@ DocClipBase *TrackView::getMissingProducer(const QString id) const {
 
     QDomNodeList params = missingXml.childNodes();
     QString resource;
-    QString mlt_service;
     for (int j = 0; j < params.count(); j++) {
         QDomElement e = params.item(j).toElement();
         if (e.attribute("name") == "resource") {
             resource = e.firstChild().nodeValue();
-        } else if (e.attribute("name") == "mlt_service") {
-            mlt_service = e.firstChild().nodeValue();
+            break;
         }
     }
-    resource.prepend(docRoot);
+    // prepend westley document root if no path in clip resource and not a color clip
+    if (!resource.contains('/') && !resource.startsWith("0x")) resource.prepend(docRoot);
     DocClipBase *missingClip = NULL;
     if (!resource.isEmpty())
         missingClip = m_doc->clipManager()->getClipByResource(resource);
     return missingClip;
 }
 
-QGraphicsScene *TrackView::projectScene() {
+QGraphicsScene *TrackView::projectScene()
+{
     return m_scene;
 }
 
-CustomTrackView *TrackView::projectView() {
+CustomTrackView *TrackView::projectView()
+{
     return m_trackview;
 }
 
-void TrackView::setEditMode(const QString & editMode) {
+void TrackView::setEditMode(const QString & editMode)
+{
     m_editMode = editMode;
 }
 
-const QString & TrackView::editMode() const {
+const QString & TrackView::editMode() const
+{
     return m_editMode;
 }
 
+void TrackView::slotChangeTrackLock(int ix, bool lock)
+{
+    QList<HeaderTrack *> widgets = findChildren<HeaderTrack *>();
+    widgets.at(ix)->setLock(lock);
+}
 
 
 #include "trackview.moc"
