@@ -29,7 +29,6 @@
 #include <QGraphicsLineItem>
 #include <QDomElement>
 
-#define FRAME_SIZE 90
 
 #include "customtrackscene.h"
 #include "ui_timeline_ui.h"
@@ -41,14 +40,13 @@ class KdenliveDoc;
 class CustomRuler;
 class DocClipBase;
 
-class TrackView : public QWidget {
+class TrackView : public QWidget
+{
     Q_OBJECT
 
 public:
-    TrackView(KdenliveDoc *doc, QWidget *parent = 0);
+    explicit TrackView(KdenliveDoc *doc, QWidget *parent = 0);
 
-    const double zoomFactor() const;
-    const int mapLocalToValue(int x) const;
     void setEditMode(const QString & editMode);
     const QString & editMode() const;
     QGraphicsScene *projectScene();
@@ -68,23 +66,20 @@ public slots:
     void slotSetZone(QPoint p);
 
 private:
-    Ui::TimeLine_UI *view;
+    Ui::TimeLine_UI m_view;
     CustomRuler *m_ruler;
     CustomTrackView *m_trackview;
+    QList <QString> m_invalidProducers;
     double m_scale;
     int m_projectTracks;
     QString m_editMode;
     CustomTrackScene *m_scene;
 
     KdenliveDoc *m_doc;
-    QVBoxLayout *m_tracksLayout;
     QVBoxLayout *m_headersLayout;
-    QScrollArea *m_scrollArea;
-    QFrame *m_scrollBox;
-    QVBoxLayout *m_tracksAreaLayout;
     QString m_documentErrors;
     void parseDocument(QDomDocument doc);
-    int slotAddProjectTrack(int ix, QDomElement xml);
+    int slotAddProjectTrack(int ix, QDomElement xml, bool locked);
     DocClipBase *getMissingProducer(const QString id) const;
 
 private slots:
@@ -92,7 +87,7 @@ private slots:
     void moveCursorPos(int pos);
     void slotTransitionItemSelected(Transition*, bool update);
     void slotRebuildTrackHeaders();
-
+    void slotChangeTrackLock(int ix, bool lock);
 
 signals:
     void mousePosition(int);
