@@ -17,27 +17,34 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
-#include <QLabel>
-#include <QFile>
-#include <QXmlStreamWriter>
-#include <QApplication>
-#include <QTimer>
+#include "wizard.h"
+#include "kdenlivesettings.h"
+#include "profilesdialog.h"
 
 #include <KStandardDirs>
 #include <KLocale>
 #include <KProcess>
 #include <kmimetype.h>
 
-#include "kdenlivesettings.h"
-#include "profilesdialog.h"
-#include "wizard.h"
+#include <QLabel>
+#include <QFile>
+#include <QXmlStreamWriter>
+#include <QTimer>
 
-Wizard::Wizard(QWidget *parent): QWizard(parent) {
+const double recommendedMltVersion = 38;
+
+Wizard::Wizard(bool upgrade, QWidget *parent) :
+        QWizard(parent)
+{
     setPixmap(QWizard::WatermarkPixmap, QPixmap(KStandardDirs::locate("appdata", "banner.png")));
 
     QWizardPage *page1 = new QWizardPage;
     page1->setTitle(i18n("Welcome"));
-    QLabel *label = new QLabel(i18n("This is the first time you run Kdenlive. This wizard will let you adjust some basic settings, you will be ready to edit your first movie in a few seconds..."));
+    QLabel *label;
+    if (upgrade)
+        label = new QLabel(i18n("Your Kdenlive version was upgraded. Please take some time to review the basic settings"));
+    else
+        label = new QLabel(i18n("This is the first time you run Kdenlive. This wizard will let you adjust some basic settings, you will be ready to edit your first movie in a few seconds..."));
     label->setWordWrap(true);
     m_startLayout = new QVBoxLayout;
     m_startLayout->addWidget(label);
@@ -56,6 +63,9 @@ Wizard::Wizard(QWidget *parent): QWizard(parent) {
     page2->setTitle(i18n("Video Standard"));
     m_standard.setupUi(page2);
 
+    m_okIcon = KIcon("dialog-ok");
+    m_badIcon = KIcon("dialog-close");
+
     // build profiles lists
     m_profilesInfo = ProfilesDialog::getProfilesInfo();
     QMap<QString, QString>::const_iterator i = m_profilesInfo.constBegin();
@@ -95,7 +105,6 @@ Wizard::Wizard(QWidget *parent): QWizard(parent) {
     QWizardPage *page5 = new QWizardPage;
     page5->setTitle(i18n("Checking system"));
     m_check.setupUi(page5);
-    slotCheckPrograms();
     addPage(page5);
 
     listViewDelegate = new WizardDelegate(m_check.programList);
@@ -105,28 +114,29 @@ Wizard::Wizard(QWidget *parent): QWizard(parent) {
 }
 
 
-void Wizard::checkMltComponents() {
+void Wizard::checkMltComponents()
+{
     m_mltCheck.programList->setColumnCount(2);
     m_mltCheck.programList->setRootIsDecorated(false);
     m_mltCheck.programList->setHeaderHidden(true);
-    QSize itemSize(20, this->fontMetrics().height() * 2.5);
-    KIcon okIcon("dialog-ok");
-    KIcon missingIcon("dialog-close");
+    QSize itemSize(20, fontMetrics().height() * 2.5);
     m_mltCheck.programList->setColumnWidth(0, 30);
     m_mltCheck.programList->setIconSize(QSize(24, 24));
 
 
-    QTreeWidgetItem *item = new QTreeWidgetItem(m_mltCheck.programList, QStringList() << QString() << i18n("Inigo") + " (" + KdenliveSettings::rendererpath() + ')');
-    item->setData(1, Qt::UserRole, i18n("Required for rendering (part of MLT package)"));
-    item->setSizeHint(0, itemSize);
-    item->setIcon(0, okIcon);
+    QTreeWidgetItem *mltitem = new QTreeWidgetItem(m_mltCheck.programList);
+
+    QTreeWidgetItem *inigoitem = new QTreeWidgetItem(m_mltCheck.programList, QStringList() << QString() << i18n("Inigo") + " (" + KdenliveSettings::rendererpath() + ')');
+    inigoitem->setData(1, Qt::UserRole, i18n("Required for rendering (part of MLT package)"));
+    inigoitem->setSizeHint(0, itemSize);
+    inigoitem->setIcon(0, m_okIcon);
 
     // Check MLT's installed producers
     QProcess checkProcess;
     checkProcess.start(KdenliveSettings::rendererpath(), QStringList() << "-query" << "producer");
     if (!checkProcess.waitForStarted()) {
-        item->setIcon(0, missingIcon);
-        item->setData(1, Qt::UserRole, i18n("Error starting MLT's command line player (inigo)"));
+        inigoitem->setIcon(0, m_badIcon);
+        inigoitem->setData(1, Qt::UserRole, i18n("Error starting MLT's command line player (inigo)"));
         button(QWizard::NextButton)->setEnabled(false);
     } else {
         checkProcess.waitForFinished();
@@ -137,12 +147,14 @@ void Wizard::checkMltComponents() {
         avformatItem->setData(1, Qt::UserRole, i18n("Required to work with various video formats (hdv, mpeg, flash, ...)"));
         avformatItem->setSizeHint(0, itemSize);
         if (!result.contains("- avformat")) {
-            avformatItem->setIcon(0, missingIcon);
+            avformatItem->setIcon(0, m_badIcon);
             m_mltCheck.tabWidget->setTabEnabled(1, false);
         } else {
-            avformatItem->setIcon(0, okIcon);
+            avformatItem->setIcon(0, m_okIcon);
             // Make sure we have MLT > 0.3.4
             bool recentMlt = false;
+            int version = 0;
+            QString mltVersion;
             QString exepath = KStandardDirs::findExe("pkg-config");
             if (!exepath.isEmpty()) {
                 checkProcess.start(exepath, QStringList() << "--variable=version" << "mlt-framework");
@@ -150,26 +162,37 @@ void Wizard::checkMltComponents() {
                     kDebug() << "// Error querying MLT's version";
                 } else {
                     checkProcess.waitForFinished();
-                    QString mltVersion = checkProcess.readAllStandardOutput();
-                    int version = 100 * mltVersion.section('.', 0, 0).toInt() + 10 * mltVersion.section('.', 1, 1).toInt() + mltVersion.section('.', 2, 2).toInt();
+                    mltVersion = checkProcess.readAllStandardOutput();
+                    version = 100 * mltVersion.section('.', 0, 0).toInt() + 10 * mltVersion.section('.', 1, 1).toInt() + mltVersion.section('.', 2, 2).toInt();
                     kDebug() << "// FOUND MLT's pkgconfig version: " << version;
                     if (version > 34) recentMlt = true;
                 }
-            } else {
+            }
+            if (version == 0) {
                 checkProcess.start(KdenliveSettings::rendererpath(), QStringList() << "--version");
                 if (!checkProcess.waitForStarted()) {
                     kDebug() << "// Error querying MLT's version";
                 } else {
                     checkProcess.waitForFinished();
-                    QString mltVersion = checkProcess.readAllStandardError();
-                    mltVersion = mltVersion.section("\n", 0, 0).simplified();
+                    mltVersion = checkProcess.readAllStandardError();
+                    mltVersion = mltVersion.section('\n', 0, 0).simplified();
                     mltVersion = mltVersion.section(' ', -1).simplified();
-                    int version = 100 * mltVersion.section('.', 0, 0).toInt() + 10 * mltVersion.section('.', 1, 1).toInt() + mltVersion.section('.', 2, 2).toInt();
+                    version = 100 * mltVersion.section('.', 0, 0).toInt() + 10 * mltVersion.section('.', 1, 1).toInt() + mltVersion.section('.', 2, 2).toInt();
                     kDebug() << "// FOUND MLT version: " << version;
                     if (version > 34) recentMlt = true;
                 }
             }
 
+            mltitem->setText(1, i18n("MLT version: %1", mltVersion.simplified()));
+            mltitem->setSizeHint(0, itemSize);
+            if (version < recommendedMltVersion) {
+                mltitem->setData(1, Qt::UserRole, i18n("Please upgrade to the latest MLT version"));
+                mltitem->setIcon(0, m_badIcon);
+            } else {
+                mltitem->setData(1, Qt::UserRole, i18n("MLT version is correct"));
+                mltitem->setIcon(0, m_okIcon);
+            }
+
             if (recentMlt) {
                 // Check installed audio codecs
                 QProcess checkProcess2;
@@ -182,7 +205,7 @@ void Wizard::checkMltComponents() {
                     QByteArray codecList = checkProcess2.readAllStandardError();
                     QString acodecList(codecList);
                     QStringList result;
-                    QStringList alist = acodecList.split("\n", QString::SkipEmptyParts);
+                    QStringList alist = acodecList.split('\n', QString::SkipEmptyParts);
                     for (int i = 0; i < alist.count(); i++) {
                         if (alist.at(i).contains("- ")) result.append(alist.at(i).section("- ", 1).simplified().toLower());
                     }
@@ -199,7 +222,7 @@ void Wizard::checkMltComponents() {
                     QByteArray codecList = checkProcess2.readAllStandardError();
                     QString vcodecList(codecList);
                     QStringList result;
-                    QStringList vlist = vcodecList.split("\n", QString::SkipEmptyParts);
+                    QStringList vlist = vcodecList.split('\n', QString::SkipEmptyParts);
                     for (int i = 0; i < vlist.count(); i++) {
                         if (vlist.at(i).contains("- ")) result.append(vlist.at(i).section("- ", 1).simplified().toLower());
                     }
@@ -216,7 +239,7 @@ void Wizard::checkMltComponents() {
                     QByteArray codecList = checkProcess2.readAllStandardError();
                     QString vcodecList(codecList);
                     QStringList result;
-                    QStringList vlist = vcodecList.split("\n", QString::SkipEmptyParts);
+                    QStringList vlist = vcodecList.split('\n', QString::SkipEmptyParts);
                     for (int i = 0; i < vlist.count(); i++) {
                         if (vlist.at(i).contains("- ")) {
                             QString format = vlist.at(i).section("- ", 1).simplified().toLower();
@@ -240,9 +263,9 @@ void Wizard::checkMltComponents() {
         dvItem->setData(1, Qt::UserRole, i18n("Required to work with dv files if avformat module is not installed"));
         dvItem->setSizeHint(0, itemSize);
         if (!result.contains("- libdv")) {
-            dvItem->setIcon(0, missingIcon);
+            dvItem->setIcon(0, m_badIcon);
         } else {
-            dvItem->setIcon(0, okIcon);
+            dvItem->setIcon(0, m_okIcon);
         }
 
         // Check MLT image format module
@@ -250,25 +273,24 @@ void Wizard::checkMltComponents() {
         imageItem->setData(1, Qt::UserRole, i18n("Required to work with images"));
         imageItem->setSizeHint(0, itemSize);
         if (!result.contains("- qimage")) {
-            imageItem->setIcon(0, missingIcon);
+            imageItem->setIcon(0, m_badIcon);
             imageItem = new QTreeWidgetItem(m_mltCheck.programList, QStringList() << QString() << i18n("Pixbuf module"));
             imageItem->setData(1, Qt::UserRole, i18n("Required to work with images"));
             imageItem->setSizeHint(0, itemSize);
-            if (!result.contains("- pixbuf")) imageItem->setIcon(0, missingIcon);
-            else imageItem->setIcon(0, okIcon);
+            if (!result.contains("- pixbuf")) imageItem->setIcon(0, m_badIcon);
+            else imageItem->setIcon(0, m_okIcon);
         } else {
-            imageItem->setIcon(0, okIcon);
+            imageItem->setIcon(0, m_okIcon);
         }
     }
 }
 
-void Wizard::slotCheckPrograms() {
+void Wizard::slotCheckPrograms()
+{
     m_check.programList->setColumnCount(2);
     m_check.programList->setRootIsDecorated(false);
     m_check.programList->setHeaderHidden(true);
-    QSize itemSize(20, this->fontMetrics().height() * 2.5);
-    KIcon okIcon("dialog-ok");
-    KIcon missingIcon("dialog-close");
+    QSize itemSize(20, fontMetrics().height() * 2.5);
     m_check.programList->setColumnWidth(0, 30);
     m_check.programList->setIconSize(QSize(24, 24));
 
@@ -276,37 +298,38 @@ void Wizard::slotCheckPrograms() {
     item->setData(1, Qt::UserRole, i18n("Required for webcam capture"));
     item->setSizeHint(0, itemSize);
     QString exepath = KStandardDirs::findExe("ffmpeg");
-    if (exepath.isEmpty()) item->setIcon(0, missingIcon);
-    else if (KStandardDirs::findExe("ffplay").isEmpty()) item->setIcon(0, missingIcon);
-    else item->setIcon(0, okIcon);
+    if (exepath.isEmpty()) item->setIcon(0, m_badIcon);
+    else if (KStandardDirs::findExe("ffplay").isEmpty()) item->setIcon(0, m_badIcon);
+    else item->setIcon(0, m_okIcon);
 
     item = new QTreeWidgetItem(m_check.programList, QStringList() << QString() << i18n("Recordmydesktop"));
     item->setData(1, Qt::UserRole, i18n("Required for screen capture"));
     item->setSizeHint(0, itemSize);
-    if (KStandardDirs::findExe("recordmydesktop").isEmpty()) item->setIcon(0, missingIcon);
-    else item->setIcon(0, okIcon);
+    if (KStandardDirs::findExe("recordmydesktop").isEmpty()) item->setIcon(0, m_badIcon);
+    else item->setIcon(0, m_okIcon);
 
     item = new QTreeWidgetItem(m_check.programList, QStringList() << QString() << i18n("Dvgrab"));
     item->setData(1, Qt::UserRole, i18n("Required for firewire capture"));
     item->setSizeHint(0, itemSize);
-    if (KStandardDirs::findExe("dvgrab").isEmpty()) item->setIcon(0, missingIcon);
-    else item->setIcon(0, okIcon);
+    if (KStandardDirs::findExe("dvgrab").isEmpty()) item->setIcon(0, m_badIcon);
+    else item->setIcon(0, m_okIcon);
 
     item = new QTreeWidgetItem(m_check.programList, QStringList() << QString() << i18n("Dvdauthor"));
     item->setData(1, Qt::UserRole, i18n("Required for creation of DVD"));
     item->setSizeHint(0, itemSize);
-    if (KStandardDirs::findExe("dvdauthor").isEmpty()) item->setIcon(0, missingIcon);
-    else item->setIcon(0, okIcon);
+    if (KStandardDirs::findExe("dvdauthor").isEmpty()) item->setIcon(0, m_badIcon);
+    else item->setIcon(0, m_okIcon);
 
     item = new QTreeWidgetItem(m_check.programList, QStringList() << QString() << i18n("Mkisofs"));
-    item->setData(1, Qt::UserRole, i18n("Required for creation of DVD iso images"));
+    item->setData(1, Qt::UserRole, i18n("Required for creation of DVD ISO images"));
     item->setSizeHint(0, itemSize);
-    if (KStandardDirs::findExe("mkisofs").isEmpty()) item->setIcon(0, missingIcon);
-    else item->setIcon(0, okIcon);
+    if (KStandardDirs::findExe("mkisofs").isEmpty()) item->setIcon(0, m_badIcon);
+    else item->setIcon(0, m_okIcon);
 
 }
 
-void Wizard::installExtraMimes(QString baseName, QStringList globs) {
+void Wizard::installExtraMimes(QString baseName, QStringList globs)
+{
     QString mimefile = baseName;
     mimefile.replace('/', '-');
     KMimeType::Ptr mime = KMimeType::mimeType(baseName);
@@ -354,7 +377,8 @@ void Wizard::installExtraMimes(QString baseName, QStringList globs) {
     }
 }
 
-void Wizard::runUpdateMimeDatabase() {
+void Wizard::runUpdateMimeDatabase()
+{
     const QString localPackageDir = KStandardDirs::locateLocal("xdgdata-mime", QString());
     //Q_ASSERT(!localPackageDir.isEmpty());
     KProcess proc;
@@ -366,7 +390,8 @@ void Wizard::runUpdateMimeDatabase() {
     }
 }
 
-void Wizard::slotCheckThumbs() {
+void Wizard::slotCheckThumbs()
+{
     QString pixname = "timeline_vthumbs.png";
     if (!m_extra.audiothumbs->isChecked() && !m_extra.videothumbs->isChecked()) {
         pixname = "timeline_nothumbs.png";
@@ -379,7 +404,8 @@ void Wizard::slotCheckThumbs() {
     m_extra.timeline_preview->setPixmap(QPixmap(KStandardDirs::locate("appdata", pixname)));
 }
 
-void Wizard::slotCheckStandard() {
+void Wizard::slotCheckStandard()
+{
     m_standard.profiles_list->clear();
     QStringList profiles;
     if (m_standard.button_dv->isChecked()) {
@@ -406,13 +432,15 @@ void Wizard::slotCheckStandard() {
     m_standard.profiles_list->setCurrentRow(0);
 }
 
-void Wizard::slotCheckSelectedItem() {
+void Wizard::slotCheckSelectedItem()
+{
     // Make sure we always have an item highlighted
     m_standard.profiles_list->setCurrentRow(m_standard.profiles_list->currentRow());
 }
 
 
-void Wizard::adjustSettings() {
+void Wizard::adjustSettings()
+{
     if (m_extra.installmimes->isChecked()) {
         QStringList globs;
         globs << "*.mts" << "*.m2t" << "*.mod" << "*.ts";
@@ -436,7 +464,8 @@ void Wizard::adjustSettings() {
 
 }
 
-void Wizard::slotCheckMlt() {
+void Wizard::slotCheckMlt()
+{
     QString errorMessage;
     if (KdenliveSettings::rendererpath().isEmpty()) {
         errorMessage.append(i18n("your MLT installation cannot be found. Install MLT and restart Kdenlive.\n"));
@@ -454,12 +483,12 @@ void Wizard::slotCheckMlt() {
     QProcess checkProcess2;
     checkProcess2.start(KdenliveSettings::rendererpath(), QStringList() << "-query" << "consumer");
     if (!checkProcess2.waitForStarted())
-        errorMessage.append(i18n("Error starting MLT's command line player (inigo).") + "\n");
+        errorMessage.append(i18n("Error starting MLT's command line player (inigo).") + '\n');
 
     checkProcess2.waitForFinished();
 
     QByteArray result = checkProcess2.readAllStandardError();
-    if (!result.contains("sdl") || !result.contains("sdl_preview")) errorMessage.append(i18n("MLT's SDL module not found. Please check your MLT install. Kdenlive will not work until this issue is fixed.") + "\n");
+    if (!result.contains("sdl") || !result.contains("sdl_preview")) errorMessage.append(i18n("MLT's SDL module not found. Please check your MLT install. Kdenlive will not work until this issue is fixed.") + '\n');
 
     if (!errorMessage.isEmpty()) {
         errorMessage.prepend(QString("<b>%1</b><br>").arg(i18n("Fatal Error")));
@@ -475,9 +504,11 @@ void Wizard::slotCheckMlt() {
     } else m_systemCheckIsOk = true;
 
     if (m_systemCheckIsOk) checkMltComponents();
+    slotCheckPrograms();
 }
 
-bool Wizard::isOk() const {
+bool Wizard::isOk() const
+{
     return m_systemCheckIsOk;
 }
 
