@@ -26,6 +26,7 @@
 #include <QItemDelegate>
 #include <QPainter>
 
+#include <KIcon>
 #include <KDebug>
 
 #include "ui_wizardstandard_ui.h"
@@ -33,7 +34,8 @@
 #include "ui_wizardcheck_ui.h"
 #include "ui_wizardmltcheck_ui.h"
 
-class WizardDelegate: public QItemDelegate {
+class WizardDelegate: public QItemDelegate
+{
 public:
     WizardDelegate(QAbstractItemView* parent = 0): QItemDelegate(parent) {
     }
@@ -69,10 +71,11 @@ public:
 };
 
 
-class Wizard : public QWizard {
+class Wizard : public QWizard
+{
     Q_OBJECT
 public:
-    Wizard(QWidget * parent = 0);
+    Wizard(bool upgrade, QWidget * parent = 0);
     void installExtraMimes(QString baseName, QStringList globs);
     void runUpdateMimeDatabase();
     void adjustSettings();
@@ -91,6 +94,8 @@ private:
     QMap <QString, QString> m_profilesInfo;
     void slotCheckPrograms();
     void checkMltComponents();
+    KIcon m_okIcon;
+    KIcon m_badIcon;
 
 private slots:
     void slotCheckThumbs();
